Author: Brian B. Avants and Nicholas J. Tustison

# ANTsPyMM processing summary and data dictionary

#### Brian B. Avants and Nicholas J. Tustison

## ANTsPyMM imaging-derived phenotypes and associated coordinate systems / neuroanatomy

A quick overview of the labels used/generated by this framework: .

An example annotated output tree is here. This shows the results of a real run of ANTsPyMM on multiple modality MRI (M3RI).

The `ANTsPyMM` system takes advantage of templates, core T1 processing and super-resolution described in this paper.

- We quantify cortex with the Desikan-Killiany-Tourville parcellation (DKT).

  - `*dktregions` refers to the segmentation label directly from the deep learning method.

  - `*dktcortex` refers to the segmentation label restricted to the cortical segmentation that is provided by the tissue segmentation method.

- Subcortical segmentation with deep learning and also SyN registration leverages the CIT168 atlas 10.1101/211201.

- A medial temporal lobe parcellation is based on manual labels derived from M. Yassa’s research group (preprint) and described here.

- A cerebellum parcellation based on a template from the CoBrALab with additional manual editing by the Tustison family (publication in progress). The parcellation scheme is defined using the Schmahmann nomenclature (reviewed here). The core tool is named `cerebellum_morphology` and based on a concatentation of two U-nets.

- Brain stem is subdivided into the mid-brain, pons and medulla; This segmentation derives from registration between the individual T1w and the manually labeled CIT168 template. The protocol is based on this used in Freesurfer.

- We segment anatomy related to the basal forebrain and associated cholinergic neurons with a deep learning method (`deepNBM`) derived from manual labeling of ADNI data.

  - This approach is based on anatomical landmarks proposed in Liu, A. et al. (2015). The `deepNBM` method uses super-resolution segmentation to take advantage of manual labels performed on super-resolution training data.

  - The classic Zaborszky, L. et al. (2008) “Stereotaxic probabilistic maps of the magnocellular cell groups in human basal forebrain.” Neuroimage 42: 1127–1141 also informed the manual labeling.

  - Presented at Human Brain Mapping conference 2022.

- The Mori JHU white matter atlas provides a parcellation of white matter regions (paper here) which are applied to diffusion weighted images.

- Jonathan Power’s coordinates from “Functional Network Organization of the Human Brain” 10.1016/j.neuron.2011.09.006 were previously used to guide our analysis of resting state function MRI (rsfMRI). We also based our processing evaluation on these data. However, we now use the homotopic coordinates described below.

- Yeo’s Homotopic local-global parcellation of the human cerebral cortex from resting-state functional connectivity is the new default that we use for rsfMRI instead of the JP coordinates. Additional details about the parcellation are here. We use the variant with 500 homotopic parcels i.e. 250 per hemisphere.

  - these parcels are used to generate inter and intra network correlations using the following networks (which are further subdivided s.t. 17 network names are available)

    - Visual Network: Processes visual information, including spatial and motion processing.

    - Somatomotor Network: Involved in the control of movement and processing of somatosensory information.

    - Dorsal Attention Network: Plays a key role in top-down attentional control and spatial orientation.

    - Ventral Attention Network: Involved in detecting unexpected stimuli and bottom-up attention.

    - Limbic Network: Associated with emotion processing, memory, and autonomic functions.

    - Frontoparietal Network: Important for cognitive functions including working memory and executive control.

    - Default Mode Network (DMN): Active during rest and involved in self-referential thought, memory retrieval, and planning for the future.

  - The 17 Network abbreviations are adapted from Ru Kong’s work.

  - rsfMRI phenotype variables like “fcnxpro129” indicate that parameter set 129 was used; currently 122 is considered “best” but 129 and 134 are also provided. they differ in the censoring and nuisance variables used in the processing.

  - we also provide voxel-wise measurements within each parcel including:

    - fALFF and ALFF each divided by the global mean of the brain (mfALFF and mALFF)

    - percent absolute fluctuation divided by the global PerAF mean of the brain (mPerAF)

## ANTsPyMM data dictionary

The `ANTsPyMM` data dictionary labels associates each column name with each of the above anatomical references. Table 1 below summarizes the number of variables associated with each modality and anatomical prior space. DTI-derived connectivity yields the largest number of variables because we pairwise map each DKT cortical region as well as the primary CIT168 regions.

### Table 1

| DTI | Flair | Neuromelanin | Other | restingStatefMRI | T1 DiReCT thickness processing | T1 hierarchical processing | unique id | p
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
| (N=709) | (N=46) | (N=44) | (N=409) | (N=2143) | (N=63) | (N=853) | (N=2)
Atlas |  |  |  |  |  |  |  |  | < 0.001
ANTs | 127 (17.9%) | 46 (100.0%) | 28 (63.6%) | 409 (100.0%) | 0 ( 0.0%) | 1 ( 1.6%) | 21 ( 2.5%) | 0 ( 0.0%) |
BF | 32 ( 4.5%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 24 ( 2.8%) | 0 ( 0.0%) |
CIT168 | 200 (28.2%) | 0 ( 0.0%) | 16 (36.4%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 189 (22.2%) | 0 ( 0.0%) |
desikan-killiany-tourville | 252 (35.5%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 62 (98.4%) | 486 (57.0%) | 0 ( 0.0%) |
johns hopkins white matter | 98 (13.8%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) |
MTL | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 36 ( 4.2%) | 0 ( 0.0%) |
quality control metrics | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 25 ( 2.9%) | 0 ( 0.0%) |
TustisonCobra | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 72 ( 8.4%) | 0 ( 0.0%) |
unique id | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 2 (100.0%) |
yeo_homotopic | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 2143 (100.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) |
Measurement | unique values:64 | unique values:64 | unique values:64 | unique values:64 | unique values:64 | unique values:64 | unique values:64 | unique values:64 |

## Quality control metrics

Automated (blind) QC is part of standard ANTsPyMM processing. QC metrics are therefore present in the standard output tables. Notes on the meaning of these metrics, along with examples of the metrics on images, are here.

The most important QC metric is `T1Hier_resnetGrade` which rejects truly bad images. We recommend rejecting images with `T1Hier_resnetGrade < 1.01` where higher thresholds may be useful in some cases. This grading function uses deep learning to generate a pseudocontinuous measurement of aggregate T1w image quality. Several factors will contribute to these scores and it is not a perfect approach but it is well-defined and evaluated based on manual ratings here.

The `outlierness` function produces additional blind QC measurements via automated outlierness calculations. These measurements are denoted by Local Outlier Probability (LOOP `*loop*` ) and local outlier factor ( LOF `*lof*` ) column names.

Time series images may have additional QC metrics such as:

- TSNR: temporal signal to noise ratio

- SSNR: spatial signal to noise ratio on the mean image (different from TSNR)

- DVARS: the spatial root mean square of the data after temporal differencing

- Neuromelanin (NM) has its own set of variables including:

  - count: the number of acquisitions at that date

  - min/max/mean/sd: a statistic on the raw image signal after averaging the acquisitions

  - `avg/std_refregion` : average and standard deviation of signal in the reference region

  - `avg/std_substantianigra` : average and standard deviation of signal in the substantia nigra or a related CIT168 region (determined by deepCIT168)

  - `NM2DMT_NM_substantianigra_z_coordinate`: estimate of the normalized (zero to one) z-coordinate of the substantia nigra in a neuromelanin scan; higher values mean higher in the slab.

- the framewise displacement (FD) values are 10x in DTI data compared to rsfMRI data. E.g. if 0.3 were a reasonable high motion threshold in rsfMRI; then 3.0 would be a comparable threshold for DTI.

## the full data dictionary

A sortable version of the data dictionary is below (if viewing on local machine).

### Table 2

Label
Modality
side
Atlas
Measurement
Anatomy
tidynames
X
Other
​
ANTs
ignore
​
x
filename
Other
​
ANTs
​
​
filename
dimensionality
Other
​
ANTs
​
​
dimensionality
noise
Other
​
ANTs
QC - noise/contrast
​
noise
snr
Other
​
ANTs
QC - noise/contrast
​
snr
cnr
Other
​
ANTs
QC - noise/contrast
​
cnr
psnr
Other
​
ANTs
QC - similarity measurements
​
psnr
ssim
Other
​
ANTs
QC - similarity measurements
​
ssim
mi
Other
​
ANTs
QC - similarity measurements
​
mi
reflection_err
Other
​
ANTs
QC - similarity measurements
​
reflection.err
EVR
Other
​
ANTs
QC - eigenvalue ratio
​
evr
msk_vol
Other
​
ANTs
geometry/volume
​
msk.vol
spc0
Other
​
ANTs
QC - physical space
​
spc0
spc1
Other
​
ANTs
QC - physical space
​
spc1
spc2
Other
​
ANTs
QC - physical space
​
spc2
org0
Other
​
ANTs
QC - physical space
​
org0
org1
Other
​
ANTs
QC - physical space
​
org1
org2
Other
​
ANTs
QC - physical space
​
org2
dimx
Other
​
ANTs
QC - physical space
​
dimx
dimy
Other
​
ANTs
QC - physical space
​
dimy
dimz
Other
​
ANTs
QC - physical space
​
dimz
dimt
Other
​
ANTs
QC - physical space
​
dimt
slice
Other
​
ANTs
slice number in time series (ignore)
​
slice
modality
Other
​
ANTs
generic modality name
​
modality
mriseries
Other
​
ANTs
​
​
mriseries
mrimfg
Other
​
ANTs
MRI manufacturer (often missing)
​
mrimfg
mrimodel
Other
​
ANTs
MRI model (often missing)
​
mrimodel
mriMagneticFieldStrength
Other
​
ANTs
MRI field strength (often missing)
​
mrimagneticfieldstrength
mriSAR
Other
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
mrisar
mriPixelBandwidth
Other
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
mripixelbandwidth
mriPixelBandwidthPE
Other
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
mripixelbandwidthpe
dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
dti.bvaluemax
dti_bvecnorm
Other
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
dti.bvecnorm
ol_loop
Other
​
ANTs
QC
​
ol.loop
ol_lof
Other
​
ANTs
QC
​
ol.lof
ol_lof_decision
Other
​
ANTs
QC
​
ol.lof.decision
dti_failed
Other
​
ANTs
heuristic decision about dti usability (eg its 3D)
​
dti.failed
rsf_failed
Other
​
ANTs
heuristic decision about rsfMRI usability (eg its 3D)
​
rsf.failed
subjectID
Other
​
ANTs
unique subject ID
​
subjectid
date
Other
​
ANTs
image acquisition date
​
date
subjectIDdate
Other
​
ANTs
concatenation of subject ID and date
​
subjectiddate
imageID
Other
​
ANTs
unique image ID (ideally unique but not always)
​
imageid
negol
Other
​
ANTs
negative outlier variable (higher is better)
​
negol
repeat.
Other
​
ANTs
​
​
repeat.
flairfn
Flair
​
ANTs
original source data filename
​
flairfn
T2Flair_dimensionality
Flair
​
ANTs
​
​
t2flair.dimensionality
T2Flair_noise
Flair
​
ANTs
QC
​
t2flair.noise
T2Flair_snr
Flair
​
ANTs
QC
​
t2flair.snr
T2Flair_cnr
Flair
​
ANTs
QC
​
t2flair.cnr
T2Flair_psnr
Flair
​
ANTs
QC
​
t2flair.psnr
T2Flair_ssim
Flair
​
ANTs
QC
​
t2flair.ssim
T2Flair_mi
Flair
​
ANTs
​
​
t2flair.mi
T2Flair_reflection_err
Flair
​
ANTs
​
​
t2flair.reflection.err
T2Flair_EVR
Flair
​
ANTs
​
​
t2flair.evr
T2Flair_msk_vol
Flair
​
ANTs
geometry/volume
​
t2flair.msk.vol
T2Flair_spc0
Flair
​
ANTs
​
​
t2flair.spc0
T2Flair_spc1
Flair
​
ANTs
​
​
t2flair.spc1
T2Flair_spc2
Flair
​
ANTs
​
​
t2flair.spc2
T2Flair_org0
Flair
​
ANTs
​
​
t2flair.org0
T2Flair_org1
Flair
​
ANTs
​
​
t2flair.org1
T2Flair_org2
Flair
​
ANTs
​
​
t2flair.org2
T2Flair_dimx
Flair
​
ANTs
​
​
t2flair.dimx
T2Flair_dimy
Flair
​
ANTs
​
​
t2flair.dimy
T2Flair_dimz
Flair
​
ANTs
​
​
t2flair.dimz
T2Flair_dimt
Flair
​
ANTs
​
​
t2flair.dimt
T2Flair_slice
Flair
​
ANTs
slice number in time series (ignore)
​
t2flair.slice
T2Flair_modality
Flair
​
ANTs
​
​
t2flair.modality
T2Flair_mriseries
Flair
​
ANTs
​
​
t2flair.mriseries
T2Flair_mriSAR
Flair
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
t2flair.mrisar
T2Flair_mriPixelBandwidth
Flair
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
t2flair.mripixelbandwidth
T2Flair_mriPixelBandwidthPE
Flair
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
t2flair.mripixelbandwidthpe
T2Flair_dti_bvalueMax
Flair
​
ANTs
MRI DTI maximum bvalue (often missing)
​
t2flair.dti.bvaluemax
T2Flair_dti_bvecnorm
Flair
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
t2flair.dti.bvecnorm
T2Flair_ol_loop
Flair
​
ANTs
QC
​
t2flair.ol.loop
T2Flair_ol_lof
Flair
​
ANTs
QC
​
t2flair.ol.lof
T2Flair_ol_lof_decision
Flair
​
ANTs
QC
​
t2flair.ol.lof.decision
flairid
Flair
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
flairid
T2Flair_negol
Flair
​
ANTs
​
​
t2flair.negol
T2Flair_score_ol_loop
Flair
​
ANTs
QC
​
t2flair.score.ol.loop
T2Flair_score_noise
Flair
​
ANTs
QC
​
t2flair.score.noise
T2Flair_score_snr
Flair
​
ANTs
QC
​
t2flair.score.snr
T2Flair_score_EVR
Flair
​
ANTs
​
​
t2flair.score.evr
T2Flair_score_reflection_err
Flair
​
ANTs
​
​
t2flair.score.reflection.err
T2Flair_best_score
Flair
​
ANTs
​
​
t2flair.best.score
nmfn1
Other
​
ANTs
original source data filename
​
nmfn1
NM1_dimensionality
Other
​
ANTs
​
​
nm1.dimensionality
NM1_noise
Other
​
ANTs
QC
​
nm1.noise
NM1_snr
Other
​
ANTs
QC
​
nm1.snr
NM1_cnr
Other
​
ANTs
QC
​
nm1.cnr
NM1_psnr
Other
​
ANTs
QC
​
nm1.psnr
NM1_ssim
Other
​
ANTs
QC
​
nm1.ssim
NM1_mi
Other
​
ANTs
​
​
nm1.mi
NM1_reflection_err
Other
​
ANTs
​
​
nm1.reflection.err
NM1_EVR
Other
​
ANTs
​
​
nm1.evr
NM1_msk_vol
Other
​
ANTs
geometry/volume
​
nm1.msk.vol
NM1_spc0
Other
​
ANTs
​
​
nm1.spc0
NM1_spc1
Other
​
ANTs
​
​
nm1.spc1
NM1_spc2
Other
​
ANTs
​
​
nm1.spc2
NM1_org0
Other
​
ANTs
​
​
nm1.org0
NM1_org1
Other
​
ANTs
​
​
nm1.org1
NM1_org2
Other
​
ANTs
​
​
nm1.org2
NM1_dimx
Other
​
ANTs
​
​
nm1.dimx
NM1_dimy
Other
​
ANTs
​
​
nm1.dimy
NM1_dimz
Other
​
ANTs
​
​
nm1.dimz
NM1_dimt
Other
​
ANTs
​
​
nm1.dimt
NM1_slice
Other
​
ANTs
slice number in time series (ignore)
​
nm1.slice
NM1_modality
Other
​
ANTs
​
​
nm1.modality
NM1_mriseries
Other
​
ANTs
​
​
nm1.mriseries
NM1_mriSAR
Other
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
nm1.mrisar
NM1_mriPixelBandwidth
Other
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
nm1.mripixelbandwidth
NM1_mriPixelBandwidthPE
Other
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
nm1.mripixelbandwidthpe
NM1_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
nm1.dti.bvaluemax
NM1_dti_bvecnorm
Other
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
nm1.dti.bvecnorm
NM1_ol_loop
Other
​
ANTs
QC
​
nm1.ol.loop
NM1_ol_lof
Other
​
ANTs
QC
​
nm1.ol.lof
NM1_ol_lof_decision
Other
​
ANTs
QC
​
nm1.ol.lof.decision
nmid1
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmid1
NM1_negol
Other
​
ANTs
​
​
nm1.negol
NM1_score_ol_loop
Other
​
ANTs
QC
​
nm1.score.ol.loop
NM1_score_noise
Other
​
ANTs
QC
​
nm1.score.noise
NM1_score_snr
Other
​
ANTs
QC
​
nm1.score.snr
NM1_score_EVR
Other
​
ANTs
​
​
nm1.score.evr
NM1_score_reflection_err
Other
​
ANTs
​
​
nm1.score.reflection.err
NM1_best_score
Other
​
ANTs
​
​
nm1.best.score
nmfn2
Other
​
ANTs
original source data filename
​
nmfn2
NM2_dimensionality
Other
​
ANTs
​
​
nm2.dimensionality
NM2_noise
Other
​
ANTs
QC
​
nm2.noise
NM2_snr
Other
​
ANTs
QC
​
nm2.snr
NM2_cnr
Other
​
ANTs
QC
​
nm2.cnr
NM2_psnr
Other
​
ANTs
QC
​
nm2.psnr
NM2_ssim
Other
​
ANTs
QC
​
nm2.ssim
NM2_mi
Other
​
ANTs
​
​
nm2.mi
NM2_reflection_err
Other
​
ANTs
​
​
nm2.reflection.err
NM2_EVR
Other
​
ANTs
​
​
nm2.evr
NM2_msk_vol
Other
​
ANTs
geometry/volume
​
nm2.msk.vol
NM2_spc0
Other
​
ANTs
​
​
nm2.spc0
NM2_spc1
Other
​
ANTs
​
​
nm2.spc1
NM2_spc2
Other
​
ANTs
​
​
nm2.spc2
NM2_org0
Other
​
ANTs
​
​
nm2.org0
NM2_org1
Other
​
ANTs
​
​
nm2.org1
NM2_org2
Other
​
ANTs
​
​
nm2.org2
NM2_dimx
Other
​
ANTs
​
​
nm2.dimx
NM2_dimy
Other
​
ANTs
​
​
nm2.dimy
NM2_dimz
Other
​
ANTs
​
​
nm2.dimz
NM2_dimt
Other
​
ANTs
​
​
nm2.dimt
NM2_slice
Other
​
ANTs
slice number in time series (ignore)
​
nm2.slice
NM2_modality
Other
​
ANTs
​
​
nm2.modality
NM2_mriseries
Other
​
ANTs
​
​
nm2.mriseries
NM2_mriSAR
Other
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
nm2.mrisar
NM2_mriPixelBandwidth
Other
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
nm2.mripixelbandwidth
NM2_mriPixelBandwidthPE
Other
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
nm2.mripixelbandwidthpe
NM2_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
nm2.dti.bvaluemax
NM2_dti_bvecnorm
Other
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
nm2.dti.bvecnorm
NM2_ol_loop
Other
​
ANTs
QC
​
nm2.ol.loop
NM2_ol_lof
Other
​
ANTs
QC
​
nm2.ol.lof
NM2_ol_lof_decision
Other
​
ANTs
QC
​
nm2.ol.lof.decision
nmid2
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmid2
NM2_negol
Other
​
ANTs
​
​
nm2.negol
NM2_score_ol_loop
Other
​
ANTs
QC
​
nm2.score.ol.loop
NM2_score_noise
Other
​
ANTs
QC
​
nm2.score.noise
NM2_score_snr
Other
​
ANTs
QC
​
nm2.score.snr
NM2_score_EVR
Other
​
ANTs
​
​
nm2.score.evr
NM2_score_reflection_err
Other
​
ANTs
​
​
nm2.score.reflection.err
NM2_best_score
Other
​
ANTs
​
​
nm2.best.score
nmfn3
Other
​
ANTs
original source data filename
​
nmfn3
NM3_dimensionality
Other
​
ANTs
​
​
nm3.dimensionality
NM3_noise
Other
​
ANTs
QC
​
nm3.noise
NM3_snr
Other
​
ANTs
QC
​
nm3.snr
NM3_cnr
Other
​
ANTs
QC
​
nm3.cnr
NM3_psnr
Other
​
ANTs
QC
​
nm3.psnr
NM3_ssim
Other
​
ANTs
QC
​
nm3.ssim
NM3_mi
Other
​
ANTs
​
​
nm3.mi
NM3_reflection_err
Other
​
ANTs
​
​
nm3.reflection.err
NM3_EVR
Other
​
ANTs
​
​
nm3.evr
NM3_msk_vol
Other
​
ANTs
geometry/volume
​
nm3.msk.vol
NM3_spc0
Other
​
ANTs
​
​
nm3.spc0
NM3_spc1
Other
​
ANTs
​
​
nm3.spc1
NM3_spc2
Other
​
ANTs
​
​
nm3.spc2
NM3_org0
Other
​
ANTs
​
​
nm3.org0
NM3_org1
Other
​
ANTs
​
​
nm3.org1
NM3_org2
Other
​
ANTs
​
​
nm3.org2
NM3_dimx
Other
​
ANTs
​
​
nm3.dimx
NM3_dimy
Other
​
ANTs
​
​
nm3.dimy
NM3_dimz
Other
​
ANTs
​
​
nm3.dimz
NM3_dimt
Other
​
ANTs
​
​
nm3.dimt
NM3_slice
Other
​
ANTs
slice number in time series (ignore)
​
nm3.slice
NM3_modality
Other
​
ANTs
​
​
nm3.modality
NM3_mriseries
Other
​
ANTs
​
​
nm3.mriseries
NM3_mriSAR
Other
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
nm3.mrisar
NM3_mriPixelBandwidth
Other
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
nm3.mripixelbandwidth
NM3_mriPixelBandwidthPE
Other
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
nm3.mripixelbandwidthpe
NM3_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
nm3.dti.bvaluemax
NM3_dti_bvecnorm
Other
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
nm3.dti.bvecnorm
NM3_ol_loop
Other
​
ANTs
QC
​
nm3.ol.loop
NM3_ol_lof
Other
​
ANTs
QC
​
nm3.ol.lof
NM3_ol_lof_decision
Other
​
ANTs
QC
​
nm3.ol.lof.decision
nmid3
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmid3
NM3_negol
Other
​
ANTs
​
​
nm3.negol
NM3_score_ol_loop
Other
​
ANTs
QC
​
nm3.score.ol.loop
NM3_score_noise
Other
​
ANTs
QC
​
nm3.score.noise
NM3_score_snr
Other
​
ANTs
QC
​
nm3.score.snr
NM3_score_EVR
Other
​
ANTs
​
​
nm3.score.evr
NM3_score_reflection_err
Other
​
ANTs
​
​
nm3.score.reflection.err
NM3_best_score
Other
​
ANTs
​
​
nm3.best.score
nmfn4
Other
​
ANTs
original source data filename
​
nmfn4
NM4_dimensionality
Other
​
ANTs
​
​
nm4.dimensionality
NM4_noise
Other
​
ANTs
QC
​
nm4.noise
NM4_snr
Other
​
ANTs
QC
​
nm4.snr
NM4_cnr
Other
​
ANTs
QC
​
nm4.cnr
NM4_psnr
Other
​
ANTs
QC
​
nm4.psnr
NM4_ssim
Other
​
ANTs
QC
​
nm4.ssim
NM4_mi
Other
​
ANTs
​
​
nm4.mi
NM4_reflection_err
Other
​
ANTs
​
​
nm4.reflection.err
NM4_EVR
Other
​
ANTs
​
​
nm4.evr
NM4_msk_vol
Other
​
ANTs
geometry/volume
​
nm4.msk.vol
NM4_spc0
Other
​
ANTs
​
​
nm4.spc0
NM4_spc1
Other
​
ANTs
​
​
nm4.spc1
NM4_spc2
Other
​
ANTs
​
​
nm4.spc2
NM4_org0
Other
​
ANTs
​
​
nm4.org0
NM4_org1
Other
​
ANTs
​
​
nm4.org1
NM4_org2
Other
​
ANTs
​
​
nm4.org2
NM4_dimx
Other
​
ANTs
​
​
nm4.dimx
NM4_dimy
Other
​
ANTs
​
​
nm4.dimy
NM4_dimz
Other
​
ANTs
​
​
nm4.dimz
NM4_dimt
Other
​
ANTs
​
​
nm4.dimt
NM4_slice
Other
​
ANTs
slice number in time series (ignore)
​
nm4.slice
NM4_modality
Other
​
ANTs
​
​
nm4.modality
NM4_mriseries
Other
​
ANTs
​
​
nm4.mriseries
NM4_mriSAR
Other
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
nm4.mrisar
NM4_mriPixelBandwidth
Other
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
nm4.mripixelbandwidth
NM4_mriPixelBandwidthPE
Other
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
nm4.mripixelbandwidthpe
NM4_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
nm4.dti.bvaluemax
NM4_dti_bvecnorm
Other
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
nm4.dti.bvecnorm
NM4_ol_loop
Other
​
ANTs
QC
​
nm4.ol.loop
NM4_ol_lof
Other
​
ANTs
QC
​
nm4.ol.lof
NM4_ol_lof_decision
Other
​
ANTs
QC
​
nm4.ol.lof.decision
nmid4
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmid4
NM4_negol
Other
​
ANTs
​
​
nm4.negol
NM4_score_ol_loop
Other
​
ANTs
QC
​
nm4.score.ol.loop
NM4_score_noise
Other
​
ANTs
QC
​
nm4.score.noise
NM4_score_snr
Other
​
ANTs
QC
​
nm4.score.snr
NM4_score_EVR
Other
​
ANTs
​
​
nm4.score.evr
NM4_score_reflection_err
Other
​
ANTs
​
​
nm4.score.reflection.err
NM4_best_score
Other
​
ANTs
​
​
nm4.best.score
nmfn5
Other
​
ANTs
original source data filename
​
nmfn5
NM5_dimensionality
Other
​
ANTs
​
​
nm5.dimensionality
NM5_noise
Other
​
ANTs
QC
​
nm5.noise
NM5_snr
Other
​
ANTs
QC
​
nm5.snr
NM5_cnr
Other
​
ANTs
QC
​
nm5.cnr
NM5_psnr
Other
​
ANTs
QC
​
nm5.psnr
NM5_ssim
Other
​
ANTs
QC
​
nm5.ssim
NM5_mi
Other
​
ANTs
​
​
nm5.mi
NM5_reflection_err
Other
​
ANTs
​
​
nm5.reflection.err
NM5_EVR
Other
​
ANTs
​
​
nm5.evr
NM5_msk_vol
Other
​
ANTs
geometry/volume
​
nm5.msk.vol
NM5_spc0
Other
​
ANTs
​
​
nm5.spc0
NM5_spc1
Other
​
ANTs
​
​
nm5.spc1
NM5_spc2
Other
​
ANTs
​
​
nm5.spc2
NM5_org0
Other
​
ANTs
​
​
nm5.org0
NM5_org1
Other
​
ANTs
​
​
nm5.org1
NM5_org2
Other
​
ANTs
​
​
nm5.org2
NM5_dimx
Other
​
ANTs
​
​
nm5.dimx
NM5_dimy
Other
​
ANTs
​
​
nm5.dimy
NM5_dimz
Other
​
ANTs
​
​
nm5.dimz
NM5_dimt
Other
​
ANTs
​
​
nm5.dimt
NM5_slice
Other
​
ANTs
slice number in time series (ignore)
​
nm5.slice
NM5_modality
Other
​
ANTs
​
​
nm5.modality
NM5_mriseries
Other
​
ANTs
​
​
nm5.mriseries
NM5_mriSAR
Other
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
nm5.mrisar
NM5_mriPixelBandwidth
Other
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
nm5.mripixelbandwidth
NM5_mriPixelBandwidthPE
Other
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
nm5.mripixelbandwidthpe
NM5_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
nm5.dti.bvaluemax
NM5_dti_bvecnorm
Other
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
nm5.dti.bvecnorm
NM5_ol_loop
Other
​
ANTs
QC
​
nm5.ol.loop
NM5_ol_lof
Other
​
ANTs
QC
​
nm5.ol.lof
NM5_ol_lof_decision
Other
​
ANTs
QC
​
nm5.ol.lof.decision
nmid5
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmid5
NM5_negol
Other
​
ANTs
​
​
nm5.negol
NM5_score_ol_loop
Other
​
ANTs
QC
​
nm5.score.ol.loop
NM5_score_noise
Other
​
ANTs
QC
​
nm5.score.noise
NM5_score_snr
Other
​
ANTs
QC
​
nm5.score.snr
NM5_score_EVR
Other
​
ANTs
​
​
nm5.score.evr
NM5_score_reflection_err
Other
​
ANTs
​
​
nm5.score.reflection.err
NM5_best_score
Other
​
ANTs
​
​
nm5.best.score
NM6_filename
Other
​
ANTs
​
​
nm6.filename
NM6_dimensionality
Other
​
ANTs
​
​
nm6.dimensionality
NM6_noise
Other
​
ANTs
QC
​
nm6.noise
NM6_snr
Other
​
ANTs
QC
​
nm6.snr
NM6_cnr
Other
​
ANTs
QC
​
nm6.cnr
NM6_psnr
Other
​
ANTs
QC
​
nm6.psnr
NM6_ssim
Other
​
ANTs
QC
​
nm6.ssim
NM6_mi
Other
​
ANTs
​
​
nm6.mi
NM6_reflection_err
Other
​
ANTs
​
​
nm6.reflection.err
NM6_EVR
Other
​
ANTs
​
​
nm6.evr
NM6_msk_vol
Other
​
ANTs
geometry/volume
​
nm6.msk.vol
NM6_spc0
Other
​
ANTs
​
​
nm6.spc0
NM6_spc1
Other
​
ANTs
​
​
nm6.spc1
NM6_spc2
Other
​
ANTs
​
​
nm6.spc2
NM6_org0
Other
​
ANTs
​
​
nm6.org0
NM6_org1
Other
​
ANTs
​
​
nm6.org1
NM6_org2
Other
​
ANTs
​
​
nm6.org2
NM6_dimx
Other
​
ANTs
​
​
nm6.dimx
NM6_dimy
Other
​
ANTs
​
​
nm6.dimy
NM6_dimz
Other
​
ANTs
​
​
nm6.dimz
NM6_dimt
Other
​
ANTs
​
​
nm6.dimt
NM6_slice
Other
​
ANTs
slice number in time series (ignore)
​
nm6.slice
NM6_modality
Other
​
ANTs
​
​
nm6.modality
NM6_mriseries
Other
​
ANTs
​
​
nm6.mriseries
NM6_mriSAR
Other
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
nm6.mrisar
NM6_mriPixelBandwidth
Other
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
nm6.mripixelbandwidth
NM6_mriPixelBandwidthPE
Other
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
nm6.mripixelbandwidthpe
NM6_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
nm6.dti.bvaluemax
NM6_dti_bvecnorm
Other
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
nm6.dti.bvecnorm
NM6_ol_loop
Other
​
ANTs
QC
​
nm6.ol.loop
NM6_ol_lof
Other
​
ANTs
QC
​
nm6.ol.lof
NM6_ol_lof_decision
Other
​
ANTs
QC
​
nm6.ol.lof.decision
NM6_imageID
Other
​
ANTs
​
​
nm6.imageid
NM6_negol
Other
​
ANTs
​
​
nm6.negol
NM6_score_ol_loop
Other
​
ANTs
QC
​
nm6.score.ol.loop
NM6_score_noise
Other
​
ANTs
QC
​
nm6.score.noise
NM6_score_snr
Other
​
ANTs
QC
​
nm6.score.snr
NM6_score_EVR
Other
​
ANTs
​
​
nm6.score.evr
NM6_score_reflection_err
Other
​
ANTs
​
​
nm6.score.reflection.err
NM6_best_score
Other
​
ANTs
​
​
nm6.best.score
dtfn1
Other
​
ANTs
original source data filename
​
dtfn1
DTI1_dimensionality
DTI
​
ANTs
​
​
dti1.dimensionality
DTI1_noise
DTI
​
ANTs
QC
​
dti1.noise
DTI1_snr
DTI
​
ANTs
QC
​
dti1.snr
DTI1_cnr
DTI
​
ANTs
QC
​
dti1.cnr
DTI1_psnr
DTI
​
ANTs
QC
​
dti1.psnr
DTI1_ssim
DTI
​
ANTs
QC
​
dti1.ssim
DTI1_mi
DTI
​
ANTs
​
​
dti1.mi
DTI1_reflection_err
DTI
​
ANTs
​
​
dti1.reflection.err
DTI1_EVR
DTI
​
ANTs
​
​
dti1.evr
DTI1_msk_vol
DTI
​
ANTs
geometry/volume
​
dti1.msk.vol
DTI1_spc0
DTI
​
ANTs
​
​
dti1.spc0
DTI1_spc1
DTI
​
ANTs
​
​
dti1.spc1
DTI1_spc2
DTI
​
ANTs
​
​
dti1.spc2
DTI1_org0
DTI
​
ANTs
​
​
dti1.org0
DTI1_org1
DTI
​
ANTs
​
​
dti1.org1
DTI1_org2
DTI
​
ANTs
​
​
dti1.org2
DTI1_dimx
DTI
​
ANTs
​
​
dti1.dimx
DTI1_dimy
DTI
​
ANTs
​
​
dti1.dimy
DTI1_dimz
DTI
​
ANTs
​
​
dti1.dimz
DTI1_dimt
DTI
​
ANTs
​
​
dti1.dimt
DTI1_slice
DTI
​
ANTs
slice number in time series (ignore)
​
dti1.slice
DTI1_modality
DTI
​
ANTs
​
​
dti1.modality
DTI1_mriseries
DTI
​
ANTs
​
​
dti1.mriseries
DTI1_mriSAR
DTI
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
dti1.mrisar
DTI1_mriPixelBandwidth
DTI
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
dti1.mripixelbandwidth
DTI1_mriPixelBandwidthPE
DTI
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
dti1.mripixelbandwidthpe
DTI1_dti_bvalueMax
DTI
​
ANTs
MRI DTI maximum bvalue (often missing)
​
dti1.dti.bvaluemax
DTI1_dti_bvecnorm
DTI
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
dti1.dti.bvecnorm
DTI1_ol_loop
DTI
​
ANTs
QC
​
dti1.ol.loop
DTI1_ol_lof
DTI
​
ANTs
QC
​
dti1.ol.lof
DTI1_ol_lof_decision
DTI
​
ANTs
QC
​
dti1.ol.lof.decision
dtid1
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
dtid1
DTI1_negol
DTI
​
ANTs
​
​
dti1.negol
DTI1_score_ol_loop
DTI
​
ANTs
QC
​
dti1.score.ol.loop
DTI1_score_noise
DTI
​
ANTs
QC
​
dti1.score.noise
DTI1_score_dti_bvalueMax
DTI
​
ANTs
MRI DTI maximum bvalue (often missing)
​
dti1.score.dti.bvaluemax
DTI1_score_dimt
DTI
​
ANTs
​
​
dti1.score.dimt
DTI1_best_score
DTI
​
ANTs
​
​
dti1.best.score
dtfn2
Other
​
ANTs
original source data filename
​
dtfn2
DTI2_dimensionality
DTI
​
ANTs
​
​
dti2.dimensionality
DTI2_noise
DTI
​
ANTs
QC
​
dti2.noise
DTI2_snr
DTI
​
ANTs
QC
​
dti2.snr
DTI2_cnr
DTI
​
ANTs
QC
​
dti2.cnr
DTI2_psnr
DTI
​
ANTs
QC
​
dti2.psnr
DTI2_ssim
DTI
​
ANTs
QC
​
dti2.ssim
DTI2_mi
DTI
​
ANTs
​
​
dti2.mi
DTI2_reflection_err
DTI
​
ANTs
​
​
dti2.reflection.err
DTI2_EVR
DTI
​
ANTs
​
​
dti2.evr
DTI2_msk_vol
DTI
​
ANTs
geometry/volume
​
dti2.msk.vol
DTI2_spc0
DTI
​
ANTs
​
​
dti2.spc0
DTI2_spc1
DTI
​
ANTs
​
​
dti2.spc1
DTI2_spc2
DTI
​
ANTs
​
​
dti2.spc2
DTI2_org0
DTI
​
ANTs
​
​
dti2.org0
DTI2_org1
DTI
​
ANTs
​
​
dti2.org1
DTI2_org2
DTI
​
ANTs
​
​
dti2.org2
DTI2_dimx
DTI
​
ANTs
​
​
dti2.dimx
DTI2_dimy
DTI
​
ANTs
​
​
dti2.dimy
DTI2_dimz
DTI
​
ANTs
​
​
dti2.dimz
DTI2_dimt
DTI
​
ANTs
​
​
dti2.dimt
DTI2_slice
DTI
​
ANTs
slice number in time series (ignore)
​
dti2.slice
DTI2_modality
DTI
​
ANTs
​
​
dti2.modality
DTI2_mriseries
DTI
​
ANTs
​
​
dti2.mriseries
DTI2_mriSAR
DTI
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
dti2.mrisar
DTI2_mriPixelBandwidth
DTI
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
dti2.mripixelbandwidth
DTI2_mriPixelBandwidthPE
DTI
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
dti2.mripixelbandwidthpe
DTI2_dti_bvalueMax
DTI
​
ANTs
MRI DTI maximum bvalue (often missing)
​
dti2.dti.bvaluemax
DTI2_dti_bvecnorm
DTI
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
dti2.dti.bvecnorm
DTI2_ol_loop
DTI
​
ANTs
QC
​
dti2.ol.loop
DTI2_ol_lof
DTI
​
ANTs
QC
​
dti2.ol.lof
DTI2_ol_lof_decision
DTI
​
ANTs
QC
​
dti2.ol.lof.decision
dtid2
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
dtid2
DTI2_negol
DTI
​
ANTs
​
​
dti2.negol
DTI2_score_ol_loop
DTI
​
ANTs
QC
​
dti2.score.ol.loop
DTI2_score_noise
DTI
​
ANTs
QC
​
dti2.score.noise
DTI2_score_dti_bvalueMax
DTI
​
ANTs
MRI DTI maximum bvalue (often missing)
​
dti2.score.dti.bvaluemax
DTI2_score_dimt
DTI
​
ANTs
​
​
dti2.score.dimt
DTI2_best_score
DTI
​
ANTs
​
​
dti2.best.score
dtfn3
Other
​
ANTs
original source data filename
​
dtfn3
DTI3_dimensionality
DTI
​
ANTs
​
​
dti3.dimensionality
DTI3_noise
DTI
​
ANTs
QC
​
dti3.noise
DTI3_snr
DTI
​
ANTs
QC
​
dti3.snr
DTI3_cnr
DTI
​
ANTs
QC
​
dti3.cnr
DTI3_psnr
DTI
​
ANTs
QC
​
dti3.psnr
DTI3_ssim
DTI
​
ANTs
QC
​
dti3.ssim
DTI3_mi
DTI
​
ANTs
​
​
dti3.mi
DTI3_reflection_err
DTI
​
ANTs
​
​
dti3.reflection.err
DTI3_EVR
DTI
​
ANTs
​
​
dti3.evr
DTI3_msk_vol
DTI
​
ANTs
geometry/volume
​
dti3.msk.vol
DTI3_spc0
DTI
​
ANTs
​
​
dti3.spc0
DTI3_spc1
DTI
​
ANTs
​
​
dti3.spc1
DTI3_spc2
DTI
​
ANTs
​
​
dti3.spc2
DTI3_org0
DTI
​
ANTs
​
​
dti3.org0
DTI3_org1
DTI
​
ANTs
​
​
dti3.org1
DTI3_org2
DTI
​
ANTs
​
​
dti3.org2
DTI3_dimx
DTI
​
ANTs
​
​
dti3.dimx
DTI3_dimy
DTI
​
ANTs
​
​
dti3.dimy
DTI3_dimz
DTI
​
ANTs
​
​
dti3.dimz
DTI3_dimt
DTI
​
ANTs
​
​
dti3.dimt
DTI3_slice
DTI
​
ANTs
slice number in time series (ignore)
​
dti3.slice
DTI3_modality
DTI
​
ANTs
​
​
dti3.modality
DTI3_mriseries
DTI
​
ANTs
​
​
dti3.mriseries
DTI3_mriSAR
DTI
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
dti3.mrisar
DTI3_mriPixelBandwidth
DTI
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
dti3.mripixelbandwidth
DTI3_mriPixelBandwidthPE
DTI
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
dti3.mripixelbandwidthpe
DTI3_dti_bvalueMax
DTI
​
ANTs
MRI DTI maximum bvalue (often missing)
​
dti3.dti.bvaluemax
DTI3_dti_bvecnorm
DTI
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
dti3.dti.bvecnorm
DTI3_ol_loop
DTI
​
ANTs
QC
​
dti3.ol.loop
DTI3_ol_lof
DTI
​
ANTs
QC
​
dti3.ol.lof
DTI3_ol_lof_decision
DTI
​
ANTs
QC
​
dti3.ol.lof.decision
dtid3
Other
​
ANTs
​
​
dtid3
DTI3_negol
DTI
​
ANTs
​
​
dti3.negol
DTI3_score_ol_loop
DTI
​
ANTs
QC
​
dti3.score.ol.loop
DTI3_score_noise
DTI
​
ANTs
QC
​
dti3.score.noise
DTI3_score_dti_bvalueMax
DTI
​
ANTs
MRI DTI maximum bvalue (often missing)
​
dti3.score.dti.bvaluemax
DTI3_score_dimt
DTI
​
ANTs
​
​
dti3.score.dimt
DTI3_best_score
DTI
​
ANTs
​
​
dti3.best.score
rsffn1
Other
​
ANTs
original source data filename
​
rsffn1
rsf1_dimensionality
Other
​
ANTs
​
​
rsf1.dimensionality
rsf1_noise
Other
​
ANTs
QC
​
rsf1.noise
rsf1_snr
Other
​
ANTs
QC
​
rsf1.snr
rsf1_cnr
Other
​
ANTs
QC
​
rsf1.cnr
rsf1_psnr
Other
​
ANTs
QC
​
rsf1.psnr
rsf1_ssim
Other
​
ANTs
QC
​
rsf1.ssim
rsf1_mi
Other
​
ANTs
​
​
rsf1.mi
rsf1_reflection_err
Other
​
ANTs
​
​
rsf1.reflection.err
rsf1_EVR
Other
​
ANTs
​
​
rsf1.evr
rsf1_msk_vol
Other
​
ANTs
geometry/volume
​
rsf1.msk.vol
rsf1_spc0
Other
​
ANTs
​
​
rsf1.spc0
rsf1_spc1
Other
​
ANTs
​
​
rsf1.spc1
rsf1_spc2
Other
​
ANTs
​
​
rsf1.spc2
rsf1_org0
Other
​
ANTs
​
​
rsf1.org0
rsf1_org1
Other
​
ANTs
​
​
rsf1.org1
rsf1_org2
Other
​
ANTs
​
​
rsf1.org2
rsf1_dimx
Other
​
ANTs
​
​
rsf1.dimx
rsf1_dimy
Other
​
ANTs
​
​
rsf1.dimy
rsf1_dimz
Other
​
ANTs
​
​
rsf1.dimz
rsf1_dimt
Other
​
ANTs
​
​
rsf1.dimt
rsf1_slice
Other
​
ANTs
slice number in time series (ignore)
​
rsf1.slice
rsf1_modality
Other
​
ANTs
​
​
rsf1.modality
rsf1_mriseries
Other
​
ANTs
​
​
rsf1.mriseries
rsf1_mriSAR
Other
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
rsf1.mrisar
rsf1_mriPixelBandwidth
Other
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
rsf1.mripixelbandwidth
rsf1_mriPixelBandwidthPE
Other
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
rsf1.mripixelbandwidthpe
rsf1_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
rsf1.dti.bvaluemax
rsf1_dti_bvecnorm
Other
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
rsf1.dti.bvecnorm
rsf1_ol_loop
Other
​
ANTs
QC
​
rsf1.ol.loop
rsf1_ol_lof
Other
​
ANTs
QC
​
rsf1.ol.lof
rsf1_ol_lof_decision
Other
​
ANTs
QC
​
rsf1.ol.lof.decision
rsfid1
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
rsfid1
rsf1_negol
Other
​
ANTs
​
​
rsf1.negol
rsf1_score_ol_loop
Other
​
ANTs
QC
​
rsf1.score.ol.loop
rsf1_score_noise
Other
​
ANTs
QC
​
rsf1.score.noise
rsf1_score_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
rsf1.score.dti.bvaluemax
rsf1_score_dimt
Other
​
ANTs
​
​
rsf1.score.dimt
rsf1_best_score
Other
​
ANTs
​
​
rsf1.best.score
rsffn2
Other
​
ANTs
original source data filename
​
rsffn2
rsf2_dimensionality
Other
​
ANTs
​
​
rsf2.dimensionality
rsf2_noise
Other
​
ANTs
QC
​
rsf2.noise
rsf2_snr
Other
​
ANTs
QC
​
rsf2.snr
rsf2_cnr
Other
​
ANTs
QC
​
rsf2.cnr
rsf2_psnr
Other
​
ANTs
QC
​
rsf2.psnr
rsf2_ssim
Other
​
ANTs
QC
​
rsf2.ssim
rsf2_mi
Other
​
ANTs
​
​
rsf2.mi
rsf2_reflection_err
Other
​
ANTs
​
​
rsf2.reflection.err
rsf2_EVR
Other
​
ANTs
​
​
rsf2.evr
rsf2_msk_vol
Other
​
ANTs
geometry/volume
​
rsf2.msk.vol
rsf2_spc0
Other
​
ANTs
​
​
rsf2.spc0
rsf2_spc1
Other
​
ANTs
​
​
rsf2.spc1
rsf2_spc2
Other
​
ANTs
​
​
rsf2.spc2
rsf2_org0
Other
​
ANTs
​
​
rsf2.org0
rsf2_org1
Other
​
ANTs
​
​
rsf2.org1
rsf2_org2
Other
​
ANTs
​
​
rsf2.org2
rsf2_dimx
Other
​
ANTs
​
​
rsf2.dimx
rsf2_dimy
Other
​
ANTs
​
​
rsf2.dimy
rsf2_dimz
Other
​
ANTs
​
​
rsf2.dimz
rsf2_dimt
Other
​
ANTs
​
​
rsf2.dimt
rsf2_slice
Other
​
ANTs
slice number in time series (ignore)
​
rsf2.slice
rsf2_modality
Other
​
ANTs
​
​
rsf2.modality
rsf2_mriseries
Other
​
ANTs
​
​
rsf2.mriseries
rsf2_mriSAR
Other
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
rsf2.mrisar
rsf2_mriPixelBandwidth
Other
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
rsf2.mripixelbandwidth
rsf2_mriPixelBandwidthPE
Other
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
rsf2.mripixelbandwidthpe
rsf2_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
rsf2.dti.bvaluemax
rsf2_dti_bvecnorm
Other
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
rsf2.dti.bvecnorm
rsf2_ol_loop
Other
​
ANTs
QC
​
rsf2.ol.loop
rsf2_ol_lof
Other
​
ANTs
QC
​
rsf2.ol.lof
rsf2_ol_lof_decision
Other
​
ANTs
QC
​
rsf2.ol.lof.decision
rsfid2
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
rsfid2
rsf2_negol
Other
​
ANTs
​
​
rsf2.negol
rsf2_score_ol_loop
Other
​
ANTs
QC
​
rsf2.score.ol.loop
rsf2_score_noise
Other
​
ANTs
QC
​
rsf2.score.noise
rsf2_score_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
rsf2.score.dti.bvaluemax
rsf2_score_dimt
Other
​
ANTs
​
​
rsf2.score.dimt
rsf2_best_score
Other
​
ANTs
​
​
rsf2.best.score
rsf3_filename
Other
​
ANTs
​
​
rsf3.filename
rsf3_dimensionality
Other
​
ANTs
​
​
rsf3.dimensionality
rsf3_noise
Other
​
ANTs
QC
​
rsf3.noise
rsf3_snr
Other
​
ANTs
QC
​
rsf3.snr
rsf3_cnr
Other
​
ANTs
QC
​
rsf3.cnr
rsf3_psnr
Other
​
ANTs
QC
​
rsf3.psnr
rsf3_ssim
Other
​
ANTs
QC
​
rsf3.ssim
rsf3_mi
Other
​
ANTs
​
​
rsf3.mi
rsf3_reflection_err
Other
​
ANTs
​
​
rsf3.reflection.err
rsf3_EVR
Other
​
ANTs
​
​
rsf3.evr
rsf3_msk_vol
Other
​
ANTs
geometry/volume
​
rsf3.msk.vol
rsf3_spc0
Other
​
ANTs
​
​
rsf3.spc0
rsf3_spc1
Other
​
ANTs
​
​
rsf3.spc1
rsf3_spc2
Other
​
ANTs
​
​
rsf3.spc2
rsf3_org0
Other
​
ANTs
​
​
rsf3.org0
rsf3_org1
Other
​
ANTs
​
​
rsf3.org1
rsf3_org2
Other
​
ANTs
​
​
rsf3.org2
rsf3_dimx
Other
​
ANTs
​
​
rsf3.dimx
rsf3_dimy
Other
​
ANTs
​
​
rsf3.dimy
rsf3_dimz
Other
​
ANTs
​
​
rsf3.dimz
rsf3_dimt
Other
​
ANTs
​
​
rsf3.dimt
rsf3_slice
Other
​
ANTs
slice number in time series (ignore)
​
rsf3.slice
rsf3_modality
Other
​
ANTs
​
​
rsf3.modality
rsf3_mriseries
Other
​
ANTs
​
​
rsf3.mriseries
rsf3_mriSAR
Other
​
ANTs
MRI Specific Absorption Rate is a measure of the rate at which energy is absorbed by the body when exposed to a radiofrequency (RF) electromagnetic field (often missing)
​
rsf3.mrisar
rsf3_mriPixelBandwidth
Other
​
ANTs
MRI range of frequencies encoded in each pixel of an image (often missing)
​
rsf3.mripixelbandwidth
rsf3_mriPixelBandwidthPE
Other
​
ANTs
MRI Pixel bandwidth in the phase encoding (PE) direction (often missing)
​
rsf3.mripixelbandwidthpe
rsf3_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
rsf3.dti.bvaluemax
rsf3_dti_bvecnorm
Other
​
ANTs
MRI DTI bvec norm (usually close to 1, often missing)
​
rsf3.dti.bvecnorm
rsf3_ol_loop
Other
​
ANTs
QC
​
rsf3.ol.loop
rsf3_ol_lof
Other
​
ANTs
QC
​
rsf3.ol.lof
rsf3_ol_lof_decision
Other
​
ANTs
QC
​
rsf3.ol.lof.decision
rsf3_imageID
Other
​
ANTs
​
​
rsf3.imageid
rsf3_negol
Other
​
ANTs
​
​
rsf3.negol
rsf3_score_ol_loop
Other
​
ANTs
QC
​
rsf3.score.ol.loop
rsf3_score_noise
Other
​
ANTs
QC
​
rsf3.score.noise
rsf3_score_dti_bvalueMax
Other
​
ANTs
MRI DTI maximum bvalue (often missing)
​
rsf3.score.dti.bvaluemax
rsf3_score_dimt
Other
​
ANTs
​
​
rsf3.score.dimt
rsf3_best_score
Other
​
ANTs
​
​
rsf3.best.score
projectID
Other
​
ANTs
project ID or name eg ADNI
​
projectid
perfid
Other
​
ANTs
​
​
perfid
T1Hier_u_hier_id
unique id
unique id
unique id
unique id
unique id
t1.u.hier.id
T1Hier_u_hier_id.1
unique id
unique id
unique id
unique id
unique id
t1.u.hier.id.1
T1Hier_vol_hemisphere_lefthemispheres
T1 hierarchical processing
left
ANTs
geometry/volume
vol hemisphere hemispheres
t1.vol.hemisphere.lefthemispheres
T1Hier_vol_hemisphere_righthemispheres
T1 hierarchical processing
right
ANTs
geometry/volume
vol hemisphere hemispheres
t1.vol.hemisphere.righthemispheres
T1Hier_area_hemisphere_lefthemispheres
T1 hierarchical processing
left
ANTs
geometry/area
hemisphere hemispheres
t1.area.hemisphere.lefthemispheres
T1Hier_area_hemisphere_righthemispheres
T1 hierarchical processing
right
ANTs
geometry/area
hemisphere hemispheres
t1.area.hemisphere.righthemispheres
T1Hier_thk_hemisphere_lefthemispheres
T1 hierarchical processing
left
ANTs
geometry/thickness
hemisphere hemispheres
t1.thk.hemisphere.lefthemispheres
T1Hier_thk_hemisphere_righthemispheres
T1 hierarchical processing
right
ANTs
geometry/thickness
hemisphere hemispheres
t1.thk.hemisphere.righthemispheres
T1Hier_vol_brainstemtissues
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.bsttissues
T1Hier_vol_csftissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol csftissues
t1.vol.csftissues
T1Hier_vol_cerebellumtissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol cerebellumtissues
t1.vol.cerebellumtissues
T1Hier_vol_deepgraytissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol deepgraytissues
t1.vol.deepgraytissues
T1Hier_vol_gmtissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol gmtissues
t1.vol.gmtissues
T1Hier_vol_wmtissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol wmtissues
t1.vol.wmtissues
T1Hier_area_brainstemtissues
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.bsttissues
T1Hier_area_csftissues
T1 hierarchical processing
​
ANTs
geometry/area
csftissues
t1.area.csftissues
T1Hier_area_cerebellumtissues
T1 hierarchical processing
​
ANTs
geometry/area
cerebellumtissues
t1.area.cerebellumtissues
T1Hier_area_deepgraytissues
T1 hierarchical processing
​
ANTs
geometry/area
deepgraytissues
t1.area.deepgraytissues
T1Hier_area_gmtissues
T1 hierarchical processing
​
ANTs
geometry/area
gmtissues
t1.area.gmtissues
T1Hier_area_wmtissues
T1 hierarchical processing
​
ANTs
geometry/area
wmtissues
t1.area.wmtissues
T1Hier_thk_brainstemtissues
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.bsttissues
T1Hier_thk_csftissues
T1 hierarchical processing
​
ANTs
geometry/thickness
csftissues
t1.thk.csftissues
T1Hier_thk_cerebellumtissues
T1 hierarchical processing
​
ANTs
geometry/thickness
cerebellumtissues
t1.thk.cerebellumtissues
T1Hier_thk_deepgraytissues
T1 hierarchical processing
​
ANTs
geometry/thickness
deepgraytissues
t1.thk.deepgraytissues
T1Hier_thk_gmtissues
T1 hierarchical processing
​
ANTs
geometry/thickness
gmtissues
t1.thk.gmtissues
T1Hier_thk_wmtissues
T1 hierarchical processing
​
ANTs
geometry/thickness
wmtissues
t1.thk.wmtissues
T1Hier_vol_brainstem_ldktlobes
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.bst.ldktlobes
T1Hier_vol_brainstem_rdktlobes
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.bst.rdktlobes
T1Hier_vol_cerebellum_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol cerebellum ldktlobes
t1.vol.cerebellum.ldktlobes
T1Hier_vol_cerebellum_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol cerebellum rdktlobes
t1.vol.cerebellum.rdktlobes
T1Hier_vol_frontal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol frontal ldktlobes
t1.vol.frontal.ldktlobes
T1Hier_vol_frontal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol frontal rdktlobes
t1.vol.frontal.rdktlobes
T1Hier_vol_occipital_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol occipital ldktlobes
t1.vol.occipital.ldktlobes
T1Hier_vol_occipital_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol occipital rdktlobes
t1.vol.occipital.rdktlobes
T1Hier_vol_parietal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol parietal ldktlobes
t1.vol.parietal.ldktlobes
T1Hier_vol_parietal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol parietal rdktlobes
t1.vol.parietal.rdktlobes
T1Hier_vol_temporal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol temporal ldktlobes
t1.vol.temporal.ldktlobes
T1Hier_vol_temporal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol temporal rdktlobes
t1.vol.temporal.rdktlobes
T1Hier_area_brainstem_ldktlobes
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.bst.ldktlobes
T1Hier_area_brainstem_rdktlobes
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.bst.rdktlobes
T1Hier_area_cerebellum_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellum ldktlobes
t1.area.cerebellum.ldktlobes
T1Hier_area_cerebellum_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellum rdktlobes
t1.area.cerebellum.rdktlobes
T1Hier_area_frontal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
frontal ldktlobes
t1.area.frontal.ldktlobes
T1Hier_area_frontal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
frontal rdktlobes
t1.area.frontal.rdktlobes
T1Hier_area_occipital_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
occipital ldktlobes
t1.area.occipital.ldktlobes
T1Hier_area_occipital_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
occipital rdktlobes
t1.area.occipital.rdktlobes
T1Hier_area_parietal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
parietal ldktlobes
t1.area.parietal.ldktlobes
T1Hier_area_parietal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
parietal rdktlobes
t1.area.parietal.rdktlobes
T1Hier_area_temporal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
temporal ldktlobes
t1.area.temporal.ldktlobes
T1Hier_area_temporal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
temporal rdktlobes
t1.area.temporal.rdktlobes
T1Hier_thk_brainstem_ldktlobes
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.bst.ldktlobes
T1Hier_thk_brainstem_rdktlobes
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.bst.rdktlobes
T1Hier_thk_cerebellum_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellum ldktlobes
t1.thk.cerebellum.ldktlobes
T1Hier_thk_cerebellum_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellum rdktlobes
t1.thk.cerebellum.rdktlobes
T1Hier_thk_frontal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
frontal ldktlobes
t1.thk.frontal.ldktlobes
T1Hier_thk_frontal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
frontal rdktlobes
t1.thk.frontal.rdktlobes
T1Hier_thk_occipital_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
occipital ldktlobes
t1.thk.occipital.ldktlobes
T1Hier_thk_occipital_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
occipital rdktlobes
t1.thk.occipital.rdktlobes
T1Hier_thk_parietal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
parietal ldktlobes
t1.thk.parietal.ldktlobes
T1Hier_thk_parietal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
parietal rdktlobes
t1.thk.parietal.rdktlobes
T1Hier_thk_temporal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
temporal ldktlobes
t1.thk.temporal.ldktlobes
T1Hier_thk_temporal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
temporal rdktlobes
t1.thk.temporal.rdktlobes
T1Hier_vol_4th_ventricledktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
4th ventricle
t1.vol.4th.ventricledktregions
T1Hier_vol_csfdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol csf
t1.vol.csfdktregions
T1Hier_vol_brain_stemdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
brain stem
t1.vol.brain.stemdktregions
T1Hier_vol_cerebellar_vermal_lobules_i.vdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol cerebellar vermal lobules i v
t1.vol.cerebellar.vermal.lobules.i.vdktregions
T1Hier_vol_cerebellar_vermal_lobules_vi.viidktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol cerebellar vermal lobules vi vii
t1.vol.cerebellar.vermal.lobules.vi.viidktregions
T1Hier_vol_cerebellar_vermal_lobules_viii.xdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol cerebellar vermal lobules viii x
t1.vol.cerebellar.vermal.lobules.viii.xdktregions
T1Hier_vol_left_amygdaladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
amygdala
t1.vol.left.amygdaladktregions
T1Hier_vol_left_caudal_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
t1.vol.left.caudal.ant.cingulatedktregions
T1Hier_vol_left_caudal_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
t1.vol.left.caudal.middle.frontaldktregions
T1Hier_vol_left_caudatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudate
t1.vol.left.caudatedktregions
T1Hier_vol_left_cerebellem_exteriordktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cerebellem exterior
t1.vol.left.cerebellem.exteriordktregions
T1Hier_vol_left_cerebellum_white_matterdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cerebellum white matter
t1.vol.left.cerebellum.white.matterdktregions
T1Hier_vol_left_cuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cuneus
t1.vol.left.cuneusdktregions
T1Hier_vol_left_entorhinaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
entorhinal
t1.vol.left.entorhinaldktregions
T1Hier_vol_left_fusiformdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
fusiform
t1.vol.left.fusiformdktregions
T1Hier_vol_left_hippocampusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
hippocampus
t1.vol.left.hippocampusdktregions
T1Hier_vol_left_inferior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior parietal
t1.vol.left.inf.parietaldktregions
T1Hier_vol_left_inferior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior temporal
t1.vol.left.inf.temporaldktregions
T1Hier_vol_left_insuladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
insula
t1.vol.left.insuladktregions
T1Hier_vol_left_isthmus_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
t1.vol.left.isthmus.cingulatedktregions
T1Hier_vol_left_lateral_occipitaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral occipital
t1.vol.left.lateral.occipitaldktregions
T1Hier_vol_left_lateral_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
t1.vol.left.lateral.orbitofrontaldktregions
T1Hier_vol_left_lateral_ventricledktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral ventricle
t1.vol.left.lateral.ventricledktregions
T1Hier_vol_left_lingualdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lingual
t1.vol.left.lingualdktregions
T1Hier_vol_left_medial_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
t1.vol.left.medial.orbitofrontaldktregions
T1Hier_vol_left_middle_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
middle temporal
t1.vol.left.middle.temporaldktregions
T1Hier_vol_left_pallidiumdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pallidium
t1.vol.left.pallidiumdktregions
T1Hier_vol_left_paracentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
paracentral
t1.vol.left.paracentdktregions
T1Hier_vol_left_parahippocampaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.left.parahippocampaldktregions
T1Hier_vol_left_pars_opercularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars opercularis
t1.vol.left.pars.opercularisdktregions
T1Hier_vol_left_pars_orbitalisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
t1.vol.left.pars.orbitalisdktregions
T1Hier_vol_left_pars_triangularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars triangularis
t1.vol.left.pars.triangularisdktregions
T1Hier_vol_left_pericalcarinedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pericalcarine
t1.vol.left.pericalcarinedktregions
T1Hier_vol_left_postcentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
postcentral
t1.vol.left.postcentdktregions
T1Hier_vol_left_posterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
t1.vol.left.post.cingulatedktregions
T1Hier_vol_left_precentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precentral
t1.vol.left.precentdktregions
T1Hier_vol_left_precuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precuneus
t1.vol.left.precuneusdktregions
T1Hier_vol_left_putamendktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
putamen
t1.vol.left.putamendktregions
T1Hier_vol_left_rostral_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
t1.vol.left.rostral.ant.cingulatedktregions
T1Hier_vol_left_rostral_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
t1.vol.left.rostral.middle.frontaldktregions
T1Hier_vol_left_superior_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior frontal
t1.vol.left.sup.frontaldktregions
T1Hier_vol_left_superior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior parietal
t1.vol.left.sup.parietaldktregions
T1Hier_vol_left_superior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior temporal
t1.vol.left.sup.temporaldktregions
T1Hier_vol_left_supramarginaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
supramarginal
t1.vol.left.supramarginaldktregions
T1Hier_vol_left_thalamus_properdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
thalamus proper
t1.vol.left.thalamus.properdktregions
T1Hier_vol_left_transverse_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
transverse temporal
t1.vol.left.transverse.temporaldktregions
T1Hier_vol_left_ventral_dcdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
volventral dc
t1.vol.left.ventral.dcdktregions
T1Hier_vol_right_amygdaladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
amygdala
t1.vol.right.amygdaladktregions
T1Hier_vol_right_caudal_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
t1.vol.right.caudal.ant.cingulatedktregions
T1Hier_vol_right_caudal_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
t1.vol.right.caudal.middle.frontaldktregions
T1Hier_vol_right_caudatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudate
t1.vol.right.caudatedktregions
T1Hier_vol_right_cerebellum_exteriordktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cerebellum exterior
t1.vol.right.cerebellum.exteriordktregions
T1Hier_vol_right_cerebellum_white_matterdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cerebellum white matter
t1.vol.right.cerebellum.white.matterdktregions
T1Hier_vol_right_cuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cuneus
t1.vol.right.cuneusdktregions
T1Hier_vol_right_entorhinaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
entorhinal
t1.vol.right.entorhinaldktregions
T1Hier_vol_right_fusiformdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
fusiform
t1.vol.right.fusiformdktregions
T1Hier_vol_right_hippocampusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
hippocampus
t1.vol.right.hippocampusdktregions
T1Hier_vol_right_inferior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior parietal
t1.vol.right.inf.parietaldktregions
T1Hier_vol_right_inferior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior temporal
t1.vol.right.inf.temporaldktregions
T1Hier_vol_right_insuladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
insula
t1.vol.right.insuladktregions
T1Hier_vol_right_isthmus_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
t1.vol.right.isthmus.cingulatedktregions
T1Hier_vol_right_lateral_occipitaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral occipital
t1.vol.right.lateral.occipitaldktregions
T1Hier_vol_right_lateral_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
t1.vol.right.lateral.orbitofrontaldktregions
T1Hier_vol_right_lateral_ventricledktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral ventricle
t1.vol.right.lateral.ventricledktregions
T1Hier_vol_right_lingualdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lingual
t1.vol.right.lingualdktregions
T1Hier_vol_right_medial_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
t1.vol.right.medial.orbitofrontaldktregions
T1Hier_vol_right_middle_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
middle temporal
t1.vol.right.middle.temporaldktregions
T1Hier_vol_right_palladiumdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
palladium
t1.vol.right.palladiumdktregions
T1Hier_vol_right_paracentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
paracentral
t1.vol.right.paracentdktregions
T1Hier_vol_right_parahippocampaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.right.parahippocampaldktregions
T1Hier_vol_right_pars_opercularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars opercularis
t1.vol.right.pars.opercularisdktregions
T1Hier_vol_right_pars_orbitalisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
t1.vol.right.pars.orbitalisdktregions
T1Hier_vol_right_pars_triangularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars triangularis
t1.vol.right.pars.triangularisdktregions
T1Hier_vol_right_pericalcarinedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pericalcarine
t1.vol.right.pericalcarinedktregions
T1Hier_vol_right_postcentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
postcentral
t1.vol.right.postcentdktregions
T1Hier_vol_right_posterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
t1.vol.right.post.cingulatedktregions
T1Hier_vol_right_precentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precentral
t1.vol.right.precentdktregions
T1Hier_vol_right_precuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precuneus
t1.vol.right.precuneusdktregions
T1Hier_vol_right_putamendktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
putamen
t1.vol.right.putamendktregions
T1Hier_vol_right_rostral_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
t1.vol.right.rostral.ant.cingulatedktregions
T1Hier_vol_right_rostral_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
t1.vol.right.rostral.middle.frontaldktregions
T1Hier_vol_right_superior_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior frontal
t1.vol.right.sup.frontaldktregions
T1Hier_vol_right_superior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior parietal
t1.vol.right.sup.parietaldktregions
T1Hier_vol_right_superior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior temporal
t1.vol.right.sup.temporaldktregions
T1Hier_vol_right_supramarginaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
supramarginal
t1.vol.right.supramarginaldktregions
T1Hier_vol_right_thalamus_properdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
thalamus proper
t1.vol.right.thalamus.properdktregions
T1Hier_vol_right_transverse_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
transverse temporal
t1.vol.right.transverse.temporaldktregions
T1Hier_vol_right_ventral_dcdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
volventral dc
t1.vol.right.ventral.dcdktregions
T1Hier_area_4th_ventricledktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
4th ventricle
t1.area.4th.ventricledktregions
T1Hier_area_csfdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
csf
t1.area.csfdktregions
T1Hier_area_brain_stemdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
brain stem
t1.area.brain.stemdktregions
T1Hier_area_cerebellar_vermal_lobules_i.vdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellar vermal lobules i v
t1.area.cerebellar.vermal.lobules.i.vdktregions
T1Hier_area_cerebellar_vermal_lobules_vi.viidktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellar vermal lobules vi vii
t1.area.cerebellar.vermal.lobules.vi.viidktregions
T1Hier_area_cerebellar_vermal_lobules_viii.xdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellar vermal lobules viii x
t1.area.cerebellar.vermal.lobules.viii.xdktregions
T1Hier_area_left_amygdaladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
amygdala
t1.area.left.amygdaladktregions
T1Hier_area_left_caudal_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
t1.area.left.caudal.ant.cingulatedktregions
T1Hier_area_left_caudal_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal middle frontal
t1.area.left.caudal.middle.frontaldktregions
T1Hier_area_left_caudatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudate
t1.area.left.caudatedktregions
T1Hier_area_left_cerebellem_exteriordktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cerebellem exterior
t1.area.left.cerebellem.exteriordktregions
T1Hier_area_left_cerebellum_white_matterdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cerebellum white matter
t1.area.left.cerebellum.white.matterdktregions
T1Hier_area_left_cuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cuneus
t1.area.left.cuneusdktregions
T1Hier_area_left_entorhinaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
entorhinal
t1.area.left.entorhinaldktregions
T1Hier_area_left_fusiformdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
fusiform
t1.area.left.fusiformdktregions
T1Hier_area_left_hippocampusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
hippocampus
t1.area.left.hippocampusdktregions
T1Hier_area_left_inferior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior parietal
t1.area.left.inf.parietaldktregions
T1Hier_area_left_inferior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior temporal
t1.area.left.inf.temporaldktregions
T1Hier_area_left_insuladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
insula
t1.area.left.insuladktregions
T1Hier_area_left_isthmus_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
isthmus cingulate
t1.area.left.isthmus.cingulatedktregions
T1Hier_area_left_lateral_occipitaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral occipital
t1.area.left.lateral.occipitaldktregions
T1Hier_area_left_lateral_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
t1.area.left.lateral.orbitofrontaldktregions
T1Hier_area_left_lateral_ventricledktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral ventricle
t1.area.left.lateral.ventricledktregions
T1Hier_area_left_lingualdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lingual
t1.area.left.lingualdktregions
T1Hier_area_left_medial_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
medial orbitofrontal
t1.area.left.medial.orbitofrontaldktregions
T1Hier_area_left_middle_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
middle temporal
t1.area.left.middle.temporaldktregions
T1Hier_area_left_pallidiumdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pallidium
t1.area.left.pallidiumdktregions
T1Hier_area_left_paracentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
paracentral
t1.area.left.paracentdktregions
T1Hier_area_left_parahippocampaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.left.parahippocampaldktregions
T1Hier_area_left_pars_opercularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars opercularis
t1.area.left.pars.opercularisdktregions
T1Hier_area_left_pars_orbitalisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars orbitalis
t1.area.left.pars.orbitalisdktregions
T1Hier_area_left_pars_triangularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars triangularis
t1.area.left.pars.triangularisdktregions
T1Hier_area_left_pericalcarinedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pericalcarine
t1.area.left.pericalcarinedktregions
T1Hier_area_left_postcentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
postcentral
t1.area.left.postcentdktregions
T1Hier_area_left_posterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
posterior cingulate
t1.area.left.post.cingulatedktregions
T1Hier_area_left_precentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precentral
t1.area.left.precentdktregions
T1Hier_area_left_precuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precuneus
t1.area.left.precuneusdktregions
T1Hier_area_left_putamendktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
putamen
t1.area.left.putamendktregions
T1Hier_area_left_rostral_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
t1.area.left.rostral.ant.cingulatedktregions
T1Hier_area_left_rostral_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral middle frontal
t1.area.left.rostral.middle.frontaldktregions
T1Hier_area_left_superior_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior frontal
t1.area.left.sup.frontaldktregions
T1Hier_area_left_superior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior parietal
t1.area.left.sup.parietaldktregions
T1Hier_area_left_superior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior temporal
t1.area.left.sup.temporaldktregions
T1Hier_area_left_supramarginaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
supramarginal
t1.area.left.supramarginaldktregions
T1Hier_area_left_thalamus_properdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
thalamus proper
t1.area.left.thalamus.properdktregions
T1Hier_area_left_transverse_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
transverse temporal
t1.area.left.transverse.temporaldktregions
T1Hier_area_left_ventral_dcdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
ventral dc
t1.area.left.ventral.dcdktregions
T1Hier_area_right_amygdaladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
amygdala
t1.area.right.amygdaladktregions
T1Hier_area_right_caudal_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
t1.area.right.caudal.ant.cingulatedktregions
T1Hier_area_right_caudal_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal middle frontal
t1.area.right.caudal.middle.frontaldktregions
T1Hier_area_right_caudatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudate
t1.area.right.caudatedktregions
T1Hier_area_right_cerebellum_exteriordktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cerebellum exterior
t1.area.right.cerebellum.exteriordktregions
T1Hier_area_right_cerebellum_white_matterdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cerebellum white matter
t1.area.right.cerebellum.white.matterdktregions
T1Hier_area_right_cuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cuneus
t1.area.right.cuneusdktregions
T1Hier_area_right_entorhinaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
entorhinal
t1.area.right.entorhinaldktregions
T1Hier_area_right_fusiformdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
fusiform
t1.area.right.fusiformdktregions
T1Hier_area_right_hippocampusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
hippocampus
t1.area.right.hippocampusdktregions
T1Hier_area_right_inferior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior parietal
t1.area.right.inf.parietaldktregions
T1Hier_area_right_inferior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior temporal
t1.area.right.inf.temporaldktregions
T1Hier_area_right_insuladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
insula
t1.area.right.insuladktregions
T1Hier_area_right_isthmus_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
isthmus cingulate
t1.area.right.isthmus.cingulatedktregions
T1Hier_area_right_lateral_occipitaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral occipital
t1.area.right.lateral.occipitaldktregions
T1Hier_area_right_lateral_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
t1.area.right.lateral.orbitofrontaldktregions
T1Hier_area_right_lateral_ventricledktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral ventricle
t1.area.right.lateral.ventricledktregions
T1Hier_area_right_lingualdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lingual
t1.area.right.lingualdktregions
T1Hier_area_right_medial_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
medial orbitofrontal
t1.area.right.medial.orbitofrontaldktregions
T1Hier_area_right_middle_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
middle temporal
t1.area.right.middle.temporaldktregions
T1Hier_area_right_palladiumdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
palladium
t1.area.right.palladiumdktregions
T1Hier_area_right_paracentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
paracentral
t1.area.right.paracentdktregions
T1Hier_area_right_parahippocampaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.right.parahippocampaldktregions
T1Hier_area_right_pars_opercularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars opercularis
t1.area.right.pars.opercularisdktregions
T1Hier_area_right_pars_orbitalisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars orbitalis
t1.area.right.pars.orbitalisdktregions
T1Hier_area_right_pars_triangularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars triangularis
t1.area.right.pars.triangularisdktregions
T1Hier_area_right_pericalcarinedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pericalcarine
t1.area.right.pericalcarinedktregions
T1Hier_area_right_postcentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
postcentral
t1.area.right.postcentdktregions
T1Hier_area_right_posterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
posterior cingulate
t1.area.right.post.cingulatedktregions
T1Hier_area_right_precentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precentral
t1.area.right.precentdktregions
T1Hier_area_right_precuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precuneus
t1.area.right.precuneusdktregions
T1Hier_area_right_putamendktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
putamen
t1.area.right.putamendktregions
T1Hier_area_right_rostral_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
t1.area.right.rostral.ant.cingulatedktregions
T1Hier_area_right_rostral_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral middle frontal
t1.area.right.rostral.middle.frontaldktregions
T1Hier_area_right_superior_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior frontal
t1.area.right.sup.frontaldktregions
T1Hier_area_right_superior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior parietal
t1.area.right.sup.parietaldktregions
T1Hier_area_right_superior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior temporal
t1.area.right.sup.temporaldktregions
T1Hier_area_right_supramarginaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
supramarginal
t1.area.right.supramarginaldktregions
T1Hier_area_right_thalamus_properdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
thalamus proper
t1.area.right.thalamus.properdktregions
T1Hier_area_right_transverse_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
transverse temporal
t1.area.right.transverse.temporaldktregions
T1Hier_area_right_ventral_dcdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
ventral dc
t1.area.right.ventral.dcdktregions
T1Hier_thk_4th_ventricledktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
4th ventricle
t1.thk.4th.ventricledktregions
T1Hier_thk_csfdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
csf
t1.thk.csfdktregions
T1Hier_thk_brain_stemdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
brain stem
t1.thk.brain.stemdktregions
T1Hier_thk_cerebellar_vermal_lobules_i.vdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellar vermal lobules i v
t1.thk.cerebellar.vermal.lobules.i.vdktregions
T1Hier_thk_cerebellar_vermal_lobules_vi.viidktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellar vermal lobules vi vii
t1.thk.cerebellar.vermal.lobules.vi.viidktregions
T1Hier_thk_cerebellar_vermal_lobules_viii.xdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellar vermal lobules viii x
t1.thk.cerebellar.vermal.lobules.viii.xdktregions
T1Hier_thk_left_amygdaladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
amygdala
t1.thk.left.amygdaladktregions
T1Hier_thk_left_caudal_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
t1.thk.left.caudal.ant.cingulatedktregions
T1Hier_thk_left_caudal_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
t1.thk.left.caudal.middle.frontaldktregions
T1Hier_thk_left_caudatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudate
t1.thk.left.caudatedktregions
T1Hier_thk_left_cerebellem_exteriordktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cerebellem exterior
t1.thk.left.cerebellem.exteriordktregions
T1Hier_thk_left_cerebellum_white_matterdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cerebellum white matter
t1.thk.left.cerebellum.white.matterdktregions
T1Hier_thk_left_cuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cuneus
t1.thk.left.cuneusdktregions
T1Hier_thk_left_entorhinaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
entorhinal
t1.thk.left.entorhinaldktregions
T1Hier_thk_left_fusiformdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
fusiform
t1.thk.left.fusiformdktregions
T1Hier_thk_left_hippocampusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
hippocampus
t1.thk.left.hippocampusdktregions
T1Hier_thk_left_inferior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior parietal
t1.thk.left.inf.parietaldktregions
T1Hier_thk_left_inferior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior temporal
t1.thk.left.inf.temporaldktregions
T1Hier_thk_left_insuladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
insula
t1.thk.left.insuladktregions
T1Hier_thk_left_isthmus_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
t1.thk.left.isthmus.cingulatedktregions
T1Hier_thk_left_lateral_occipitaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral occipital
t1.thk.left.lateral.occipitaldktregions
T1Hier_thk_left_lateral_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
t1.thk.left.lateral.orbitofrontaldktregions
T1Hier_thk_left_lateral_ventricledktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral ventricle
t1.thk.left.lateral.ventricledktregions
T1Hier_thk_left_lingualdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lingual
t1.thk.left.lingualdktregions
T1Hier_thk_left_medial_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
t1.thk.left.medial.orbitofrontaldktregions
T1Hier_thk_left_middle_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
middle temporal
t1.thk.left.middle.temporaldktregions
T1Hier_thk_left_pallidiumdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pallidium
t1.thk.left.pallidiumdktregions
T1Hier_thk_left_paracentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
paracentral
t1.thk.left.paracentdktregions
T1Hier_thk_left_parahippocampaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.left.parahippocampaldktregions
T1Hier_thk_left_pars_opercularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars opercularis
t1.thk.left.pars.opercularisdktregions
T1Hier_thk_left_pars_orbitalisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars orbitalis
t1.thk.left.pars.orbitalisdktregions
T1Hier_thk_left_pars_triangularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars triangularis
t1.thk.left.pars.triangularisdktregions
T1Hier_thk_left_pericalcarinedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pericalcarine
t1.thk.left.pericalcarinedktregions
T1Hier_thk_left_postcentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
postcentral
t1.thk.left.postcentdktregions
T1Hier_thk_left_posterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
posterior cingulate
t1.thk.left.post.cingulatedktregions
T1Hier_thk_left_precentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precentral
t1.thk.left.precentdktregions
T1Hier_thk_left_precuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precuneus
t1.thk.left.precuneusdktregions
T1Hier_thk_left_putamendktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
putamen
t1.thk.left.putamendktregions
T1Hier_thk_left_rostral_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
t1.thk.left.rostral.ant.cingulatedktregions
T1Hier_thk_left_rostral_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
t1.thk.left.rostral.middle.frontaldktregions
T1Hier_thk_left_superior_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior frontal
t1.thk.left.sup.frontaldktregions
T1Hier_thk_left_superior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior parietal
t1.thk.left.sup.parietaldktregions
T1Hier_thk_left_superior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior temporal
t1.thk.left.sup.temporaldktregions
T1Hier_thk_left_supramarginaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
supramarginal
t1.thk.left.supramarginaldktregions
T1Hier_thk_left_thalamus_properdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
thalamus proper
t1.thk.left.thalamus.properdktregions
T1Hier_thk_left_transverse_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
transverse temporal
t1.thk.left.transverse.temporaldktregions
T1Hier_thk_left_ventral_dcdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
ventral dc
t1.thk.left.ventral.dcdktregions
T1Hier_thk_right_amygdaladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
amygdala
t1.thk.right.amygdaladktregions
T1Hier_thk_right_caudal_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
t1.thk.right.caudal.ant.cingulatedktregions
T1Hier_thk_right_caudal_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
t1.thk.right.caudal.middle.frontaldktregions
T1Hier_thk_right_caudatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudate
t1.thk.right.caudatedktregions
T1Hier_thk_right_cerebellum_exteriordktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cerebellum exterior
t1.thk.right.cerebellum.exteriordktregions
T1Hier_thk_right_cerebellum_white_matterdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cerebellum white matter
t1.thk.right.cerebellum.white.matterdktregions
T1Hier_thk_right_cuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cuneus
t1.thk.right.cuneusdktregions
T1Hier_thk_right_entorhinaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
entorhinal
t1.thk.right.entorhinaldktregions
T1Hier_thk_right_fusiformdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
fusiform
t1.thk.right.fusiformdktregions
T1Hier_thk_right_hippocampusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
hippocampus
t1.thk.right.hippocampusdktregions
T1Hier_thk_right_inferior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior parietal
t1.thk.right.inf.parietaldktregions
T1Hier_thk_right_inferior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior temporal
t1.thk.right.inf.temporaldktregions
T1Hier_thk_right_insuladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
insula
t1.thk.right.insuladktregions
T1Hier_thk_right_isthmus_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
t1.thk.right.isthmus.cingulatedktregions
T1Hier_thk_right_lateral_occipitaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral occipital
t1.thk.right.lateral.occipitaldktregions
T1Hier_thk_right_lateral_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
t1.thk.right.lateral.orbitofrontaldktregions
T1Hier_thk_right_lateral_ventricledktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral ventricle
t1.thk.right.lateral.ventricledktregions
T1Hier_thk_right_lingualdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lingual
t1.thk.right.lingualdktregions
T1Hier_thk_right_medial_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
t1.thk.right.medial.orbitofrontaldktregions
T1Hier_thk_right_middle_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
middle temporal
t1.thk.right.middle.temporaldktregions
T1Hier_thk_right_palladiumdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
palladium
t1.thk.right.palladiumdktregions
T1Hier_thk_right_paracentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
paracentral
t1.thk.right.paracentdktregions
T1Hier_thk_right_parahippocampaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.right.parahippocampaldktregions
T1Hier_thk_right_pars_opercularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars opercularis
t1.thk.right.pars.opercularisdktregions
T1Hier_thk_right_pars_orbitalisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars orbitalis
t1.thk.right.pars.orbitalisdktregions
T1Hier_thk_right_pars_triangularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars triangularis
t1.thk.right.pars.triangularisdktregions
T1Hier_thk_right_pericalcarinedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pericalcarine
t1.thk.right.pericalcarinedktregions
T1Hier_thk_right_postcentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
postcentral
t1.thk.right.postcentdktregions
T1Hier_thk_right_posterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
posterior cingulate
t1.thk.right.post.cingulatedktregions
T1Hier_thk_right_precentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precentral
t1.thk.right.precentdktregions
T1Hier_thk_right_precuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precuneus
t1.thk.right.precuneusdktregions
T1Hier_thk_right_putamendktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
putamen
t1.thk.right.putamendktregions
T1Hier_thk_right_rostral_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
t1.thk.right.rostral.ant.cingulatedktregions
T1Hier_thk_right_rostral_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
t1.thk.right.rostral.middle.frontaldktregions
T1Hier_thk_right_superior_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior frontal
t1.thk.right.sup.frontaldktregions
T1Hier_thk_right_superior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior parietal
t1.thk.right.sup.parietaldktregions
T1Hier_thk_right_superior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior temporal
t1.thk.right.sup.temporaldktregions
T1Hier_thk_right_supramarginaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
supramarginal
t1.thk.right.supramarginaldktregions
T1Hier_thk_right_thalamus_properdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
thalamus proper
t1.thk.right.thalamus.properdktregions
T1Hier_thk_right_transverse_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
transverse temporal
t1.thk.right.transverse.temporaldktregions
T1Hier_thk_right_ventral_dcdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
ventral dc
t1.thk.right.ventral.dcdktregions
T1Hier_vol_left_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
t1.vol.left.caudal.ant.cingulate.ctx
T1Hier_vol_left_caudal_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
t1.vol.left.caudal.middle.frontal.ctx
T1Hier_vol_left_cuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cuneus
t1.vol.left.cuneus.ctx
T1Hier_vol_left_entorhinaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
entorhinal
t1.vol.left.entorhinal.ctx
T1Hier_vol_left_fusiformdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
fusiform
t1.vol.left.fusiform.ctx
T1Hier_vol_left_inferior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior parietal
t1.vol.left.inf.parietal.ctx
T1Hier_vol_left_inferior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior temporal
t1.vol.left.inf.temporal.ctx
T1Hier_vol_left_insuladktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
insula
t1.vol.left.insula.ctx
T1Hier_vol_left_isthmus_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
t1.vol.left.isthmus.cingulate.ctx
T1Hier_vol_left_lateral_occipitaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral occipital
t1.vol.left.lateral.occipital.ctx
T1Hier_vol_left_lateral_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
t1.vol.left.lateral.orbitofrontal.ctx
T1Hier_vol_left_lingualdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lingual
t1.vol.left.lingual.ctx
T1Hier_vol_left_medial_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
t1.vol.left.medial.orbitofrontal.ctx
T1Hier_vol_left_middle_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
middle temporal
t1.vol.left.middle.temporal.ctx
T1Hier_vol_left_paracentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
paracentral
t1.vol.left.paracent.ctx
T1Hier_vol_left_parahippocampaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.left.parahippocampal.ctx
T1Hier_vol_left_pars_opercularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars opercularis
t1.vol.left.pars.opercularis.ctx
T1Hier_vol_left_pars_orbitalisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
t1.vol.left.pars.orbitalis.ctx
T1Hier_vol_left_pars_triangularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars triangularis
t1.vol.left.pars.triangularis.ctx
T1Hier_vol_left_pericalcarinedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pericalcarine
t1.vol.left.pericalcarine.ctx
T1Hier_vol_left_postcentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
postcentral
t1.vol.left.postcent.ctx
T1Hier_vol_left_posterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
t1.vol.left.post.cingulate.ctx
T1Hier_vol_left_precentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precentral
t1.vol.left.precent.ctx
T1Hier_vol_left_precuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precuneus
t1.vol.left.precuneus.ctx
T1Hier_vol_left_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
t1.vol.left.rostral.ant.cingulate.ctx
T1Hier_vol_left_rostral_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
t1.vol.left.rostral.middle.frontal.ctx
T1Hier_vol_left_superior_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior frontal
t1.vol.left.sup.frontal.ctx
T1Hier_vol_left_superior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior parietal
t1.vol.left.sup.parietal.ctx
T1Hier_vol_left_superior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior temporal
t1.vol.left.sup.temporal.ctx
T1Hier_vol_left_supramarginaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
supramarginal
t1.vol.left.supramarginal.ctx
T1Hier_vol_left_transverse_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
transverse temporal
t1.vol.left.transverse.temporal.ctx
T1Hier_vol_right_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
t1.vol.right.caudal.ant.cingulate.ctx
T1Hier_vol_right_caudal_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
t1.vol.right.caudal.middle.frontal.ctx
T1Hier_vol_right_cuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cuneus
t1.vol.right.cuneus.ctx
T1Hier_vol_right_entorhinaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
entorhinal
t1.vol.right.entorhinal.ctx
T1Hier_vol_right_fusiformdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
fusiform
t1.vol.right.fusiform.ctx
T1Hier_vol_right_inferior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior parietal
t1.vol.right.inf.parietal.ctx
T1Hier_vol_right_inferior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior temporal
t1.vol.right.inf.temporal.ctx
T1Hier_vol_right_insuladktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
insula
t1.vol.right.insula.ctx
T1Hier_vol_right_isthmus_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
t1.vol.right.isthmus.cingulate.ctx
T1Hier_vol_right_lateral_occipitaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral occipital
t1.vol.right.lateral.occipital.ctx
T1Hier_vol_right_lateral_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
t1.vol.right.lateral.orbitofrontal.ctx
T1Hier_vol_right_lingualdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lingual
t1.vol.right.lingual.ctx
T1Hier_vol_right_medial_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
t1.vol.right.medial.orbitofrontal.ctx
T1Hier_vol_right_middle_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
middle temporal
t1.vol.right.middle.temporal.ctx
T1Hier_vol_right_paracentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
paracentral
t1.vol.right.paracent.ctx
T1Hier_vol_right_parahippocampaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.right.parahippocampal.ctx
T1Hier_vol_right_pars_opercularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars opercularis
t1.vol.right.pars.opercularis.ctx
T1Hier_vol_right_pars_orbitalisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
t1.vol.right.pars.orbitalis.ctx
T1Hier_vol_right_pars_triangularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars triangularis
t1.vol.right.pars.triangularis.ctx
T1Hier_vol_right_pericalcarinedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pericalcarine
t1.vol.right.pericalcarine.ctx
T1Hier_vol_right_postcentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
postcentral
t1.vol.right.postcent.ctx
T1Hier_vol_right_posterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
t1.vol.right.post.cingulate.ctx
T1Hier_vol_right_precentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precentral
t1.vol.right.precent.ctx
T1Hier_vol_right_precuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precuneus
t1.vol.right.precuneus.ctx
T1Hier_vol_right_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
t1.vol.right.rostral.ant.cingulate.ctx
T1Hier_vol_right_rostral_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
t1.vol.right.rostral.middle.frontal.ctx
T1Hier_vol_right_superior_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior frontal
t1.vol.right.sup.frontal.ctx
T1Hier_vol_right_superior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior parietal
t1.vol.right.sup.parietal.ctx
T1Hier_vol_right_superior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior temporal
t1.vol.right.sup.temporal.ctx
T1Hier_vol_right_supramarginaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
supramarginal
t1.vol.right.supramarginal.ctx
T1Hier_vol_right_transverse_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
transverse temporal
t1.vol.right.transverse.temporal.ctx
T1Hier_area_left_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
t1.area.left.caudal.ant.cingulate.ctx
T1Hier_area_left_caudal_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal middle frontal
t1.area.left.caudal.middle.frontal.ctx
T1Hier_area_left_cuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cuneus
t1.area.left.cuneus.ctx
T1Hier_area_left_entorhinaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
entorhinal
t1.area.left.entorhinal.ctx
T1Hier_area_left_fusiformdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
fusiform
t1.area.left.fusiform.ctx
T1Hier_area_left_inferior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior parietal
t1.area.left.inf.parietal.ctx
T1Hier_area_left_inferior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior temporal
t1.area.left.inf.temporal.ctx
T1Hier_area_left_insuladktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
insula
t1.area.left.insula.ctx
T1Hier_area_left_isthmus_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
isthmus cingulate
t1.area.left.isthmus.cingulate.ctx
T1Hier_area_left_lateral_occipitaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral occipital
t1.area.left.lateral.occipital.ctx
T1Hier_area_left_lateral_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
t1.area.left.lateral.orbitofrontal.ctx
T1Hier_area_left_lingualdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lingual
t1.area.left.lingual.ctx
T1Hier_area_left_medial_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
medial orbitofrontal
t1.area.left.medial.orbitofrontal.ctx
T1Hier_area_left_middle_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
middle temporal
t1.area.left.middle.temporal.ctx
T1Hier_area_left_paracentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
paracentral
t1.area.left.paracent.ctx
T1Hier_area_left_parahippocampaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.left.parahippocampal.ctx
T1Hier_area_left_pars_opercularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars opercularis
t1.area.left.pars.opercularis.ctx
T1Hier_area_left_pars_orbitalisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars orbitalis
t1.area.left.pars.orbitalis.ctx
T1Hier_area_left_pars_triangularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars triangularis
t1.area.left.pars.triangularis.ctx
T1Hier_area_left_pericalcarinedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pericalcarine
t1.area.left.pericalcarine.ctx
T1Hier_area_left_postcentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
postcentral
t1.area.left.postcent.ctx
T1Hier_area_left_posterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
posterior cingulate
t1.area.left.post.cingulate.ctx
T1Hier_area_left_precentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precentral
t1.area.left.precent.ctx
T1Hier_area_left_precuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precuneus
t1.area.left.precuneus.ctx
T1Hier_area_left_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
t1.area.left.rostral.ant.cingulate.ctx
T1Hier_area_left_rostral_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral middle frontal
t1.area.left.rostral.middle.frontal.ctx
T1Hier_area_left_superior_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior frontal
t1.area.left.sup.frontal.ctx
T1Hier_area_left_superior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior parietal
t1.area.left.sup.parietal.ctx
T1Hier_area_left_superior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior temporal
t1.area.left.sup.temporal.ctx
T1Hier_area_left_supramarginaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
supramarginal
t1.area.left.supramarginal.ctx
T1Hier_area_left_transverse_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
transverse temporal
t1.area.left.transverse.temporal.ctx
T1Hier_area_right_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
t1.area.right.caudal.ant.cingulate.ctx
T1Hier_area_right_caudal_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal middle frontal
t1.area.right.caudal.middle.frontal.ctx
T1Hier_area_right_cuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cuneus
t1.area.right.cuneus.ctx
T1Hier_area_right_entorhinaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
entorhinal
t1.area.right.entorhinal.ctx
T1Hier_area_right_fusiformdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
fusiform
t1.area.right.fusiform.ctx
T1Hier_area_right_inferior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior parietal
t1.area.right.inf.parietal.ctx
T1Hier_area_right_inferior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior temporal
t1.area.right.inf.temporal.ctx
T1Hier_area_right_insuladktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
insula
t1.area.right.insula.ctx
T1Hier_area_right_isthmus_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
isthmus cingulate
t1.area.right.isthmus.cingulate.ctx
T1Hier_area_right_lateral_occipitaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral occipital
t1.area.right.lateral.occipital.ctx
T1Hier_area_right_lateral_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
t1.area.right.lateral.orbitofrontal.ctx
T1Hier_area_right_lingualdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lingual
t1.area.right.lingual.ctx
T1Hier_area_right_medial_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
medial orbitofrontal
t1.area.right.medial.orbitofrontal.ctx
T1Hier_area_right_middle_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
middle temporal
t1.area.right.middle.temporal.ctx
T1Hier_area_right_paracentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
paracentral
t1.area.right.paracent.ctx
T1Hier_area_right_parahippocampaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.right.parahippocampal.ctx
T1Hier_area_right_pars_opercularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars opercularis
t1.area.right.pars.opercularis.ctx
T1Hier_area_right_pars_orbitalisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars orbitalis
t1.area.right.pars.orbitalis.ctx
T1Hier_area_right_pars_triangularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars triangularis
t1.area.right.pars.triangularis.ctx
T1Hier_area_right_pericalcarinedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pericalcarine
t1.area.right.pericalcarine.ctx
T1Hier_area_right_postcentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
postcentral
t1.area.right.postcent.ctx
T1Hier_area_right_posterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
posterior cingulate
t1.area.right.post.cingulate.ctx
T1Hier_area_right_precentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precentral
t1.area.right.precent.ctx
T1Hier_area_right_precuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precuneus
t1.area.right.precuneus.ctx
T1Hier_area_right_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
t1.area.right.rostral.ant.cingulate.ctx
T1Hier_area_right_rostral_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral middle frontal
t1.area.right.rostral.middle.frontal.ctx
T1Hier_area_right_superior_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior frontal
t1.area.right.sup.frontal.ctx
T1Hier_area_right_superior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior parietal
t1.area.right.sup.parietal.ctx
T1Hier_area_right_superior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior temporal
t1.area.right.sup.temporal.ctx
T1Hier_area_right_supramarginaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
supramarginal
t1.area.right.supramarginal.ctx
T1Hier_area_right_transverse_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
transverse temporal
t1.area.right.transverse.temporal.ctx
T1Hier_thk_left_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
t1.thk.left.caudal.ant.cingulate.ctx
T1Hier_thk_left_caudal_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
t1.thk.left.caudal.middle.frontal.ctx
T1Hier_thk_left_cuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cuneus
t1.thk.left.cuneus.ctx
T1Hier_thk_left_entorhinaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
entorhinal
t1.thk.left.entorhinal.ctx
T1Hier_thk_left_fusiformdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
fusiform
t1.thk.left.fusiform.ctx
T1Hier_thk_left_inferior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior parietal
t1.thk.left.inf.parietal.ctx
T1Hier_thk_left_inferior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior temporal
t1.thk.left.inf.temporal.ctx
T1Hier_thk_left_insuladktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
insula
t1.thk.left.insula.ctx
T1Hier_thk_left_isthmus_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
t1.thk.left.isthmus.cingulate.ctx
T1Hier_thk_left_lateral_occipitaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral occipital
t1.thk.left.lateral.occipital.ctx
T1Hier_thk_left_lateral_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
t1.thk.left.lateral.orbitofrontal.ctx
T1Hier_thk_left_lingualdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lingual
t1.thk.left.lingual.ctx
T1Hier_thk_left_medial_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
t1.thk.left.medial.orbitofrontal.ctx
T1Hier_thk_left_middle_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
middle temporal
t1.thk.left.middle.temporal.ctx
T1Hier_thk_left_paracentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
paracentral
t1.thk.left.paracent.ctx
T1Hier_thk_left_parahippocampaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.left.parahippocampal.ctx
T1Hier_thk_left_pars_opercularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars opercularis
t1.thk.left.pars.opercularis.ctx
T1Hier_thk_left_pars_orbitalisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars orbitalis
t1.thk.left.pars.orbitalis.ctx
T1Hier_thk_left_pars_triangularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars triangularis
t1.thk.left.pars.triangularis.ctx
T1Hier_thk_left_pericalcarinedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pericalcarine
t1.thk.left.pericalcarine.ctx
T1Hier_thk_left_postcentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
postcentral
t1.thk.left.postcent.ctx
T1Hier_thk_left_posterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
posterior cingulate
t1.thk.left.post.cingulate.ctx
T1Hier_thk_left_precentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precentral
t1.thk.left.precent.ctx
T1Hier_thk_left_precuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precuneus
t1.thk.left.precuneus.ctx
T1Hier_thk_left_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
t1.thk.left.rostral.ant.cingulate.ctx
T1Hier_thk_left_rostral_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
t1.thk.left.rostral.middle.frontal.ctx
T1Hier_thk_left_superior_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior frontal
t1.thk.left.sup.frontal.ctx
T1Hier_thk_left_superior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior parietal
t1.thk.left.sup.parietal.ctx
T1Hier_thk_left_superior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior temporal
t1.thk.left.sup.temporal.ctx
T1Hier_thk_left_supramarginaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
supramarginal
t1.thk.left.supramarginal.ctx
T1Hier_thk_left_transverse_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
transverse temporal
t1.thk.left.transverse.temporal.ctx
T1Hier_thk_right_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
t1.thk.right.caudal.ant.cingulate.ctx
T1Hier_thk_right_caudal_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
t1.thk.right.caudal.middle.frontal.ctx
T1Hier_thk_right_cuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cuneus
t1.thk.right.cuneus.ctx
T1Hier_thk_right_entorhinaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
entorhinal
t1.thk.right.entorhinal.ctx
T1Hier_thk_right_fusiformdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
fusiform
t1.thk.right.fusiform.ctx
T1Hier_thk_right_inferior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior parietal
t1.thk.right.inf.parietal.ctx
T1Hier_thk_right_inferior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior temporal
t1.thk.right.inf.temporal.ctx
T1Hier_thk_right_insuladktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
insula
t1.thk.right.insula.ctx
T1Hier_thk_right_isthmus_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
t1.thk.right.isthmus.cingulate.ctx
T1Hier_thk_right_lateral_occipitaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral occipital
t1.thk.right.lateral.occipital.ctx
T1Hier_thk_right_lateral_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
t1.thk.right.lateral.orbitofrontal.ctx
T1Hier_thk_right_lingualdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lingual
t1.thk.right.lingual.ctx
T1Hier_thk_right_medial_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
t1.thk.right.medial.orbitofrontal.ctx
T1Hier_thk_right_middle_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
middle temporal
t1.thk.right.middle.temporal.ctx
T1Hier_thk_right_paracentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
paracentral
t1.thk.right.paracent.ctx
T1Hier_thk_right_parahippocampaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.right.parahippocampal.ctx
T1Hier_thk_right_pars_opercularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars opercularis
t1.thk.right.pars.opercularis.ctx
T1Hier_thk_right_pars_orbitalisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars orbitalis
t1.thk.right.pars.orbitalis.ctx
T1Hier_thk_right_pars_triangularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars triangularis
t1.thk.right.pars.triangularis.ctx
T1Hier_thk_right_pericalcarinedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pericalcarine
t1.thk.right.pericalcarine.ctx
T1Hier_thk_right_postcentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
postcentral
t1.thk.right.postcent.ctx
T1Hier_thk_right_posterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
posterior cingulate
t1.thk.right.post.cingulate.ctx
T1Hier_thk_right_precentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precentral
t1.thk.right.precent.ctx
T1Hier_thk_right_precuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precuneus
t1.thk.right.precuneus.ctx
T1Hier_thk_right_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
t1.thk.right.rostral.ant.cingulate.ctx
T1Hier_thk_right_rostral_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
t1.thk.right.rostral.middle.frontal.ctx
T1Hier_thk_right_superior_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior frontal
t1.thk.right.sup.frontal.ctx
T1Hier_thk_right_superior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior parietal
t1.thk.right.sup.parietal.ctx
T1Hier_thk_right_superior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior temporal
t1.thk.right.sup.temporal.ctx
T1Hier_thk_right_supramarginaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
supramarginal
t1.thk.right.supramarginal.ctx
T1Hier_thk_right_transverse_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
transverse temporal
t1.thk.right.transverse.temporal.ctx
T1Hier_vol_left_ca1mtl
T1 hierarchical processing
left
MTL
geometry/volume
volca1mtl
t1.vol.left.ca1mtl
T1Hier_vol_left_dg.ca3mtl
T1 hierarchical processing
left
MTL
geometry/volume
voldg ca3mtl
t1.vol.left.dg.ca3mtl
T1Hier_vol_left_alecmtl
T1 hierarchical processing
left
MTL
geometry/volume
volalecmtl
t1.vol.left.alecmtl
T1Hier_vol_left_pmecmtl
T1 hierarchical processing
left
MTL
geometry/volume
volpmecmtl
t1.vol.left.pmecmtl
T1Hier_vol_left_parahippocampalmtl
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.left.parahippocampalmtl
T1Hier_vol_left_perirhinalmtl
T1 hierarchical processing
left
MTL
geometry/volume
volperirhinalmtl
t1.vol.left.perirhinalmtl
T1Hier_vol_left_subiculummtl
T1 hierarchical processing
left
MTL
geometry/volume
volsubiculummtl
t1.vol.left.subiculummtl
T1Hier_vol_right_ca1mtl
T1 hierarchical processing
right
MTL
geometry/volume
volca1mtl
t1.vol.right.ca1mtl
T1Hier_vol_right_dg.ca3mtl
T1 hierarchical processing
right
MTL
geometry/volume
voldg ca3mtl
t1.vol.right.dg.ca3mtl
T1Hier_vol_right_alecmtl
T1 hierarchical processing
right
MTL
geometry/volume
volalecmtl
t1.vol.right.alecmtl
T1Hier_vol_right_pmecmtl
T1 hierarchical processing
right
MTL
geometry/volume
volpmecmtl
t1.vol.right.pmecmtl
T1Hier_vol_right_parahippocampalmtl
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.right.parahippocampalmtl
T1Hier_vol_right_perirhinalmtl
T1 hierarchical processing
right
MTL
geometry/volume
volperirhinalmtl
t1.vol.right.perirhinalmtl
T1Hier_vol_right_subiculummtl
T1 hierarchical processing
right
MTL
geometry/volume
volsubiculummtl
t1.vol.right.subiculummtl
T1Hier_area_left_ca1mtl
T1 hierarchical processing
left
MTL
geometry/area
ca1mtl
t1.area.left.ca1mtl
T1Hier_area_left_dg.ca3mtl
T1 hierarchical processing
left
MTL
geometry/area
dg ca3mtl
t1.area.left.dg.ca3mtl
T1Hier_area_left_alecmtl
T1 hierarchical processing
left
MTL
geometry/area
alecmtl
t1.area.left.alecmtl
T1Hier_area_left_pmecmtl
T1 hierarchical processing
left
MTL
geometry/area
pmecmtl
t1.area.left.pmecmtl
T1Hier_area_left_parahippocampalmtl
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.left.parahippocampalmtl
T1Hier_area_left_perirhinalmtl
T1 hierarchical processing
left
MTL
geometry/area
perirhinalmtl
t1.area.left.perirhinalmtl
T1Hier_area_left_subiculummtl
T1 hierarchical processing
left
MTL
geometry/area
subiculummtl
t1.area.left.subiculummtl
T1Hier_area_right_ca1mtl
T1 hierarchical processing
right
MTL
geometry/area
ca1mtl
t1.area.right.ca1mtl
T1Hier_area_right_dg.ca3mtl
T1 hierarchical processing
right
MTL
geometry/area
dg ca3mtl
t1.area.right.dg.ca3mtl
T1Hier_area_right_alecmtl
T1 hierarchical processing
right
MTL
geometry/area
alecmtl
t1.area.right.alecmtl
T1Hier_area_right_pmecmtl
T1 hierarchical processing
right
MTL
geometry/area
pmecmtl
t1.area.right.pmecmtl
T1Hier_area_right_parahippocampalmtl
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.right.parahippocampalmtl
T1Hier_area_right_perirhinalmtl
T1 hierarchical processing
right
MTL
geometry/area
perirhinalmtl
t1.area.right.perirhinalmtl
T1Hier_area_right_subiculummtl
T1 hierarchical processing
right
MTL
geometry/area
subiculummtl
t1.area.right.subiculummtl
T1Hier_thk_left_ca1mtl
T1 hierarchical processing
left
MTL
geometry/thickness
ca1mtl
t1.thk.left.ca1mtl
T1Hier_thk_left_dg.ca3mtl
T1 hierarchical processing
left
MTL
geometry/thickness
dg ca3mtl
t1.thk.left.dg.ca3mtl
T1Hier_thk_left_alecmtl
T1 hierarchical processing
left
MTL
geometry/thickness
alecmtl
t1.thk.left.alecmtl
T1Hier_thk_left_pmecmtl
T1 hierarchical processing
left
MTL
geometry/thickness
pmecmtl
t1.thk.left.pmecmtl
T1Hier_thk_left_parahippocampalmtl
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.left.parahippocampalmtl
T1Hier_thk_left_perirhinalmtl
T1 hierarchical processing
left
MTL
geometry/thickness
perirhinalmtl
t1.thk.left.perirhinalmtl
T1Hier_thk_left_subiculummtl
T1 hierarchical processing
left
MTL
geometry/thickness
subiculummtl
t1.thk.left.subiculummtl
T1Hier_thk_right_ca1mtl
T1 hierarchical processing
right
MTL
geometry/thickness
ca1mtl
t1.thk.right.ca1mtl
T1Hier_thk_right_dg.ca3mtl
T1 hierarchical processing
right
MTL
geometry/thickness
dg ca3mtl
t1.thk.right.dg.ca3mtl
T1Hier_thk_right_alecmtl
T1 hierarchical processing
right
MTL
geometry/thickness
alecmtl
t1.thk.right.alecmtl
T1Hier_thk_right_pmecmtl
T1 hierarchical processing
right
MTL
geometry/thickness
pmecmtl
t1.thk.right.pmecmtl
T1Hier_thk_right_parahippocampalmtl
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.right.parahippocampalmtl
T1Hier_thk_right_perirhinalmtl
T1 hierarchical processing
right
MTL
geometry/thickness
perirhinalmtl
t1.thk.right.perirhinalmtl
T1Hier_thk_right_subiculummtl
T1 hierarchical processing
right
MTL
geometry/thickness
subiculummtl
t1.thk.right.subiculummtl
T1Hier_vol_ch13_leftbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus ch1 to ch3
t1.vol.ch13.leftbf
T1Hier_vol_ch13_rightbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus ch1 to ch3
t1.vol.ch13.rightbf
T1Hier_vol_nbm_left_antbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus anterior ch4
t1.vol.nbm.left.antbf
T1Hier_vol_nbm_left_midbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus middle ch4
t1.vol.nbm.left.midbf
T1Hier_vol_nbm_left_posbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus posterior ch4
t1.vol.nbm.left.posbf
T1Hier_vol_nbm_right_antbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus anterior ch4
t1.vol.nbm.right.antbf
T1Hier_vol_nbm_right_midbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus middle ch4
t1.vol.nbm.right.midbf
T1Hier_vol_nbm_right_posbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus posterior ch4
t1.vol.nbm.right.posbf
T1Hier_area_ch13_leftbf
T1 hierarchical processing
left
BF
geometry/area
ch13 bf
t1.area.ch13.leftbf
T1Hier_area_ch13_rightbf
T1 hierarchical processing
right
BF
geometry/area
ch13 bf
t1.area.ch13.rightbf
T1Hier_area_nbm_left_antbf
T1 hierarchical processing
left
BF
geometry/area
basal nucleus anterior ch4
t1.area.nbm.left.antbf
T1Hier_area_nbm_left_midbf
T1 hierarchical processing
left
BF
geometry/area
basal nucleus middle ch4
t1.area.nbm.left.midbf
T1Hier_area_nbm_left_posbf
T1 hierarchical processing
left
BF
geometry/area
basal nucleus posterior ch4
t1.area.nbm.left.posbf
T1Hier_area_nbm_right_antbf
T1 hierarchical processing
right
BF
geometry/area
basal nucleus anterior ch4
t1.area.nbm.right.antbf
T1Hier_area_nbm_right_midbf
T1 hierarchical processing
right
BF
geometry/area
basal nucleus middle ch4
t1.area.nbm.right.midbf
T1Hier_area_nbm_right_posbf
T1 hierarchical processing
right
BF
geometry/area
basal nucleus posterior ch4
t1.area.nbm.right.posbf
T1Hier_thk_ch13_leftbf
T1 hierarchical processing
left
BF
geometry/thickness
ch13 bf
t1.thk.ch13.leftbf
T1Hier_thk_ch13_rightbf
T1 hierarchical processing
right
BF
geometry/thickness
ch13 bf
t1.thk.ch13.rightbf
T1Hier_thk_nbm_left_antbf
T1 hierarchical processing
left
BF
geometry/thickness
basal nucleus anterior ch4
t1.thk.nbm.left.antbf
T1Hier_thk_nbm_left_midbf
T1 hierarchical processing
left
BF
geometry/thickness
basal nucleus middle ch4
t1.thk.nbm.left.midbf
T1Hier_thk_nbm_left_posbf
T1 hierarchical processing
left
BF
geometry/thickness
basal nucleus posterior ch4
t1.thk.nbm.left.posbf
T1Hier_thk_nbm_right_antbf
T1 hierarchical processing
right
BF
geometry/thickness
basal nucleus anterior ch4
t1.thk.nbm.right.antbf
T1Hier_thk_nbm_right_midbf
T1 hierarchical processing
right
BF
geometry/thickness
basal nucleus middle ch4
t1.thk.nbm.right.midbf
T1Hier_thk_nbm_right_posbf
T1 hierarchical processing
right
BF
geometry/thickness
basal nucleus posterior ch4
t1.thk.nbm.right.posbf
T1Hier_vol_bn_gp_gpe_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus externa
t1.vol.bn.gp.gpe.left
T1Hier_vol_bn_gp_gpe_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus externa
t1.vol.bn.gp.gpe.right
T1Hier_vol_bn_gp_gpi_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus interna
t1.vol.bn.gp.gpi.left
T1Hier_vol_bn_gp_gpi_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus interna
t1.vol.bn.gp.gpi.right
T1Hier_vol_bn_gp_vep_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
ventral pallidum
t1.vol.bn.gp.vep.left
T1Hier_vol_bn_gp_vep_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
ventral pallidum
t1.vol.bn.gp.vep.right
T1Hier_vol_bn_str_ca_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
caudate
t1.vol.bn.str.ca.left
T1Hier_vol_bn_str_ca_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
caudate
t1.vol.bn.str.ca.right
T1Hier_vol_bn_str_nac_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Nucleus Accumbens
t1.vol.bn.str.nac.left
T1Hier_vol_bn_str_nac_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Nucleus Accumbens
t1.vol.bn.str.nac.right
T1Hier_vol_bn_str_pu_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
putamen
t1.vol.bn.str.pu.left
T1Hier_vol_bn_str_pu_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
putamen
t1.vol.bn.str.pu.right
T1Hier_vol_die_hth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Hypothalamus
t1.vol.die.hth.left
T1Hier_vol_die_hth_mn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
mammillary nucleus
t1.vol.die.hth.mn.left
T1Hier_vol_die_hth_mn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
mammillary nucleus
t1.vol.die.hth.mn.right
T1Hier_vol_die_hth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Hypothalamus
t1.vol.die.hth.right
T1Hier_vol_die_sth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Subthalamic Nucleus
t1.vol.die.sth.left
T1Hier_vol_die_sth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Subthalamic Nucleus
t1.vol.die.sth.right
T1Hier_vol_exa_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
extended amygdala
t1.vol.exa.left
T1Hier_vol_exa_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
extended amygdala
t1.vol.exa.right
T1Hier_vol_mtg_rn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
red nucleus
t1.vol.mtg.rn.left
T1Hier_vol_mtg_rn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
red nucleus
t1.vol.mtg.rn.right
T1Hier_vol_mtg_sn_snc_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.left
T1Hier_vol_mtg_sn_snc_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.right
T1Hier_vol_mtg_sn_snr_leftcit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.left
T1Hier_vol_mtg_sn_snr_rightcit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.right
T1Hier_vol_mtg_vtr_pbp_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
t1.vol.mtg.vtr.pbp.left
T1Hier_vol_mtg_vtr_pbp_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
t1.vol.mtg.vtr.pbp.right
T1Hier_vol_mtg_vtr_vta_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Ventral Tegmental Area
t1.vol.mtg.vtr.vta.left
T1Hier_vol_mtg_vtr_vta_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Ventral Tegmental Area
t1.vol.mtg.vtr.vta.right
T1Hier_vol_referenceregion_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
​
t1.vol.referenceregion.left
T1Hier_vol_referenceregion_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
​
t1.vol.referenceregion.right
T1Hier_vol_thm_eth_hn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Habenular Nuclei
t1.vol.thm.eth.hn.left
T1Hier_vol_thm_eth_hn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Habenular Nuclei
t1.vol.thm.eth.hn.right
T1Hier_area_bn_gp_gpe_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus externa
t1.area.bn.gp.gpe.left
T1Hier_area_bn_gp_gpe_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus externa
t1.area.bn.gp.gpe.right
T1Hier_area_bn_gp_gpi_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus interna
t1.area.bn.gp.gpi.left
T1Hier_area_bn_gp_gpi_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus interna
t1.area.bn.gp.gpi.right
T1Hier_area_bn_gp_vep_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
ventral pallidum
t1.area.bn.gp.vep.left
T1Hier_area_bn_gp_vep_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
ventral pallidum
t1.area.bn.gp.vep.right
T1Hier_area_bn_str_ca_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
caudate
t1.area.bn.str.ca.left
T1Hier_area_bn_str_ca_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
caudate
t1.area.bn.str.ca.right
T1Hier_area_bn_str_nac_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Nucleus Accumbens
t1.area.bn.str.nac.left
T1Hier_area_bn_str_nac_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Nucleus Accumbens
t1.area.bn.str.nac.right
T1Hier_area_bn_str_pu_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
putamen
t1.area.bn.str.pu.left
T1Hier_area_bn_str_pu_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
putamen
t1.area.bn.str.pu.right
T1Hier_area_die_hth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Hypothalamus
t1.area.die.hth.left
T1Hier_area_die_hth_mn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
mammillary nucleus
t1.area.die.hth.mn.left
T1Hier_area_die_hth_mn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
mammillary nucleus
t1.area.die.hth.mn.right
T1Hier_area_die_hth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Hypothalamus
t1.area.die.hth.right
T1Hier_area_die_sth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Subthalamic Nucleus
t1.area.die.sth.left
T1Hier_area_die_sth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Subthalamic Nucleus
t1.area.die.sth.right
T1Hier_area_exa_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
extended amygdala
t1.area.exa.left
T1Hier_area_exa_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
extended amygdala
t1.area.exa.right
T1Hier_area_mtg_rn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
red nucleus
t1.area.mtg.rn.left
T1Hier_area_mtg_rn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
red nucleus
t1.area.mtg.rn.right
T1Hier_area_mtg_sn_snc_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.left
T1Hier_area_mtg_sn_snc_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.right
T1Hier_area_mtg_sn_snr_leftcit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.left
T1Hier_area_mtg_sn_snr_rightcit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.right
T1Hier_area_mtg_vtr_pbp_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Parabrachial Pigmented Nucleus
t1.area.mtg.vtr.pbp.left
T1Hier_area_mtg_vtr_pbp_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Parabrachial Pigmented Nucleus
t1.area.mtg.vtr.pbp.right
T1Hier_area_mtg_vtr_vta_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Ventral Tegmental Area
t1.area.mtg.vtr.vta.left
T1Hier_area_mtg_vtr_vta_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Ventral Tegmental Area
t1.area.mtg.vtr.vta.right
T1Hier_area_referenceregion_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
​
t1.area.referenceregion.left
T1Hier_area_referenceregion_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
​
t1.area.referenceregion.right
T1Hier_area_thm_eth_hn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Habenular Nuclei
t1.area.thm.eth.hn.left
T1Hier_area_thm_eth_hn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Habenular Nuclei
t1.area.thm.eth.hn.right
T1Hier_thk_bn_gp_gpe_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus externa
t1.thk.bn.gp.gpe.left
T1Hier_thk_bn_gp_gpe_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus externa
t1.thk.bn.gp.gpe.right
T1Hier_thk_bn_gp_gpi_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus interna
t1.thk.bn.gp.gpi.left
T1Hier_thk_bn_gp_gpi_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus interna
t1.thk.bn.gp.gpi.right
T1Hier_thk_bn_gp_vep_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
ventral pallidum
t1.thk.bn.gp.vep.left
T1Hier_thk_bn_gp_vep_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
ventral pallidum
t1.thk.bn.gp.vep.right
T1Hier_thk_bn_str_ca_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
caudate
t1.thk.bn.str.ca.left
T1Hier_thk_bn_str_ca_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
caudate
t1.thk.bn.str.ca.right
T1Hier_thk_bn_str_nac_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Nucleus Accumbens
t1.thk.bn.str.nac.left
T1Hier_thk_bn_str_nac_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Nucleus Accumbens
t1.thk.bn.str.nac.right
T1Hier_thk_bn_str_pu_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
putamen
t1.thk.bn.str.pu.left
T1Hier_thk_bn_str_pu_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
putamen
t1.thk.bn.str.pu.right
T1Hier_thk_die_hth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Hypothalamus
t1.thk.die.hth.left
T1Hier_thk_die_hth_mn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
mammillary nucleus
t1.thk.die.hth.mn.left
T1Hier_thk_die_hth_mn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
mammillary nucleus
t1.thk.die.hth.mn.right
T1Hier_thk_die_hth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Hypothalamus
t1.thk.die.hth.right
T1Hier_thk_die_sth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Subthalamic Nucleus
t1.thk.die.sth.left
T1Hier_thk_die_sth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Subthalamic Nucleus
t1.thk.die.sth.right
T1Hier_thk_exa_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
extended amygdala
t1.thk.exa.left
T1Hier_thk_exa_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
extended amygdala
t1.thk.exa.right
T1Hier_thk_mtg_rn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
red nucleus
t1.thk.mtg.rn.left
T1Hier_thk_mtg_rn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
red nucleus
t1.thk.mtg.rn.right
T1Hier_thk_mtg_sn_snc_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.left
T1Hier_thk_mtg_sn_snc_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.right
T1Hier_thk_mtg_sn_snr_leftcit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.left
T1Hier_thk_mtg_sn_snr_rightcit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.right
T1Hier_thk_mtg_vtr_pbp_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Parabrachial Pigmented Nucleus
t1.thk.mtg.vtr.pbp.left
T1Hier_thk_mtg_vtr_pbp_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Parabrachial Pigmented Nucleus
t1.thk.mtg.vtr.pbp.right
T1Hier_thk_mtg_vtr_vta_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Ventral Tegmental Area
t1.thk.mtg.vtr.vta.left
T1Hier_thk_mtg_vtr_vta_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Ventral Tegmental Area
t1.thk.mtg.vtr.vta.right
T1Hier_thk_referenceregion_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
​
t1.thk.referenceregion.left
T1Hier_thk_referenceregion_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
​
t1.thk.referenceregion.right
T1Hier_thk_thm_eth_hn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Habenular Nuclei
t1.thk.thm.eth.hn.left
T1Hier_thk_thm_eth_hn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Habenular Nuclei
t1.thk.thm.eth.hn.right
T1Hier_vol_bn_gp_gpe_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus externa
t1.vol.bn.gp.gpe.leftdp.
T1Hier_vol_bn_gp_gpe_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus externa
t1.vol.bn.gp.gpe.rightdp.
T1Hier_vol_bn_gp_gpi_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus interna
t1.vol.bn.gp.gpi.leftdp.
T1Hier_vol_bn_gp_gpi_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus interna
t1.vol.bn.gp.gpi.rightdp.
T1Hier_vol_bn_str_ca_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
caudate
t1.vol.bn.str.ca.leftdp.
T1Hier_vol_bn_str_ca_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
caudate
t1.vol.bn.str.ca.rightdp.
T1Hier_vol_bn_str_pu_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
putamen
t1.vol.bn.str.pu.leftdp.
T1Hier_vol_bn_str_pu_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
putamen
t1.vol.bn.str.pu.rightdp.
T1Hier_vol_mtg_rn_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
red nucleus
t1.vol.mtg.rn.leftdp.
T1Hier_vol_mtg_rn_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
red nucleus
t1.vol.mtg.rn.rightdp.
T1Hier_vol_mtg_sn_snc_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.leftdp.
T1Hier_vol_mtg_sn_snc_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.rightdp.
T1Hier_vol_mtg_sn_snr_leftdeep_cit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.leftdp.
T1Hier_vol_mtg_sn_snr_rightdeep_cit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.rightdp.
T1Hier_vol_referenceregion_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
​
t1.vol.referenceregion.leftdp.
T1Hier_vol_referenceregion_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
​
t1.vol.referenceregion.rightdp.
T1Hier_area_bn_gp_gpe_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus externa
t1.area.bn.gp.gpe.leftdp.
T1Hier_area_bn_gp_gpe_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus externa
t1.area.bn.gp.gpe.rightdp.
T1Hier_area_bn_gp_gpi_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus interna
t1.area.bn.gp.gpi.leftdp.
T1Hier_area_bn_gp_gpi_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus interna
t1.area.bn.gp.gpi.rightdp.
T1Hier_area_bn_str_ca_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
caudate
t1.area.bn.str.ca.leftdp.
T1Hier_area_bn_str_ca_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
caudate
t1.area.bn.str.ca.rightdp.
T1Hier_area_bn_str_pu_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
putamen
t1.area.bn.str.pu.leftdp.
T1Hier_area_bn_str_pu_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
putamen
t1.area.bn.str.pu.rightdp.
T1Hier_area_mtg_rn_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
red nucleus
t1.area.mtg.rn.leftdp.
T1Hier_area_mtg_rn_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
red nucleus
t1.area.mtg.rn.rightdp.
T1Hier_area_mtg_sn_snc_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.leftdp.
T1Hier_area_mtg_sn_snc_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.rightdp.
T1Hier_area_mtg_sn_snr_leftdeep_cit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.leftdp.
T1Hier_area_mtg_sn_snr_rightdeep_cit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.rightdp.
T1Hier_area_referenceregion_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
​
t1.area.referenceregion.leftdp.
T1Hier_area_referenceregion_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
​
t1.area.referenceregion.rightdp.
T1Hier_thk_bn_gp_gpe_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus externa
t1.thk.bn.gp.gpe.leftdp.
T1Hier_thk_bn_gp_gpe_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus externa
t1.thk.bn.gp.gpe.rightdp.
T1Hier_thk_bn_gp_gpi_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus interna
t1.thk.bn.gp.gpi.leftdp.
T1Hier_thk_bn_gp_gpi_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus interna
t1.thk.bn.gp.gpi.rightdp.
T1Hier_thk_bn_str_ca_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
caudate
t1.thk.bn.str.ca.leftdp.
T1Hier_thk_bn_str_ca_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
caudate
t1.thk.bn.str.ca.rightdp.
T1Hier_thk_bn_str_pu_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
putamen
t1.thk.bn.str.pu.leftdp.
T1Hier_thk_bn_str_pu_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
putamen
t1.thk.bn.str.pu.rightdp.
T1Hier_thk_mtg_rn_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
red nucleus
t1.thk.mtg.rn.leftdp.
T1Hier_thk_mtg_rn_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
red nucleus
t1.thk.mtg.rn.rightdp.
T1Hier_thk_mtg_sn_snc_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.leftdp.
T1Hier_thk_mtg_sn_snc_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.rightdp.
T1Hier_thk_mtg_sn_snr_leftdeep_cit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.leftdp.
T1Hier_thk_mtg_sn_snr_rightdeep_cit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.rightdp.
T1Hier_thk_referenceregion_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
​
t1.thk.referenceregion.leftdp.
T1Hier_thk_referenceregion_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
​
t1.thk.referenceregion.rightdp.
T1Hier_vol_mtg_sn_snc_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.leftsnseg
T1Hier_vol_mtg_sn_snc_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.rightsnseg
T1Hier_vol_mtg_sn_snr_leftsnseg
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.leftsnseg
T1Hier_vol_mtg_sn_snr_rightsnseg
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.rightsnseg
T1Hier_vol_referenceregion_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/volume
​
t1.vol.referenceregion.leftsnseg
T1Hier_vol_referenceregion_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/volume
​
t1.vol.referenceregion.rightsnseg
T1Hier_area_mtg_sn_snc_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.leftsnseg
T1Hier_area_mtg_sn_snc_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.rightsnseg
T1Hier_area_mtg_sn_snr_leftsnseg
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.leftsnseg
T1Hier_area_mtg_sn_snr_rightsnseg
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.rightsnseg
T1Hier_area_referenceregion_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/area
​
t1.area.referenceregion.leftsnseg
T1Hier_area_referenceregion_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/area
​
t1.area.referenceregion.rightsnseg
T1Hier_thk_mtg_sn_snc_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.leftsnseg
T1Hier_thk_mtg_sn_snc_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.rightsnseg
T1Hier_thk_mtg_sn_snr_leftsnseg
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.leftsnseg
T1Hier_thk_mtg_sn_snr_rightsnseg
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.rightsnseg
T1Hier_thk_referenceregion_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/thickness
​
t1.thk.referenceregion.leftsnseg
T1Hier_thk_referenceregion_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/thickness
​
t1.thk.referenceregion.rightsnseg
T1Hier_vol_cleanupbrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.cleanup.bst
T1Hier_vol_medullabrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.medulla.bst
T1Hier_vol_midbrainbrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.midbrain.bst
T1Hier_vol_ponsbrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.pons.bst
T1Hier_area_cleanupbrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.cleanup.bst
T1Hier_area_medullabrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.medulla.bst
T1Hier_area_midbrainbrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.midbrain.bst
T1Hier_area_ponsbrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.pons.bst
T1Hier_thk_cleanupbrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.cleanup.bst
T1Hier_thk_medullabrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.medulla.bst
T1Hier_thk_midbrainbrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.midbrain.bst
T1Hier_thk_ponsbrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.pons.bst
T1Hier_vol_l_crus_icerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.crus.icerebellum
T1Hier_vol_l_crus_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.crus.iicerebellum
T1Hier_vol_l_iiicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.iiicerebellum
T1Hier_vol_l_ivcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.ivcerebellum
T1Hier_vol_l_ixcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.ixcerebellum
T1Hier_vol_l_i_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.i.iicerebellum
T1Hier_vol_l_vcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.vcerebellum
T1Hier_vol_l_vicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.vicerebellum
T1Hier_vol_l_viibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.viibcerebellum
T1Hier_vol_l_viiiacerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.viiiacerebellum
T1Hier_vol_l_viiibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.viiibcerebellum
T1Hier_vol_l_xcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.xcerebellum
T1Hier_vol_r_crus_icerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.crus.icerebellum
T1Hier_vol_r_crus_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.crus.iicerebellum
T1Hier_vol_r_iiicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.iiicerebellum
T1Hier_vol_r_ivcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.ivcerebellum
T1Hier_vol_r_ixcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.ixcerebellum
T1Hier_vol_r_i_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.i.iicerebellum
T1Hier_vol_r_vcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.vcerebellum
T1Hier_vol_r_vicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.vicerebellum
T1Hier_vol_r_viibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.viibcerebellum
T1Hier_vol_r_viiiacerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.viiiacerebellum
T1Hier_vol_r_viiibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.viiibcerebellum
T1Hier_vol_r_xcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.xcerebellum
T1Hier_area_l_crus_icerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.crus.icerebellum
T1Hier_area_l_crus_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.crus.iicerebellum
T1Hier_area_l_iiicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.iiicerebellum
T1Hier_area_l_ivcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.ivcerebellum
T1Hier_area_l_ixcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.ixcerebellum
T1Hier_area_l_i_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.i.iicerebellum
T1Hier_area_l_vcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.vcerebellum
T1Hier_area_l_vicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.vicerebellum
T1Hier_area_l_viibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.viibcerebellum
T1Hier_area_l_viiiacerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.viiiacerebellum
T1Hier_area_l_viiibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.viiibcerebellum
T1Hier_area_l_xcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.xcerebellum
T1Hier_area_r_crus_icerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.crus.icerebellum
T1Hier_area_r_crus_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.crus.iicerebellum
T1Hier_area_r_iiicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.iiicerebellum
T1Hier_area_r_ivcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.ivcerebellum
T1Hier_area_r_ixcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.ixcerebellum
T1Hier_area_r_i_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.i.iicerebellum
T1Hier_area_r_vcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.vcerebellum
T1Hier_area_r_vicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.vicerebellum
T1Hier_area_r_viibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.viibcerebellum
T1Hier_area_r_viiiacerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.viiiacerebellum
T1Hier_area_r_viiibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.viiibcerebellum
T1Hier_area_r_xcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.xcerebellum
T1Hier_thk_l_crus_icerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.crus.icerebellum
T1Hier_thk_l_crus_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.crus.iicerebellum
T1Hier_thk_l_iiicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.iiicerebellum
T1Hier_thk_l_ivcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.ivcerebellum
T1Hier_thk_l_ixcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.ixcerebellum
T1Hier_thk_l_i_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.i.iicerebellum
T1Hier_thk_l_vcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.vcerebellum
T1Hier_thk_l_vicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.vicerebellum
T1Hier_thk_l_viibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.viibcerebellum
T1Hier_thk_l_viiiacerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.viiiacerebellum
T1Hier_thk_l_viiibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.viiibcerebellum
T1Hier_thk_l_xcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.xcerebellum
T1Hier_thk_r_crus_icerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.crus.icerebellum
T1Hier_thk_r_crus_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.crus.iicerebellum
T1Hier_thk_r_iiicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.iiicerebellum
T1Hier_thk_r_ivcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.ivcerebellum
T1Hier_thk_r_ixcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.ixcerebellum
T1Hier_thk_r_i_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.i.iicerebellum
T1Hier_thk_r_vcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.vcerebellum
T1Hier_thk_r_vicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.vicerebellum
T1Hier_thk_r_viibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.viibcerebellum
T1Hier_thk_r_viiiacerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.viiiacerebellum
T1Hier_thk_r_viiibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.viiibcerebellum
T1Hier_thk_r_xcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.xcerebellum
T1Hier_RandBasisProj01
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj01
t1.randbasisproj01
T1Hier_RandBasisProj02
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj02
t1.randbasisproj02
T1Hier_RandBasisProj03
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj03
t1.randbasisproj03
T1Hier_RandBasisProj04
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj04
t1.randbasisproj04
T1Hier_RandBasisProj05
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj05
t1.randbasisproj05
T1Hier_RandBasisProj06
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj06
t1.randbasisproj06
T1Hier_RandBasisProj07
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj07
t1.randbasisproj07
T1Hier_RandBasisProj08
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj08
t1.randbasisproj08
T1Hier_RandBasisProj09
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj09
t1.randbasisproj09
T1Hier_RandBasisProj10
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj10
t1.randbasisproj10
T1Hier_RandBasisProjPos01
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos01
t1.randbasisprojpos01
T1Hier_RandBasisProjPos02
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos02
t1.randbasisprojpos02
T1Hier_RandBasisProjPos03
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos03
t1.randbasisprojpos03
T1Hier_RandBasisProjPos04
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos04
t1.randbasisprojpos04
T1Hier_RandBasisProjPos05
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos05
t1.randbasisprojpos05
T1Hier_RandBasisProjPos06
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos06
t1.randbasisprojpos06
T1Hier_RandBasisProjPos07
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos07
t1.randbasisprojpos07
T1Hier_RandBasisProjPos08
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos08
t1.randbasisprojpos08
T1Hier_RandBasisProjPos09
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos09
t1.randbasisprojpos09
T1Hier_RandBasisProjPos10
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos10
t1.randbasisprojpos10
T1Hier_loop_outlier_probability
T1 hierarchical processing
​
quality control metrics
QC
loop outlier probability
t1.loop.outlier.probability
T1Hier_mhdist
T1 hierarchical processing
​
quality control metrics
QC
mhdist
t1.mhdist
T1Hier_templateL1
T1 hierarchical processing
​
quality control metrics
QC
templateL1
t1.templatel1
T1Hier_evratio
T1 hierarchical processing
​
quality control metrics
QC
evratio
t1.evratio
T1Hier_resnetGrade
T1 hierarchical processing
​
quality control metrics
QC
resnetGrade
t1.resnetgrade
T1w_mean_background
T1 DiReCT thickness processing
​
ANTs
Regional average of DiReCT estimated thickness
​
t1vth.background
T1w_mean_left_caudal_anterior_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal anterior cingulate
t1vth.left.caudal.ant.cingulate
T1w_mean_left_caudal_middle_frontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal middle frontal
t1vth.left.caudal.middle.frontal
T1w_mean_left_cuneus
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
cuneus
t1vth.left.cuneus
T1w_mean_left_entorhinal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
entorhinal
t1vth.left.entorhinal
T1w_mean_left_fusiform
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
fusiform
t1vth.left.fusiform
T1w_mean_left_inferior_parietal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior parietal
t1vth.left.inf.parietal
T1w_mean_left_inferior_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior temporal
t1vth.left.inf.temporal
T1w_mean_left_insula
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
insula
t1vth.left.insula
T1w_mean_left_isthmus_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
isthmus cingulate
t1vth.left.isthmus.cingulate
T1w_mean_left_lateral_occipital
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral occipital
t1vth.left.lateral.occipital
T1w_mean_left_lateral_orbitofrontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral orbitofrontal
t1vth.left.lateral.orbitofrontal
T1w_mean_left_lingual
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lingual
t1vth.left.lingual
T1w_mean_left_medial_orbitofrontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
medial orbitofrontal
t1vth.left.medial.orbitofrontal
T1w_mean_left_middle_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
middle temporal
t1vth.left.middle.temporal
T1w_mean_left_paracentral
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
paracentral
t1vth.left.paracent
T1w_mean_left_parahippocampal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
parahippocampal
t1vth.left.parahippocampal
T1w_mean_left_pars_opercularis
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars opercularis
t1vth.left.pars.opercularis
T1w_mean_left_pars_orbitalis
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars orbitalis
t1vth.left.pars.orbitalis
T1w_mean_left_pars_triangularis
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars triangularis
t1vth.left.pars.triangularis
T1w_mean_left_pericalcarine
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pericalcarine
t1vth.left.pericalcarine
T1w_mean_left_postcentral
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
postcentral
t1vth.left.postcent
T1w_mean_left_posterior_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
posterior cingulate
t1vth.left.post.cingulate
T1w_mean_left_precentral
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precentral
t1vth.left.precent
T1w_mean_left_precuneus
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precuneus
t1vth.left.precuneus
T1w_mean_left_rostral_anterior_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral anterior cingulate
t1vth.left.rostral.ant.cingulate
T1w_mean_left_rostral_middle_frontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral middle frontal
t1vth.left.rostral.middle.frontal
T1w_mean_left_superior_frontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior frontal
t1vth.left.sup.frontal
T1w_mean_left_superior_parietal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior parietal
t1vth.left.sup.parietal
T1w_mean_left_superior_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior temporal
t1vth.left.sup.temporal
T1w_mean_left_supramarginal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
supramarginal
t1vth.left.supramarginal
T1w_mean_left_transverse_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
transverse temporal
t1vth.left.transverse.temporal
T1w_mean_right_caudal_anterior_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal anterior cingulate
t1vth.right.caudal.ant.cingulate
T1w_mean_right_caudal_middle_frontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal middle frontal
t1vth.right.caudal.middle.frontal
T1w_mean_right_cuneus
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
cuneus
t1vth.right.cuneus
T1w_mean_right_entorhinal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
entorhinal
t1vth.right.entorhinal
T1w_mean_right_fusiform
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
fusiform
t1vth.right.fusiform
T1w_mean_right_inferior_parietal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior parietal
t1vth.right.inf.parietal
T1w_mean_right_inferior_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior temporal
t1vth.right.inf.temporal
T1w_mean_right_insula
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
insula
t1vth.right.insula
T1w_mean_right_isthmus_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
isthmus cingulate
t1vth.right.isthmus.cingulate
T1w_mean_right_lateral_occipital
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral occipital
t1vth.right.lateral.occipital
T1w_mean_right_lateral_orbitofrontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral orbitofrontal
t1vth.right.lateral.orbitofrontal
T1w_mean_right_lingual
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lingual
t1vth.right.lingual
T1w_mean_right_medial_orbitofrontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
medial orbitofrontal
t1vth.right.medial.orbitofrontal
T1w_mean_right_middle_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
middle temporal
t1vth.right.middle.temporal
T1w_mean_right_paracentral
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
paracentral
t1vth.right.paracent
T1w_mean_right_parahippocampal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
parahippocampal
t1vth.right.parahippocampal
T1w_mean_right_pars_opercularis
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars opercularis
t1vth.right.pars.opercularis
T1w_mean_right_pars_orbitalis
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars orbitalis
t1vth.right.pars.orbitalis
T1w_mean_right_pars_triangularis
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars triangularis
t1vth.right.pars.triangularis
T1w_mean_right_pericalcarine
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pericalcarine
t1vth.right.pericalcarine
T1w_mean_right_postcentral
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
postcentral
t1vth.right.postcent
T1w_mean_right_posterior_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
posterior cingulate
t1vth.right.post.cingulate
T1w_mean_right_precentral
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precentral
t1vth.right.precent
T1w_mean_right_precuneus
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precuneus
t1vth.right.precuneus
T1w_mean_right_rostral_anterior_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral anterior cingulate
t1vth.right.rostral.ant.cingulate
T1w_mean_right_rostral_middle_frontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral middle frontal
t1vth.right.rostral.middle.frontal
T1w_mean_right_superior_frontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior frontal
t1vth.right.sup.frontal
T1w_mean_right_superior_parietal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior parietal
t1vth.right.sup.parietal
T1w_mean_right_superior_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior temporal
t1vth.right.sup.temporal
T1w_mean_right_supramarginal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
supramarginal
t1vth.right.supramarginal
T1w_mean_right_transverse_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
transverse temporal
t1vth.right.transverse.temporal
T2Flair_flair_mean
Flair
​
ANTs
​
​
t2flair.flair.mean
T2Flair_WMH_probability_map_mean
Flair
​
ANTs
​
​
t2flair.wmh.probability.map.mean
T2Flair_WMH_posterior_probability_map_mean
Flair
​
ANTs
​
​
t2flair.wmh.post.probability.map.mean
T2Flair_wmh_mass
Flair
​
ANTs
​
​
t2flair.wmh.mass
T2Flair_wmh_mass_prior
Flair
​
ANTs
​
​
t2flair.wmh.mass.prior
T2Flair_wmh_evr
Flair
​
ANTs
QC
​
t2flair.wmh.evr
rsfMRI_fcnxpro122_paramset
restingStatefMRI
​
yeo_homotopic
parameter id
​
rsf.p1.paramset
rsfMRI_fcnxpro122_upsampling
restingStatefMRI
​
yeo_homotopic
upsampling parameter
​
rsf.p1.upsampling
rsfMRI_fcnxpro122_meanBold_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.meanbold.mean
rsfMRI_fcnxpro122_TempPar_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.temppar.mean
rsfMRI_fcnxpro122_DefaultC_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.defaultc.mean
rsfMRI_fcnxpro122_DefaultB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.defaultb.mean
rsfMRI_fcnxpro122_DefaultA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.defaulta.mean
rsfMRI_fcnxpro122_ContC_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.contc.mean
rsfMRI_fcnxpro122_ContB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.contb.mean
rsfMRI_fcnxpro122_ContA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.conta.mean
rsfMRI_fcnxpro122_LimbicA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.limbica.mean
rsfMRI_fcnxpro122_LimbicB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.limbicb.mean
rsfMRI_fcnxpro122_SalVentAttnB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.salventattnb.mean
rsfMRI_fcnxpro122_SalVentAttnA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.salventattna.mean
rsfMRI_fcnxpro122_DorsAttnB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.dorsattnb.mean
rsfMRI_fcnxpro122_DorsAttnA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.dorsattna.mean
rsfMRI_fcnxpro122_SomMotB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.sommotb.mean
rsfMRI_fcnxpro122_SomMotA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.sommota.mean
rsfMRI_fcnxpro122_VisPeri_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.visperi.mean
rsfMRI_fcnxpro122_VisCent_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.viscent.mean
rsfMRI_fcnxpro122_Striatum_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.striatum.mean
rsfMRI_fcnxpro122_Dopamine_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.dopamine.mean
rsfMRI_fcnxpro122_CITLimbic_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.citlimbic.mean
rsfMRI_fcnxpro122_BasalGanglia_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.basalganglia.mean
rsfMRI_fcnxpro122_MidBrain_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.midbrain.mean
rsfMRI_fcnxpro122_fmri_template_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.fmri.template.mean
rsfMRI_fcnxpro122_brainmask_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.brainmask.mean
rsfMRI_fcnxpro122_gmmask_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.gmmask.mean
rsfMRI_fcnxpro122_alff_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.alff.mean
rsfMRI_fcnxpro122_alff_sd
restingStatefMRI
​
yeo_homotopic
global sd of image
​
rsf.p1.alff.sd
rsfMRI_fcnxpro122_falff_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.falff.mean
rsfMRI_fcnxpro122_falff_sd
restingStatefMRI
​
yeo_homotopic
global sd of image
​
rsf.p1.falff.sd
rsfMRI_fcnxpro122_falffPoint000_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint000.iplleft
rsfMRI_fcnxpro122_alffPoint000_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint000.iplleft
rsfMRI_fcnxpro122_perafPoint000_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint000.iplleft
rsfMRI_fcnxpro122_falffPoint001_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint001.stleft
rsfMRI_fcnxpro122_alffPoint001_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint001.stleft
rsfMRI_fcnxpro122_perafPoint001_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint001.stleft
rsfMRI_fcnxpro122_falffPoint002_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint002.stleft
rsfMRI_fcnxpro122_alffPoint002_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint002.stleft
rsfMRI_fcnxpro122_perafPoint002_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint002.stleft
rsfMRI_fcnxpro122_falffPoint003_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint003.tempoccleft
rsfMRI_fcnxpro122_alffPoint003_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint003.tempoccleft
rsfMRI_fcnxpro122_perafPoint003_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint003.tempoccleft
rsfMRI_fcnxpro122_falffPoint004_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint004.templeft
rsfMRI_fcnxpro122_alffPoint004_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint004.templeft
rsfMRI_fcnxpro122_perafPoint004_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint004.templeft
rsfMRI_fcnxpro122_falffPoint005_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint005.templeft
rsfMRI_fcnxpro122_alffPoint005_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint005.templeft
rsfMRI_fcnxpro122_perafPoint005_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint005.templeft
rsfMRI_fcnxpro122_falffPoint006_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint006.exstrinfleft
rsfMRI_fcnxpro122_alffPoint006_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint006.exstrinfleft
rsfMRI_fcnxpro122_perafPoint006_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint006.exstrinfleft
rsfMRI_fcnxpro122_falffPoint007_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint007.iplleft
rsfMRI_fcnxpro122_alffPoint007_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint007.iplleft
rsfMRI_fcnxpro122_perafPoint007_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint007.iplleft
rsfMRI_fcnxpro122_falffPoint008_PHCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint008.phcleft
rsfMRI_fcnxpro122_alffPoint008_PHCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint008.phcleft
rsfMRI_fcnxpro122_perafPoint008_PHCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint008.phcleft
rsfMRI_fcnxpro122_falffPoint009_PHCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint009.phcleft
rsfMRI_fcnxpro122_alffPoint009_PHCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint009.phcleft
rsfMRI_fcnxpro122_perafPoint009_PHCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint009.phcleft
rsfMRI_fcnxpro122_falffPoint010_PHCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint010.phcleft
rsfMRI_fcnxpro122_alffPoint010_PHCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint010.phcleft
rsfMRI_fcnxpro122_perafPoint010_PHCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint010.phcleft
rsfMRI_fcnxpro122_falffPoint011_RSCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint011.rscleft
rsfMRI_fcnxpro122_alffPoint011_RSCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint011.rscleft
rsfMRI_fcnxpro122_perafPoint011_RSCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint011.rscleft
rsfMRI_fcnxpro122_falffPoint012_RSCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint012.rscleft
rsfMRI_fcnxpro122_alffPoint012_RSCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint012.rscleft
rsfMRI_fcnxpro122_perafPoint012_RSCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint012.rscleft
rsfMRI_fcnxpro122_falffPoint013_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint013.iplleft
rsfMRI_fcnxpro122_alffPoint013_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint013.iplleft
rsfMRI_fcnxpro122_perafPoint013_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint013.iplleft
rsfMRI_fcnxpro122_falffPoint014_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint014.iplleft
rsfMRI_fcnxpro122_alffPoint014_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint014.iplleft
rsfMRI_fcnxpro122_perafPoint014_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint014.iplleft
rsfMRI_fcnxpro122_falffPoint015_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint015.iplleft
rsfMRI_fcnxpro122_alffPoint015_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint015.iplleft
rsfMRI_fcnxpro122_perafPoint015_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint015.iplleft
rsfMRI_fcnxpro122_falffPoint016_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint016.iplleft
rsfMRI_fcnxpro122_alffPoint016_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint016.iplleft
rsfMRI_fcnxpro122_perafPoint016_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint016.iplleft
rsfMRI_fcnxpro122_falffPoint017_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint017.pfcdleft
rsfMRI_fcnxpro122_alffPoint017_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint017.pfcdleft
rsfMRI_fcnxpro122_perafPoint017_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint017.pfcdleft
rsfMRI_fcnxpro122_falffPoint018_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint018.pfcdleft
rsfMRI_fcnxpro122_alffPoint018_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint018.pfcdleft
rsfMRI_fcnxpro122_perafPoint018_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint018.pfcdleft
rsfMRI_fcnxpro122_falffPoint019_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint019.pfcdleft
rsfMRI_fcnxpro122_alffPoint019_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint019.pfcdleft
rsfMRI_fcnxpro122_perafPoint019_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint019.pfcdleft
rsfMRI_fcnxpro122_falffPoint020_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint020.pfcdleft
rsfMRI_fcnxpro122_alffPoint020_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint020.pfcdleft
rsfMRI_fcnxpro122_perafPoint020_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint020.pfcdleft
rsfMRI_fcnxpro122_falffPoint021_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint021.pfcdleft
rsfMRI_fcnxpro122_alffPoint021_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint021.pfcdleft
rsfMRI_fcnxpro122_perafPoint021_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint021.pfcdleft
rsfMRI_fcnxpro122_falffPoint022_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint022.pfcdleft
rsfMRI_fcnxpro122_alffPoint022_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint022.pfcdleft
rsfMRI_fcnxpro122_perafPoint022_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint022.pfcdleft
rsfMRI_fcnxpro122_falffPoint023_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint023.pfcdleft
rsfMRI_fcnxpro122_alffPoint023_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint023.pfcdleft
rsfMRI_fcnxpro122_perafPoint023_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint023.pfcdleft
rsfMRI_fcnxpro122_falffPoint024_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint024.pfclleft
rsfMRI_fcnxpro122_alffPoint024_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint024.pfclleft
rsfMRI_fcnxpro122_perafPoint024_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint024.pfclleft
rsfMRI_fcnxpro122_falffPoint025_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint025.pfclleft
rsfMRI_fcnxpro122_alffPoint025_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint025.pfclleft
rsfMRI_fcnxpro122_perafPoint025_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint025.pfclleft
rsfMRI_fcnxpro122_falffPoint026_PFCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint026.pfcvleft
rsfMRI_fcnxpro122_alffPoint026_PFCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint026.pfcvleft
rsfMRI_fcnxpro122_perafPoint026_PFCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint026.pfcvleft
rsfMRI_fcnxpro122_falffPoint027_PFCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint027.pfcvleft
rsfMRI_fcnxpro122_alffPoint027_PFCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint027.pfcvleft
rsfMRI_fcnxpro122_perafPoint027_PFCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint027.pfcvleft
rsfMRI_fcnxpro122_falffPoint028_PFCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint028.pfcvleft
rsfMRI_fcnxpro122_alffPoint028_PFCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint028.pfcvleft
rsfMRI_fcnxpro122_perafPoint028_PFCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint028.pfcvleft
rsfMRI_fcnxpro122_falffPoint029_PFCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint029.pfcvleft
rsfMRI_fcnxpro122_alffPoint029_PFCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint029.pfcvleft
rsfMRI_fcnxpro122_perafPoint029_PFCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint029.pfcvleft
rsfMRI_fcnxpro122_falffPoint030_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint030.temppoleleft
rsfMRI_fcnxpro122_alffPoint030_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint030.temppoleleft
rsfMRI_fcnxpro122_perafPoint030_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint030.temppoleleft
rsfMRI_fcnxpro122_falffPoint031_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint031.templeft
rsfMRI_fcnxpro122_alffPoint031_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint031.templeft
rsfMRI_fcnxpro122_perafPoint031_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint031.templeft
rsfMRI_fcnxpro122_falffPoint032_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint032.templeft
rsfMRI_fcnxpro122_alffPoint032_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint032.templeft
rsfMRI_fcnxpro122_perafPoint032_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint032.templeft
rsfMRI_fcnxpro122_falffPoint033_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint033.templeft
rsfMRI_fcnxpro122_alffPoint033_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint033.templeft
rsfMRI_fcnxpro122_perafPoint033_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint033.templeft
rsfMRI_fcnxpro122_falffPoint034_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint034.templeft
rsfMRI_fcnxpro122_alffPoint034_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint034.templeft
rsfMRI_fcnxpro122_perafPoint034_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint034.templeft
rsfMRI_fcnxpro122_falffPoint035_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint035.templeft
rsfMRI_fcnxpro122_alffPoint035_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint035.templeft
rsfMRI_fcnxpro122_perafPoint035_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint035.templeft
rsfMRI_fcnxpro122_falffPoint036_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint036.templeft
rsfMRI_fcnxpro122_alffPoint036_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint036.templeft
rsfMRI_fcnxpro122_perafPoint036_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint036.templeft
rsfMRI_fcnxpro122_falffPoint037_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint037.templeft
rsfMRI_fcnxpro122_alffPoint037_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint037.templeft
rsfMRI_fcnxpro122_perafPoint037_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint037.templeft
rsfMRI_fcnxpro122_falffPoint038_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint038.templeft
rsfMRI_fcnxpro122_alffPoint038_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint038.templeft
rsfMRI_fcnxpro122_perafPoint038_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint038.templeft
rsfMRI_fcnxpro122_falffPoint039_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint039.templeft
rsfMRI_fcnxpro122_alffPoint039_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint039.templeft
rsfMRI_fcnxpro122_perafPoint039_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint039.templeft
rsfMRI_fcnxpro122_falffPoint040_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint040.templeft
rsfMRI_fcnxpro122_alffPoint040_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint040.templeft
rsfMRI_fcnxpro122_perafPoint040_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint040.templeft
rsfMRI_fcnxpro122_falffPoint041_FPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint041.fpoleleft
rsfMRI_fcnxpro122_alffPoint041_FPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint041.fpoleleft
rsfMRI_fcnxpro122_perafPoint041_FPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint041.fpoleleft
rsfMRI_fcnxpro122_falffPoint042_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint042.iplleft
rsfMRI_fcnxpro122_alffPoint042_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint042.iplleft
rsfMRI_fcnxpro122_perafPoint042_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint042.iplleft
rsfMRI_fcnxpro122_falffPoint043_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint043.iplleft
rsfMRI_fcnxpro122_alffPoint043_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint043.iplleft
rsfMRI_fcnxpro122_perafPoint043_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint043.iplleft
rsfMRI_fcnxpro122_falffPoint044_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint044.iplleft
rsfMRI_fcnxpro122_alffPoint044_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint044.iplleft
rsfMRI_fcnxpro122_perafPoint044_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint044.iplleft
rsfMRI_fcnxpro122_falffPoint045_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint045.pccleft
rsfMRI_fcnxpro122_alffPoint045_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint045.pccleft
rsfMRI_fcnxpro122_perafPoint045_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint045.pccleft
rsfMRI_fcnxpro122_falffPoint046_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint046.pccleft
rsfMRI_fcnxpro122_alffPoint046_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint046.pccleft
rsfMRI_fcnxpro122_perafPoint046_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint046.pccleft
rsfMRI_fcnxpro122_falffPoint047_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint047.pccleft
rsfMRI_fcnxpro122_alffPoint047_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint047.pccleft
rsfMRI_fcnxpro122_perafPoint047_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint047.pccleft
rsfMRI_fcnxpro122_falffPoint048_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint048.pccleft
rsfMRI_fcnxpro122_alffPoint048_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint048.pccleft
rsfMRI_fcnxpro122_perafPoint048_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint048.pccleft
rsfMRI_fcnxpro122_falffPoint049_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint049.pccleft
rsfMRI_fcnxpro122_alffPoint049_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint049.pccleft
rsfMRI_fcnxpro122_perafPoint049_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint049.pccleft
rsfMRI_fcnxpro122_falffPoint050_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint050.pccleft
rsfMRI_fcnxpro122_alffPoint050_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint050.pccleft
rsfMRI_fcnxpro122_perafPoint050_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint050.pccleft
rsfMRI_fcnxpro122_falffPoint051_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint051.pccleft
rsfMRI_fcnxpro122_alffPoint051_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint051.pccleft
rsfMRI_fcnxpro122_perafPoint051_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint051.pccleft
rsfMRI_fcnxpro122_falffPoint052_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint052.pfcdleft
rsfMRI_fcnxpro122_alffPoint052_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint052.pfcdleft
rsfMRI_fcnxpro122_perafPoint052_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint052.pfcdleft
rsfMRI_fcnxpro122_falffPoint053_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint053.pfcdleft
rsfMRI_fcnxpro122_alffPoint053_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint053.pfcdleft
rsfMRI_fcnxpro122_perafPoint053_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint053.pfcdleft
rsfMRI_fcnxpro122_falffPoint054_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint054.pfcdleft
rsfMRI_fcnxpro122_alffPoint054_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint054.pfcdleft
rsfMRI_fcnxpro122_perafPoint054_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint054.pfcdleft
rsfMRI_fcnxpro122_falffPoint055_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint055.pfcdleft
rsfMRI_fcnxpro122_alffPoint055_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint055.pfcdleft
rsfMRI_fcnxpro122_perafPoint055_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint055.pfcdleft
rsfMRI_fcnxpro122_falffPoint056_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint056.pfcmleft
rsfMRI_fcnxpro122_alffPoint056_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint056.pfcmleft
rsfMRI_fcnxpro122_perafPoint056_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint056.pfcmleft
rsfMRI_fcnxpro122_falffPoint057_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint057.pfcmleft
rsfMRI_fcnxpro122_alffPoint057_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint057.pfcmleft
rsfMRI_fcnxpro122_perafPoint057_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint057.pfcmleft
rsfMRI_fcnxpro122_falffPoint058_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint058.pfcmleft
rsfMRI_fcnxpro122_alffPoint058_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint058.pfcmleft
rsfMRI_fcnxpro122_perafPoint058_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint058.pfcmleft
rsfMRI_fcnxpro122_falffPoint059_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint059.pfcmleft
rsfMRI_fcnxpro122_alffPoint059_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint059.pfcmleft
rsfMRI_fcnxpro122_perafPoint059_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint059.pfcmleft
rsfMRI_fcnxpro122_falffPoint060_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint060.pfcmleft
rsfMRI_fcnxpro122_alffPoint060_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint060.pfcmleft
rsfMRI_fcnxpro122_perafPoint060_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint060.pfcmleft
rsfMRI_fcnxpro122_falffPoint061_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint061.pcunleft
rsfMRI_fcnxpro122_alffPoint061_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint061.pcunleft
rsfMRI_fcnxpro122_perafPoint061_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint061.pcunleft
rsfMRI_fcnxpro122_falffPoint062_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint062.pcunleft
rsfMRI_fcnxpro122_alffPoint062_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint062.pcunleft
rsfMRI_fcnxpro122_perafPoint062_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint062.pcunleft
rsfMRI_fcnxpro122_falffPoint063_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint063.pcunleft
rsfMRI_fcnxpro122_alffPoint063_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint063.pcunleft
rsfMRI_fcnxpro122_perafPoint063_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint063.pcunleft
rsfMRI_fcnxpro122_falffPoint064_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint064.pccleft
rsfMRI_fcnxpro122_alffPoint064_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint064.pccleft
rsfMRI_fcnxpro122_perafPoint064_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint064.pccleft
rsfMRI_fcnxpro122_falffPoint065_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint065.splleft
rsfMRI_fcnxpro122_alffPoint065_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint065.splleft
rsfMRI_fcnxpro122_perafPoint065_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint065.splleft
rsfMRI_fcnxpro122_falffPoint066_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint066.pcunleft
rsfMRI_fcnxpro122_alffPoint066_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint066.pcunleft
rsfMRI_fcnxpro122_perafPoint066_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint066.pcunleft
rsfMRI_fcnxpro122_falffPoint067_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint067.pcunleft
rsfMRI_fcnxpro122_alffPoint067_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint067.pcunleft
rsfMRI_fcnxpro122_perafPoint067_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint067.pcunleft
rsfMRI_fcnxpro122_falffPoint068_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint068.pcunleft
rsfMRI_fcnxpro122_alffPoint068_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint068.pcunleft
rsfMRI_fcnxpro122_perafPoint068_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint068.pcunleft
rsfMRI_fcnxpro122_falffPoint069_FPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint069.fpoleleft
rsfMRI_fcnxpro122_alffPoint069_FPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint069.fpoleleft
rsfMRI_fcnxpro122_perafPoint069_FPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint069.fpoleleft
rsfMRI_fcnxpro122_falffPoint070_FPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint070.fpoleleft
rsfMRI_fcnxpro122_alffPoint070_FPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint070.fpoleleft
rsfMRI_fcnxpro122_perafPoint070_FPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint070.fpoleleft
rsfMRI_fcnxpro122_falffPoint071_FrMedleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint071.frmedleft
rsfMRI_fcnxpro122_alffPoint071_FrMedleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint071.frmedleft
rsfMRI_fcnxpro122_perafPoint071_FrMedleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint071.frmedleft
rsfMRI_fcnxpro122_falffPoint072_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint072.iplleft
rsfMRI_fcnxpro122_alffPoint072_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint072.iplleft
rsfMRI_fcnxpro122_perafPoint072_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint072.iplleft
rsfMRI_fcnxpro122_falffPoint073_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint073.ipsleft
rsfMRI_fcnxpro122_alffPoint073_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint073.ipsleft
rsfMRI_fcnxpro122_perafPoint073_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint073.ipsleft
rsfMRI_fcnxpro122_falffPoint074_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint074.ipsleft
rsfMRI_fcnxpro122_alffPoint074_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint074.ipsleft
rsfMRI_fcnxpro122_perafPoint074_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint074.ipsleft
rsfMRI_fcnxpro122_falffPoint075_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint075.pfcdleft
rsfMRI_fcnxpro122_alffPoint075_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint075.pfcdleft
rsfMRI_fcnxpro122_perafPoint075_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint075.pfcdleft
rsfMRI_fcnxpro122_falffPoint076_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint076.pfclleft
rsfMRI_fcnxpro122_alffPoint076_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint076.pfclleft
rsfMRI_fcnxpro122_perafPoint076_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint076.pfclleft
rsfMRI_fcnxpro122_falffPoint077_PFCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint077.pfcvleft
rsfMRI_fcnxpro122_alffPoint077_PFCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint077.pfcvleft
rsfMRI_fcnxpro122_perafPoint077_PFCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint077.pfcvleft
rsfMRI_fcnxpro122_falffPoint078_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint078.templeft
rsfMRI_fcnxpro122_alffPoint078_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint078.templeft
rsfMRI_fcnxpro122_perafPoint078_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint078.templeft
rsfMRI_fcnxpro122_falffPoint079_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint079.templeft
rsfMRI_fcnxpro122_alffPoint079_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint079.templeft
rsfMRI_fcnxpro122_perafPoint079_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint079.templeft
rsfMRI_fcnxpro122_falffPoint080_Cingmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint080.cingmleft
rsfMRI_fcnxpro122_alffPoint080_Cingmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint080.cingmleft
rsfMRI_fcnxpro122_perafPoint080_Cingmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint080.cingmleft
rsfMRI_fcnxpro122_falffPoint081_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint081.ipsleft
rsfMRI_fcnxpro122_alffPoint081_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint081.ipsleft
rsfMRI_fcnxpro122_perafPoint081_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint081.ipsleft
rsfMRI_fcnxpro122_falffPoint082_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint082.ipsleft
rsfMRI_fcnxpro122_alffPoint082_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint082.ipsleft
rsfMRI_fcnxpro122_perafPoint082_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint082.ipsleft
rsfMRI_fcnxpro122_falffPoint083_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint083.ipsleft
rsfMRI_fcnxpro122_alffPoint083_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint083.ipsleft
rsfMRI_fcnxpro122_perafPoint083_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint083.ipsleft
rsfMRI_fcnxpro122_falffPoint084_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint084.ipsleft
rsfMRI_fcnxpro122_alffPoint084_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint084.ipsleft
rsfMRI_fcnxpro122_perafPoint084_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint084.ipsleft
rsfMRI_fcnxpro122_falffPoint085_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint085.ipsleft
rsfMRI_fcnxpro122_alffPoint085_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint085.ipsleft
rsfMRI_fcnxpro122_perafPoint085_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint085.ipsleft
rsfMRI_fcnxpro122_falffPoint086_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint086.pfcdleft
rsfMRI_fcnxpro122_alffPoint086_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint086.pfcdleft
rsfMRI_fcnxpro122_perafPoint086_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint086.pfcdleft
rsfMRI_fcnxpro122_falffPoint087_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint087.pfclleft
rsfMRI_fcnxpro122_alffPoint087_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint087.pfclleft
rsfMRI_fcnxpro122_perafPoint087_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint087.pfclleft
rsfMRI_fcnxpro122_falffPoint088_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint088.pfclleft
rsfMRI_fcnxpro122_alffPoint088_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint088.pfclleft
rsfMRI_fcnxpro122_perafPoint088_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint088.pfclleft
rsfMRI_fcnxpro122_falffPoint089_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint089.pfclleft
rsfMRI_fcnxpro122_alffPoint089_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint089.pfclleft
rsfMRI_fcnxpro122_perafPoint089_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint089.pfclleft
rsfMRI_fcnxpro122_falffPoint090_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint090.pfclleft
rsfMRI_fcnxpro122_alffPoint090_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint090.pfclleft
rsfMRI_fcnxpro122_perafPoint090_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint090.pfclleft
rsfMRI_fcnxpro122_falffPoint091_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint091.pfclleft
rsfMRI_fcnxpro122_alffPoint091_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint091.pfclleft
rsfMRI_fcnxpro122_perafPoint091_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint091.pfclleft
rsfMRI_fcnxpro122_falffPoint092_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint092.pfclleft
rsfMRI_fcnxpro122_alffPoint092_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint092.pfclleft
rsfMRI_fcnxpro122_perafPoint092_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint092.pfclleft
rsfMRI_fcnxpro122_falffPoint093_PrCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint093.prcvleft
rsfMRI_fcnxpro122_alffPoint093_PrCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint093.prcvleft
rsfMRI_fcnxpro122_perafPoint093_PrCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint093.prcvleft
rsfMRI_fcnxpro122_falffPoint094_PrCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint094.prcvleft
rsfMRI_fcnxpro122_alffPoint094_PrCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint094.prcvleft
rsfMRI_fcnxpro122_perafPoint094_PrCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint094.prcvleft
rsfMRI_fcnxpro122_falffPoint095_PrCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint095.prcvleft
rsfMRI_fcnxpro122_alffPoint095_PrCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint095.prcvleft
rsfMRI_fcnxpro122_perafPoint095_PrCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint095.prcvleft
rsfMRI_fcnxpro122_falffPoint096_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint096.splleft
rsfMRI_fcnxpro122_alffPoint096_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint096.splleft
rsfMRI_fcnxpro122_perafPoint096_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint096.splleft
rsfMRI_fcnxpro122_falffPoint097_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint097.tempoccleft
rsfMRI_fcnxpro122_alffPoint097_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint097.tempoccleft
rsfMRI_fcnxpro122_perafPoint097_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint097.tempoccleft
rsfMRI_fcnxpro122_falffPoint098_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint098.insleft
rsfMRI_fcnxpro122_alffPoint098_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint098.insleft
rsfMRI_fcnxpro122_perafPoint098_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint098.insleft
rsfMRI_fcnxpro122_falffPoint099_PHCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint099.phcleft
rsfMRI_fcnxpro122_alffPoint099_PHCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint099.phcleft
rsfMRI_fcnxpro122_perafPoint099_PHCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint099.phcleft
rsfMRI_fcnxpro122_falffPoint100_PHCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint100.phcleft
rsfMRI_fcnxpro122_alffPoint100_PHCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint100.phcleft
rsfMRI_fcnxpro122_perafPoint100_PHCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint100.phcleft
rsfMRI_fcnxpro122_falffPoint101_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint101.stleft
rsfMRI_fcnxpro122_alffPoint101_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint101.stleft
rsfMRI_fcnxpro122_perafPoint101_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint101.stleft
rsfMRI_fcnxpro122_falffPoint102_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint102.temppoleleft
rsfMRI_fcnxpro122_alffPoint102_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint102.temppoleleft
rsfMRI_fcnxpro122_perafPoint102_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint102.temppoleleft
rsfMRI_fcnxpro122_falffPoint103_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint103.temppoleleft
rsfMRI_fcnxpro122_alffPoint103_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint103.temppoleleft
rsfMRI_fcnxpro122_perafPoint103_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint103.temppoleleft
rsfMRI_fcnxpro122_falffPoint104_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint104.temppoleleft
rsfMRI_fcnxpro122_alffPoint104_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint104.temppoleleft
rsfMRI_fcnxpro122_perafPoint104_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint104.temppoleleft
rsfMRI_fcnxpro122_falffPoint105_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint105.temppoleleft
rsfMRI_fcnxpro122_alffPoint105_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint105.temppoleleft
rsfMRI_fcnxpro122_perafPoint105_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint105.temppoleleft
rsfMRI_fcnxpro122_falffPoint106_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint106.temppoleleft
rsfMRI_fcnxpro122_alffPoint106_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint106.temppoleleft
rsfMRI_fcnxpro122_perafPoint106_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint106.temppoleleft
rsfMRI_fcnxpro122_falffPoint107_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint107.templeft
rsfMRI_fcnxpro122_alffPoint107_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint107.templeft
rsfMRI_fcnxpro122_perafPoint107_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint107.templeft
rsfMRI_fcnxpro122_falffPoint108_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint108.templeft
rsfMRI_fcnxpro122_alffPoint108_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint108.templeft
rsfMRI_fcnxpro122_perafPoint108_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint108.templeft
rsfMRI_fcnxpro122_falffPoint109_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint109.templeft
rsfMRI_fcnxpro122_alffPoint109_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint109.templeft
rsfMRI_fcnxpro122_perafPoint109_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint109.templeft
rsfMRI_fcnxpro122_falffPoint110_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint110.templeft
rsfMRI_fcnxpro122_alffPoint110_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint110.templeft
rsfMRI_fcnxpro122_perafPoint110_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint110.templeft
rsfMRI_fcnxpro122_falffPoint111_FPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint111.fpoleleft
rsfMRI_fcnxpro122_alffPoint111_FPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint111.fpoleleft
rsfMRI_fcnxpro122_perafPoint111_FPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint111.fpoleleft
rsfMRI_fcnxpro122_falffPoint112_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint112.ofcleft
rsfMRI_fcnxpro122_alffPoint112_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint112.ofcleft
rsfMRI_fcnxpro122_perafPoint112_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint112.ofcleft
rsfMRI_fcnxpro122_falffPoint113_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint113.ofcleft
rsfMRI_fcnxpro122_alffPoint113_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint113.ofcleft
rsfMRI_fcnxpro122_perafPoint113_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint113.ofcleft
rsfMRI_fcnxpro122_falffPoint114_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint114.ofcleft
rsfMRI_fcnxpro122_alffPoint114_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint114.ofcleft
rsfMRI_fcnxpro122_perafPoint114_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint114.ofcleft
rsfMRI_fcnxpro122_falffPoint115_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint115.ofcleft
rsfMRI_fcnxpro122_alffPoint115_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint115.ofcleft
rsfMRI_fcnxpro122_perafPoint115_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint115.ofcleft
rsfMRI_fcnxpro122_falffPoint116_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint116.ofcleft
rsfMRI_fcnxpro122_alffPoint116_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint116.ofcleft
rsfMRI_fcnxpro122_perafPoint116_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint116.ofcleft
rsfMRI_fcnxpro122_falffPoint117_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint117.ofcleft
rsfMRI_fcnxpro122_alffPoint117_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint117.ofcleft
rsfMRI_fcnxpro122_perafPoint117_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint117.ofcleft
rsfMRI_fcnxpro122_falffPoint118_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint118.pfcmleft
rsfMRI_fcnxpro122_alffPoint118_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint118.pfcmleft
rsfMRI_fcnxpro122_perafPoint118_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint118.pfcmleft
rsfMRI_fcnxpro122_falffPoint119_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint119.pfcmleft
rsfMRI_fcnxpro122_alffPoint119_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint119.pfcmleft
rsfMRI_fcnxpro122_perafPoint119_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint119.pfcmleft
rsfMRI_fcnxpro122_falffPoint120_FrMedleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint120.frmedleft
rsfMRI_fcnxpro122_alffPoint120_FrMedleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint120.frmedleft
rsfMRI_fcnxpro122_perafPoint120_FrMedleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint120.frmedleft
rsfMRI_fcnxpro122_falffPoint121_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint121.insleft
rsfMRI_fcnxpro122_alffPoint121_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint121.insleft
rsfMRI_fcnxpro122_perafPoint121_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint121.insleft
rsfMRI_fcnxpro122_falffPoint122_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint122.insleft
rsfMRI_fcnxpro122_alffPoint122_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint122.insleft
rsfMRI_fcnxpro122_perafPoint122_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint122.insleft
rsfMRI_fcnxpro122_falffPoint123_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint123.insleft
rsfMRI_fcnxpro122_alffPoint123_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint123.insleft
rsfMRI_fcnxpro122_perafPoint123_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint123.insleft
rsfMRI_fcnxpro122_falffPoint124_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint124.pfclleft
rsfMRI_fcnxpro122_alffPoint124_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint124.pfclleft
rsfMRI_fcnxpro122_perafPoint124_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint124.pfclleft
rsfMRI_fcnxpro122_falffPoint125_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint125.pfclleft
rsfMRI_fcnxpro122_alffPoint125_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint125.pfclleft
rsfMRI_fcnxpro122_perafPoint125_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint125.pfclleft
rsfMRI_fcnxpro122_falffPoint126_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint126.pfcmleft
rsfMRI_fcnxpro122_alffPoint126_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint126.pfcmleft
rsfMRI_fcnxpro122_perafPoint126_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint126.pfcmleft
rsfMRI_fcnxpro122_falffPoint127_FrMedleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint127.frmedleft
rsfMRI_fcnxpro122_alffPoint127_FrMedleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint127.frmedleft
rsfMRI_fcnxpro122_perafPoint127_FrMedleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint127.frmedleft
rsfMRI_fcnxpro122_falffPoint128_FrMedleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint128.frmedleft
rsfMRI_fcnxpro122_alffPoint128_FrMedleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint128.frmedleft
rsfMRI_fcnxpro122_perafPoint128_FrMedleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint128.frmedleft
rsfMRI_fcnxpro122_falffPoint129_FrMedleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint129.frmedleft
rsfMRI_fcnxpro122_alffPoint129_FrMedleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint129.frmedleft
rsfMRI_fcnxpro122_perafPoint129_FrMedleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint129.frmedleft
rsfMRI_fcnxpro122_falffPoint130_FrOperleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint130.froperleft
rsfMRI_fcnxpro122_alffPoint130_FrOperleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint130.froperleft
rsfMRI_fcnxpro122_perafPoint130_FrOperleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint130.froperleft
rsfMRI_fcnxpro122_falffPoint131_FrOperleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint131.froperleft
rsfMRI_fcnxpro122_alffPoint131_FrOperleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint131.froperleft
rsfMRI_fcnxpro122_perafPoint131_FrOperleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint131.froperleft
rsfMRI_fcnxpro122_falffPoint132_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint132.iplleft
rsfMRI_fcnxpro122_alffPoint132_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint132.iplleft
rsfMRI_fcnxpro122_perafPoint132_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint132.iplleft
rsfMRI_fcnxpro122_falffPoint133_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint133.iplleft
rsfMRI_fcnxpro122_alffPoint133_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint133.iplleft
rsfMRI_fcnxpro122_perafPoint133_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint133.iplleft
rsfMRI_fcnxpro122_falffPoint134_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint134.insleft
rsfMRI_fcnxpro122_alffPoint134_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint134.insleft
rsfMRI_fcnxpro122_perafPoint134_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint134.insleft
rsfMRI_fcnxpro122_falffPoint135_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint135.insleft
rsfMRI_fcnxpro122_alffPoint135_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint135.insleft
rsfMRI_fcnxpro122_perafPoint135_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint135.insleft
rsfMRI_fcnxpro122_falffPoint136_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint136.insleft
rsfMRI_fcnxpro122_alffPoint136_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint136.insleft
rsfMRI_fcnxpro122_perafPoint136_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint136.insleft
rsfMRI_fcnxpro122_falffPoint137_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint137.insleft
rsfMRI_fcnxpro122_alffPoint137_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint137.insleft
rsfMRI_fcnxpro122_perafPoint137_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint137.insleft
rsfMRI_fcnxpro122_falffPoint138_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint138.insleft
rsfMRI_fcnxpro122_alffPoint138_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint138.insleft
rsfMRI_fcnxpro122_perafPoint138_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint138.insleft
rsfMRI_fcnxpro122_falffPoint139_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint139.splleft
rsfMRI_fcnxpro122_alffPoint139_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint139.splleft
rsfMRI_fcnxpro122_perafPoint139_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint139.splleft
rsfMRI_fcnxpro122_falffPoint140_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint140.splleft
rsfMRI_fcnxpro122_alffPoint140_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint140.splleft
rsfMRI_fcnxpro122_perafPoint140_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint140.splleft
rsfMRI_fcnxpro122_falffPoint141_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint141.splleft
rsfMRI_fcnxpro122_alffPoint141_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint141.splleft
rsfMRI_fcnxpro122_perafPoint141_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint141.splleft
rsfMRI_fcnxpro122_falffPoint142_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint142.iplleft
rsfMRI_fcnxpro122_alffPoint142_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint142.iplleft
rsfMRI_fcnxpro122_perafPoint142_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint142.iplleft
rsfMRI_fcnxpro122_falffPoint143_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint143.iplleft
rsfMRI_fcnxpro122_alffPoint143_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint143.iplleft
rsfMRI_fcnxpro122_perafPoint143_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint143.iplleft
rsfMRI_fcnxpro122_falffPoint144_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint144.pfcdleft
rsfMRI_fcnxpro122_alffPoint144_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint144.pfcdleft
rsfMRI_fcnxpro122_perafPoint144_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint144.pfcdleft
rsfMRI_fcnxpro122_falffPoint145_PostCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint145.postcleft
rsfMRI_fcnxpro122_alffPoint145_PostCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint145.postcleft
rsfMRI_fcnxpro122_perafPoint145_PostCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint145.postcleft
rsfMRI_fcnxpro122_falffPoint146_PostCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint146.postcleft
rsfMRI_fcnxpro122_alffPoint146_PostCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint146.postcleft
rsfMRI_fcnxpro122_perafPoint146_PostCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint146.postcleft
rsfMRI_fcnxpro122_falffPoint147_PostCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint147.postcleft
rsfMRI_fcnxpro122_alffPoint147_PostCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint147.postcleft
rsfMRI_fcnxpro122_perafPoint147_PostCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint147.postcleft
rsfMRI_fcnxpro122_falffPoint148_PrCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint148.prcdleft
rsfMRI_fcnxpro122_alffPoint148_PrCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint148.prcdleft
rsfMRI_fcnxpro122_perafPoint148_PrCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint148.prcdleft
rsfMRI_fcnxpro122_falffPoint149_PrCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint149.prcdleft
rsfMRI_fcnxpro122_alffPoint149_PrCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint149.prcdleft
rsfMRI_fcnxpro122_perafPoint149_PrCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint149.prcdleft
rsfMRI_fcnxpro122_falffPoint150_PrCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint150.prcdleft
rsfMRI_fcnxpro122_alffPoint150_PrCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint150.prcdleft
rsfMRI_fcnxpro122_perafPoint150_PrCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint150.prcdleft
rsfMRI_fcnxpro122_falffPoint151_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint151.splleft
rsfMRI_fcnxpro122_alffPoint151_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint151.splleft
rsfMRI_fcnxpro122_perafPoint151_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint151.splleft
rsfMRI_fcnxpro122_falffPoint152_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint152.splleft
rsfMRI_fcnxpro122_alffPoint152_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint152.splleft
rsfMRI_fcnxpro122_perafPoint152_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint152.splleft
rsfMRI_fcnxpro122_falffPoint153_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint153.splleft
rsfMRI_fcnxpro122_alffPoint153_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint153.splleft
rsfMRI_fcnxpro122_perafPoint153_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint153.splleft
rsfMRI_fcnxpro122_falffPoint154_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint154.splleft
rsfMRI_fcnxpro122_alffPoint154_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint154.splleft
rsfMRI_fcnxpro122_perafPoint154_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint154.splleft
rsfMRI_fcnxpro122_falffPoint155_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint155.tempoccleft
rsfMRI_fcnxpro122_alffPoint155_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint155.tempoccleft
rsfMRI_fcnxpro122_perafPoint155_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint155.tempoccleft
rsfMRI_fcnxpro122_falffPoint156_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint156.exstrleft
rsfMRI_fcnxpro122_alffPoint156_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint156.exstrleft
rsfMRI_fcnxpro122_perafPoint156_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint156.exstrleft
rsfMRI_fcnxpro122_falffPoint157_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint157.exstrleft
rsfMRI_fcnxpro122_alffPoint157_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint157.exstrleft
rsfMRI_fcnxpro122_perafPoint157_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint157.exstrleft
rsfMRI_fcnxpro122_falffPoint158_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint158.exstrleft
rsfMRI_fcnxpro122_alffPoint158_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint158.exstrleft
rsfMRI_fcnxpro122_perafPoint158_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint158.exstrleft
rsfMRI_fcnxpro122_falffPoint159_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint159.exstrleft
rsfMRI_fcnxpro122_alffPoint159_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint159.exstrleft
rsfMRI_fcnxpro122_perafPoint159_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint159.exstrleft
rsfMRI_fcnxpro122_falffPoint160_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint160.ipsleft
rsfMRI_fcnxpro122_alffPoint160_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint160.ipsleft
rsfMRI_fcnxpro122_perafPoint160_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint160.ipsleft
rsfMRI_fcnxpro122_falffPoint161_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint161.splleft
rsfMRI_fcnxpro122_alffPoint161_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint161.splleft
rsfMRI_fcnxpro122_perafPoint161_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint161.splleft
rsfMRI_fcnxpro122_falffPoint162_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint162.splleft
rsfMRI_fcnxpro122_alffPoint162_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint162.splleft
rsfMRI_fcnxpro122_perafPoint162_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint162.splleft
rsfMRI_fcnxpro122_falffPoint163_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint163.splleft
rsfMRI_fcnxpro122_alffPoint163_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint163.splleft
rsfMRI_fcnxpro122_perafPoint163_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint163.splleft
rsfMRI_fcnxpro122_falffPoint164_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint164.splleft
rsfMRI_fcnxpro122_alffPoint164_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint164.splleft
rsfMRI_fcnxpro122_perafPoint164_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint164.splleft
rsfMRI_fcnxpro122_falffPoint165_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint165.splleft
rsfMRI_fcnxpro122_alffPoint165_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint165.splleft
rsfMRI_fcnxpro122_perafPoint165_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint165.splleft
rsfMRI_fcnxpro122_falffPoint166_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint166.splleft
rsfMRI_fcnxpro122_alffPoint166_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint166.splleft
rsfMRI_fcnxpro122_perafPoint166_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint166.splleft
rsfMRI_fcnxpro122_falffPoint167_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint167.tempoccleft
rsfMRI_fcnxpro122_alffPoint167_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint167.tempoccleft
rsfMRI_fcnxpro122_perafPoint167_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint167.tempoccleft
rsfMRI_fcnxpro122_falffPoint168_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint168.tempoccleft
rsfMRI_fcnxpro122_alffPoint168_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint168.tempoccleft
rsfMRI_fcnxpro122_perafPoint168_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint168.tempoccleft
rsfMRI_fcnxpro122_falffPoint169_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint169.tempoccleft
rsfMRI_fcnxpro122_alffPoint169_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint169.tempoccleft
rsfMRI_fcnxpro122_perafPoint169_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint169.tempoccleft
rsfMRI_fcnxpro122_falffPoint170_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint170.tempoccleft
rsfMRI_fcnxpro122_alffPoint170_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint170.tempoccleft
rsfMRI_fcnxpro122_perafPoint170_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint170.tempoccleft
rsfMRI_fcnxpro122_falffPoint171_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint171.tempoccleft
rsfMRI_fcnxpro122_alffPoint171_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint171.tempoccleft
rsfMRI_fcnxpro122_perafPoint171_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint171.tempoccleft
rsfMRI_fcnxpro122_falffPoint172_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint172.tempoccleft
rsfMRI_fcnxpro122_alffPoint172_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint172.tempoccleft
rsfMRI_fcnxpro122_perafPoint172_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint172.tempoccleft
rsfMRI_fcnxpro122_falffPoint173_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint173.tempoccleft
rsfMRI_fcnxpro122_alffPoint173_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint173.tempoccleft
rsfMRI_fcnxpro122_perafPoint173_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint173.tempoccleft
rsfMRI_fcnxpro122_falffPoint174_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint174.tempoccleft
rsfMRI_fcnxpro122_alffPoint174_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint174.tempoccleft
rsfMRI_fcnxpro122_perafPoint174_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint174.tempoccleft
rsfMRI_fcnxpro122_falffPoint175_1left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint175.1left
rsfMRI_fcnxpro122_alffPoint175_1left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint175.1left
rsfMRI_fcnxpro122_perafPoint175_1left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint175.1left
rsfMRI_fcnxpro122_falffPoint176_2left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint176.2left
rsfMRI_fcnxpro122_alffPoint176_2left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint176.2left
rsfMRI_fcnxpro122_perafPoint176_2left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint176.2left
rsfMRI_fcnxpro122_falffPoint177_3left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint177.3left
rsfMRI_fcnxpro122_alffPoint177_3left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint177.3left
rsfMRI_fcnxpro122_perafPoint177_3left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint177.3left
rsfMRI_fcnxpro122_falffPoint178_4left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint178.4left
rsfMRI_fcnxpro122_alffPoint178_4left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint178.4left
rsfMRI_fcnxpro122_perafPoint178_4left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint178.4left
rsfMRI_fcnxpro122_falffPoint179_5left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint179.5left
rsfMRI_fcnxpro122_alffPoint179_5left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint179.5left
rsfMRI_fcnxpro122_perafPoint179_5left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint179.5left
rsfMRI_fcnxpro122_falffPoint180_6left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint180.6left
rsfMRI_fcnxpro122_alffPoint180_6left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint180.6left
rsfMRI_fcnxpro122_perafPoint180_6left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint180.6left
rsfMRI_fcnxpro122_falffPoint181_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint181.iplleft
rsfMRI_fcnxpro122_alffPoint181_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint181.iplleft
rsfMRI_fcnxpro122_perafPoint181_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint181.iplleft
rsfMRI_fcnxpro122_falffPoint182_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint182.insleft
rsfMRI_fcnxpro122_alffPoint182_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint182.insleft
rsfMRI_fcnxpro122_perafPoint182_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint182.insleft
rsfMRI_fcnxpro122_falffPoint183_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint183.insleft
rsfMRI_fcnxpro122_alffPoint183_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint183.insleft
rsfMRI_fcnxpro122_perafPoint183_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint183.insleft
rsfMRI_fcnxpro122_falffPoint184_ParOperleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint184.paroperleft
rsfMRI_fcnxpro122_alffPoint184_ParOperleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint184.paroperleft
rsfMRI_fcnxpro122_perafPoint184_ParOperleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint184.paroperleft
rsfMRI_fcnxpro122_falffPoint185_ParOperleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint185.paroperleft
rsfMRI_fcnxpro122_alffPoint185_ParOperleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint185.paroperleft
rsfMRI_fcnxpro122_perafPoint185_ParOperleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint185.paroperleft
rsfMRI_fcnxpro122_falffPoint186_ParOperleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint186.paroperleft
rsfMRI_fcnxpro122_alffPoint186_ParOperleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint186.paroperleft
rsfMRI_fcnxpro122_perafPoint186_ParOperleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint186.paroperleft
rsfMRI_fcnxpro122_falffPoint187_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint187.stleft
rsfMRI_fcnxpro122_alffPoint187_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint187.stleft
rsfMRI_fcnxpro122_perafPoint187_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint187.stleft
rsfMRI_fcnxpro122_falffPoint188_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint188.stleft
rsfMRI_fcnxpro122_alffPoint188_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint188.stleft
rsfMRI_fcnxpro122_perafPoint188_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint188.stleft
rsfMRI_fcnxpro122_falffPoint189_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint189.stleft
rsfMRI_fcnxpro122_alffPoint189_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint189.stleft
rsfMRI_fcnxpro122_perafPoint189_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint189.stleft
rsfMRI_fcnxpro122_falffPoint190_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint190.stleft
rsfMRI_fcnxpro122_alffPoint190_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint190.stleft
rsfMRI_fcnxpro122_perafPoint190_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint190.stleft
rsfMRI_fcnxpro122_falffPoint191_1left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint191.1left
rsfMRI_fcnxpro122_alffPoint191_1left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint191.1left
rsfMRI_fcnxpro122_perafPoint191_1left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint191.1left
rsfMRI_fcnxpro122_falffPoint192_10left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint192.10left
rsfMRI_fcnxpro122_alffPoint192_10left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint192.10left
rsfMRI_fcnxpro122_perafPoint192_10left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint192.10left
rsfMRI_fcnxpro122_falffPoint193_11left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint193.11left
rsfMRI_fcnxpro122_alffPoint193_11left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint193.11left
rsfMRI_fcnxpro122_perafPoint193_11left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint193.11left
rsfMRI_fcnxpro122_falffPoint194_12left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint194.12left
rsfMRI_fcnxpro122_alffPoint194_12left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint194.12left
rsfMRI_fcnxpro122_perafPoint194_12left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint194.12left
rsfMRI_fcnxpro122_falffPoint195_13left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint195.13left
rsfMRI_fcnxpro122_alffPoint195_13left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint195.13left
rsfMRI_fcnxpro122_perafPoint195_13left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint195.13left
rsfMRI_fcnxpro122_falffPoint196_14left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint196.14left
rsfMRI_fcnxpro122_alffPoint196_14left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint196.14left
rsfMRI_fcnxpro122_perafPoint196_14left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint196.14left
rsfMRI_fcnxpro122_falffPoint197_15left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint197.15left
rsfMRI_fcnxpro122_alffPoint197_15left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint197.15left
rsfMRI_fcnxpro122_perafPoint197_15left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint197.15left
rsfMRI_fcnxpro122_falffPoint198_16left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint198.16left
rsfMRI_fcnxpro122_alffPoint198_16left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint198.16left
rsfMRI_fcnxpro122_perafPoint198_16left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint198.16left
rsfMRI_fcnxpro122_falffPoint199_17left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint199.17left
rsfMRI_fcnxpro122_alffPoint199_17left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint199.17left
rsfMRI_fcnxpro122_perafPoint199_17left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint199.17left
rsfMRI_fcnxpro122_falffPoint200_18left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint200.18left
rsfMRI_fcnxpro122_alffPoint200_18left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint200.18left
rsfMRI_fcnxpro122_perafPoint200_18left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint200.18left
rsfMRI_fcnxpro122_falffPoint201_19left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint201.19left
rsfMRI_fcnxpro122_alffPoint201_19left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint201.19left
rsfMRI_fcnxpro122_perafPoint201_19left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint201.19left
rsfMRI_fcnxpro122_falffPoint202_2left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint202.2left
rsfMRI_fcnxpro122_alffPoint202_2left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint202.2left
rsfMRI_fcnxpro122_perafPoint202_2left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint202.2left
rsfMRI_fcnxpro122_falffPoint203_20left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint203.20left
rsfMRI_fcnxpro122_alffPoint203_20left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint203.20left
rsfMRI_fcnxpro122_perafPoint203_20left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint203.20left
rsfMRI_fcnxpro122_falffPoint204_21left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint204.21left
rsfMRI_fcnxpro122_alffPoint204_21left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint204.21left
rsfMRI_fcnxpro122_perafPoint204_21left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint204.21left
rsfMRI_fcnxpro122_falffPoint205_22left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint205.22left
rsfMRI_fcnxpro122_alffPoint205_22left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint205.22left
rsfMRI_fcnxpro122_perafPoint205_22left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint205.22left
rsfMRI_fcnxpro122_falffPoint206_23left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint206.23left
rsfMRI_fcnxpro122_alffPoint206_23left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint206.23left
rsfMRI_fcnxpro122_perafPoint206_23left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint206.23left
rsfMRI_fcnxpro122_falffPoint207_24left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint207.24left
rsfMRI_fcnxpro122_alffPoint207_24left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint207.24left
rsfMRI_fcnxpro122_perafPoint207_24left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint207.24left
rsfMRI_fcnxpro122_falffPoint208_25left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint208.25left
rsfMRI_fcnxpro122_alffPoint208_25left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint208.25left
rsfMRI_fcnxpro122_perafPoint208_25left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint208.25left
rsfMRI_fcnxpro122_falffPoint209_26left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint209.26left
rsfMRI_fcnxpro122_alffPoint209_26left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint209.26left
rsfMRI_fcnxpro122_perafPoint209_26left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint209.26left
rsfMRI_fcnxpro122_falffPoint210_27left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint210.27left
rsfMRI_fcnxpro122_alffPoint210_27left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint210.27left
rsfMRI_fcnxpro122_perafPoint210_27left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint210.27left
rsfMRI_fcnxpro122_falffPoint211_28left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint211.28left
rsfMRI_fcnxpro122_alffPoint211_28left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint211.28left
rsfMRI_fcnxpro122_perafPoint211_28left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint211.28left
rsfMRI_fcnxpro122_falffPoint212_29left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint212.29left
rsfMRI_fcnxpro122_alffPoint212_29left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint212.29left
rsfMRI_fcnxpro122_perafPoint212_29left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint212.29left
rsfMRI_fcnxpro122_falffPoint213_3left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint213.3left
rsfMRI_fcnxpro122_alffPoint213_3left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint213.3left
rsfMRI_fcnxpro122_perafPoint213_3left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint213.3left
rsfMRI_fcnxpro122_falffPoint214_4left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint214.4left
rsfMRI_fcnxpro122_alffPoint214_4left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint214.4left
rsfMRI_fcnxpro122_perafPoint214_4left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint214.4left
rsfMRI_fcnxpro122_falffPoint215_5left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint215.5left
rsfMRI_fcnxpro122_alffPoint215_5left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint215.5left
rsfMRI_fcnxpro122_perafPoint215_5left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint215.5left
rsfMRI_fcnxpro122_falffPoint216_6left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint216.6left
rsfMRI_fcnxpro122_alffPoint216_6left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint216.6left
rsfMRI_fcnxpro122_perafPoint216_6left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint216.6left
rsfMRI_fcnxpro122_falffPoint217_7left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint217.7left
rsfMRI_fcnxpro122_alffPoint217_7left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint217.7left
rsfMRI_fcnxpro122_perafPoint217_7left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint217.7left
rsfMRI_fcnxpro122_falffPoint218_8left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint218.8left
rsfMRI_fcnxpro122_alffPoint218_8left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint218.8left
rsfMRI_fcnxpro122_perafPoint218_8left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint218.8left
rsfMRI_fcnxpro122_falffPoint219_9left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint219.9left
rsfMRI_fcnxpro122_alffPoint219_9left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint219.9left
rsfMRI_fcnxpro122_perafPoint219_9left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint219.9left
rsfMRI_fcnxpro122_falffPoint220_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint220.splleft
rsfMRI_fcnxpro122_alffPoint220_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint220.splleft
rsfMRI_fcnxpro122_perafPoint220_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint220.splleft
rsfMRI_fcnxpro122_falffPoint221_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint221.exstrleft
rsfMRI_fcnxpro122_alffPoint221_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint221.exstrleft
rsfMRI_fcnxpro122_perafPoint221_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint221.exstrleft
rsfMRI_fcnxpro122_falffPoint222_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint222.exstrinfleft
rsfMRI_fcnxpro122_alffPoint222_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint222.exstrinfleft
rsfMRI_fcnxpro122_perafPoint222_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint222.exstrinfleft
rsfMRI_fcnxpro122_falffPoint223_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint223.exstrinfleft
rsfMRI_fcnxpro122_alffPoint223_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint223.exstrinfleft
rsfMRI_fcnxpro122_perafPoint223_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint223.exstrinfleft
rsfMRI_fcnxpro122_falffPoint224_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint224.exstrinfleft
rsfMRI_fcnxpro122_alffPoint224_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint224.exstrinfleft
rsfMRI_fcnxpro122_perafPoint224_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint224.exstrinfleft
rsfMRI_fcnxpro122_falffPoint225_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint225.exstrinfleft
rsfMRI_fcnxpro122_alffPoint225_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint225.exstrinfleft
rsfMRI_fcnxpro122_perafPoint225_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint225.exstrinfleft
rsfMRI_fcnxpro122_falffPoint226_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint226.exstrinfleft
rsfMRI_fcnxpro122_alffPoint226_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint226.exstrinfleft
rsfMRI_fcnxpro122_perafPoint226_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint226.exstrinfleft
rsfMRI_fcnxpro122_falffPoint227_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint227.exstrsupleft
rsfMRI_fcnxpro122_alffPoint227_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint227.exstrsupleft
rsfMRI_fcnxpro122_perafPoint227_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint227.exstrsupleft
rsfMRI_fcnxpro122_falffPoint228_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint228.exstrsupleft
rsfMRI_fcnxpro122_alffPoint228_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint228.exstrsupleft
rsfMRI_fcnxpro122_perafPoint228_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint228.exstrsupleft
rsfMRI_fcnxpro122_falffPoint229_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint229.exstrsupleft
rsfMRI_fcnxpro122_alffPoint229_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint229.exstrsupleft
rsfMRI_fcnxpro122_perafPoint229_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint229.exstrsupleft
rsfMRI_fcnxpro122_falffPoint230_Striateleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint230.striateleft
rsfMRI_fcnxpro122_alffPoint230_Striateleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint230.striateleft
rsfMRI_fcnxpro122_perafPoint230_Striateleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint230.striateleft
rsfMRI_fcnxpro122_falffPoint231_Striateleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint231.striateleft
rsfMRI_fcnxpro122_alffPoint231_Striateleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint231.striateleft
rsfMRI_fcnxpro122_perafPoint231_Striateleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint231.striateleft
rsfMRI_fcnxpro122_falffPoint232_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint232.exstrinfleft
rsfMRI_fcnxpro122_alffPoint232_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint232.exstrinfleft
rsfMRI_fcnxpro122_perafPoint232_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint232.exstrinfleft
rsfMRI_fcnxpro122_falffPoint233_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint233.exstrleft
rsfMRI_fcnxpro122_alffPoint233_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint233.exstrleft
rsfMRI_fcnxpro122_perafPoint233_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint233.exstrleft
rsfMRI_fcnxpro122_falffPoint234_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint234.exstrleft
rsfMRI_fcnxpro122_alffPoint234_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint234.exstrleft
rsfMRI_fcnxpro122_perafPoint234_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint234.exstrleft
rsfMRI_fcnxpro122_falffPoint235_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint235.exstrleft
rsfMRI_fcnxpro122_alffPoint235_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint235.exstrleft
rsfMRI_fcnxpro122_perafPoint235_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint235.exstrleft
rsfMRI_fcnxpro122_falffPoint236_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint236.exstrleft
rsfMRI_fcnxpro122_alffPoint236_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint236.exstrleft
rsfMRI_fcnxpro122_perafPoint236_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint236.exstrleft
rsfMRI_fcnxpro122_falffPoint237_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint237.exstrleft
rsfMRI_fcnxpro122_alffPoint237_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint237.exstrleft
rsfMRI_fcnxpro122_perafPoint237_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint237.exstrleft
rsfMRI_fcnxpro122_falffPoint238_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint238.exstrleft
rsfMRI_fcnxpro122_alffPoint238_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint238.exstrleft
rsfMRI_fcnxpro122_perafPoint238_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint238.exstrleft
rsfMRI_fcnxpro122_falffPoint239_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint239.exstrleft
rsfMRI_fcnxpro122_alffPoint239_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint239.exstrleft
rsfMRI_fcnxpro122_perafPoint239_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint239.exstrleft
rsfMRI_fcnxpro122_falffPoint240_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint240.exstrleft
rsfMRI_fcnxpro122_alffPoint240_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint240.exstrleft
rsfMRI_fcnxpro122_perafPoint240_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint240.exstrleft
rsfMRI_fcnxpro122_falffPoint241_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint241.exstrleft
rsfMRI_fcnxpro122_alffPoint241_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint241.exstrleft
rsfMRI_fcnxpro122_perafPoint241_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint241.exstrleft
rsfMRI_fcnxpro122_falffPoint242_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint242.exstrleft
rsfMRI_fcnxpro122_alffPoint242_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint242.exstrleft
rsfMRI_fcnxpro122_perafPoint242_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint242.exstrleft
rsfMRI_fcnxpro122_falffPoint243_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint243.exstrleft
rsfMRI_fcnxpro122_alffPoint243_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint243.exstrleft
rsfMRI_fcnxpro122_perafPoint243_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint243.exstrleft
rsfMRI_fcnxpro122_falffPoint244_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint244.exstrleft
rsfMRI_fcnxpro122_alffPoint244_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint244.exstrleft
rsfMRI_fcnxpro122_perafPoint244_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint244.exstrleft
rsfMRI_fcnxpro122_falffPoint245_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint245.exstrleft
rsfMRI_fcnxpro122_alffPoint245_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint245.exstrleft
rsfMRI_fcnxpro122_perafPoint245_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint245.exstrleft
rsfMRI_fcnxpro122_falffPoint246_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint246.exstrleft
rsfMRI_fcnxpro122_alffPoint246_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint246.exstrleft
rsfMRI_fcnxpro122_perafPoint246_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint246.exstrleft
rsfMRI_fcnxpro122_falffPoint247_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint247.exstrleft
rsfMRI_fcnxpro122_alffPoint247_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint247.exstrleft
rsfMRI_fcnxpro122_perafPoint247_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint247.exstrleft
rsfMRI_fcnxpro122_falffPoint248_Striateleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint248.striateleft
rsfMRI_fcnxpro122_alffPoint248_Striateleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint248.striateleft
rsfMRI_fcnxpro122_perafPoint248_Striateleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint248.striateleft
rsfMRI_fcnxpro122_falffPoint249_Striateleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint249.striateleft
rsfMRI_fcnxpro122_alffPoint249_Striateleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint249.striateleft
rsfMRI_fcnxpro122_perafPoint249_Striateleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint249.striateleft
rsfMRI_fcnxpro122_falffPoint250_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint250.iplright
rsfMRI_fcnxpro122_alffPoint250_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint250.iplright
rsfMRI_fcnxpro122_perafPoint250_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint250.iplright
rsfMRI_fcnxpro122_falffPoint251_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint251.stright
rsfMRI_fcnxpro122_alffPoint251_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint251.stright
rsfMRI_fcnxpro122_perafPoint251_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint251.stright
rsfMRI_fcnxpro122_falffPoint252_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint252.stright
rsfMRI_fcnxpro122_alffPoint252_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint252.stright
rsfMRI_fcnxpro122_perafPoint252_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint252.stright
rsfMRI_fcnxpro122_falffPoint253_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint253.tempoccright
rsfMRI_fcnxpro122_alffPoint253_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint253.tempoccright
rsfMRI_fcnxpro122_perafPoint253_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint253.tempoccright
rsfMRI_fcnxpro122_falffPoint254_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint254.tempright
rsfMRI_fcnxpro122_alffPoint254_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint254.tempright
rsfMRI_fcnxpro122_perafPoint254_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint254.tempright
rsfMRI_fcnxpro122_falffPoint255_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint255.tempright
rsfMRI_fcnxpro122_alffPoint255_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint255.tempright
rsfMRI_fcnxpro122_perafPoint255_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint255.tempright
rsfMRI_fcnxpro122_falffPoint256_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint256.exstrinfright
rsfMRI_fcnxpro122_alffPoint256_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint256.exstrinfright
rsfMRI_fcnxpro122_perafPoint256_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint256.exstrinfright
rsfMRI_fcnxpro122_falffPoint257_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint257.iplright
rsfMRI_fcnxpro122_alffPoint257_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint257.iplright
rsfMRI_fcnxpro122_perafPoint257_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint257.iplright
rsfMRI_fcnxpro122_falffPoint258_PHCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint258.phcright
rsfMRI_fcnxpro122_alffPoint258_PHCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint258.phcright
rsfMRI_fcnxpro122_perafPoint258_PHCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint258.phcright
rsfMRI_fcnxpro122_falffPoint259_PHCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint259.phcright
rsfMRI_fcnxpro122_alffPoint259_PHCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint259.phcright
rsfMRI_fcnxpro122_perafPoint259_PHCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint259.phcright
rsfMRI_fcnxpro122_falffPoint260_PHCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint260.phcright
rsfMRI_fcnxpro122_alffPoint260_PHCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint260.phcright
rsfMRI_fcnxpro122_perafPoint260_PHCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint260.phcright
rsfMRI_fcnxpro122_falffPoint261_RSCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint261.rscright
rsfMRI_fcnxpro122_alffPoint261_RSCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint261.rscright
rsfMRI_fcnxpro122_perafPoint261_RSCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint261.rscright
rsfMRI_fcnxpro122_falffPoint262_RSCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint262.rscright
rsfMRI_fcnxpro122_alffPoint262_RSCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint262.rscright
rsfMRI_fcnxpro122_perafPoint262_RSCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint262.rscright
rsfMRI_fcnxpro122_falffPoint263_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint263.iplright
rsfMRI_fcnxpro122_alffPoint263_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint263.iplright
rsfMRI_fcnxpro122_perafPoint263_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint263.iplright
rsfMRI_fcnxpro122_falffPoint264_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint264.iplright
rsfMRI_fcnxpro122_alffPoint264_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint264.iplright
rsfMRI_fcnxpro122_perafPoint264_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint264.iplright
rsfMRI_fcnxpro122_falffPoint265_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint265.iplright
rsfMRI_fcnxpro122_alffPoint265_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint265.iplright
rsfMRI_fcnxpro122_perafPoint265_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint265.iplright
rsfMRI_fcnxpro122_falffPoint266_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint266.iplright
rsfMRI_fcnxpro122_alffPoint266_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint266.iplright
rsfMRI_fcnxpro122_perafPoint266_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint266.iplright
rsfMRI_fcnxpro122_falffPoint000_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint000.pfcdright
rsfMRI_fcnxpro122_alffPoint000_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint000.pfcdright
rsfMRI_fcnxpro122_perafPoint000_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint000.pfcdright
rsfMRI_fcnxpro122_falffPoint001_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint001.pfcdright
rsfMRI_fcnxpro122_alffPoint001_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint001.pfcdright
rsfMRI_fcnxpro122_perafPoint001_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint001.pfcdright
rsfMRI_fcnxpro122_falffPoint002_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint002.pfcdright
rsfMRI_fcnxpro122_alffPoint002_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint002.pfcdright
rsfMRI_fcnxpro122_perafPoint002_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint002.pfcdright
rsfMRI_fcnxpro122_falffPoint003_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint003.pfcdright
rsfMRI_fcnxpro122_alffPoint003_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint003.pfcdright
rsfMRI_fcnxpro122_perafPoint003_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint003.pfcdright
rsfMRI_fcnxpro122_falffPoint004_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint004.pfcdright
rsfMRI_fcnxpro122_alffPoint004_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint004.pfcdright
rsfMRI_fcnxpro122_perafPoint004_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint004.pfcdright
rsfMRI_fcnxpro122_falffPoint005_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint005.pfcdright
rsfMRI_fcnxpro122_alffPoint005_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint005.pfcdright
rsfMRI_fcnxpro122_perafPoint005_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint005.pfcdright
rsfMRI_fcnxpro122_falffPoint006_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint006.pfcdright
rsfMRI_fcnxpro122_alffPoint006_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint006.pfcdright
rsfMRI_fcnxpro122_perafPoint006_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint006.pfcdright
rsfMRI_fcnxpro122_falffPoint007_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint007.pfclright
rsfMRI_fcnxpro122_alffPoint007_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint007.pfclright
rsfMRI_fcnxpro122_perafPoint007_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint007.pfclright
rsfMRI_fcnxpro122_falffPoint008_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint008.pfclright
rsfMRI_fcnxpro122_alffPoint008_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint008.pfclright
rsfMRI_fcnxpro122_perafPoint008_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint008.pfclright
rsfMRI_fcnxpro122_falffPoint009_PFCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint009.pfcvright
rsfMRI_fcnxpro122_alffPoint009_PFCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint009.pfcvright
rsfMRI_fcnxpro122_perafPoint009_PFCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint009.pfcvright
rsfMRI_fcnxpro122_falffPoint010_PFCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint010.pfcvright
rsfMRI_fcnxpro122_alffPoint010_PFCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint010.pfcvright
rsfMRI_fcnxpro122_perafPoint010_PFCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint010.pfcvright
rsfMRI_fcnxpro122_falffPoint011_PFCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint011.pfcvright
rsfMRI_fcnxpro122_alffPoint011_PFCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint011.pfcvright
rsfMRI_fcnxpro122_perafPoint011_PFCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint011.pfcvright
rsfMRI_fcnxpro122_falffPoint012_PFCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint012.pfcvright
rsfMRI_fcnxpro122_alffPoint012_PFCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint012.pfcvright
rsfMRI_fcnxpro122_perafPoint012_PFCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint012.pfcvright
rsfMRI_fcnxpro122_falffPoint013_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint013.temppoleright
rsfMRI_fcnxpro122_alffPoint013_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint013.temppoleright
rsfMRI_fcnxpro122_perafPoint013_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint013.temppoleright
rsfMRI_fcnxpro122_falffPoint014_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint014.tempright
rsfMRI_fcnxpro122_alffPoint014_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint014.tempright
rsfMRI_fcnxpro122_perafPoint014_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint014.tempright
rsfMRI_fcnxpro122_falffPoint015_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint015.tempright
rsfMRI_fcnxpro122_alffPoint015_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint015.tempright
rsfMRI_fcnxpro122_perafPoint015_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint015.tempright
rsfMRI_fcnxpro122_falffPoint016_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint016.tempright
rsfMRI_fcnxpro122_alffPoint016_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint016.tempright
rsfMRI_fcnxpro122_perafPoint016_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint016.tempright
rsfMRI_fcnxpro122_falffPoint017_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint017.tempright
rsfMRI_fcnxpro122_alffPoint017_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint017.tempright
rsfMRI_fcnxpro122_perafPoint017_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint017.tempright
rsfMRI_fcnxpro122_falffPoint018_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint018.tempright
rsfMRI_fcnxpro122_alffPoint018_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint018.tempright
rsfMRI_fcnxpro122_perafPoint018_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint018.tempright
rsfMRI_fcnxpro122_falffPoint019_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint019.tempright
rsfMRI_fcnxpro122_alffPoint019_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint019.tempright
rsfMRI_fcnxpro122_perafPoint019_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint019.tempright
rsfMRI_fcnxpro122_falffPoint020_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint020.tempright
rsfMRI_fcnxpro122_alffPoint020_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint020.tempright
rsfMRI_fcnxpro122_perafPoint020_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint020.tempright
rsfMRI_fcnxpro122_falffPoint021_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint021.tempright
rsfMRI_fcnxpro122_alffPoint021_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint021.tempright
rsfMRI_fcnxpro122_perafPoint021_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint021.tempright
rsfMRI_fcnxpro122_falffPoint022_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint022.tempright
rsfMRI_fcnxpro122_alffPoint022_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint022.tempright
rsfMRI_fcnxpro122_perafPoint022_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint022.tempright
rsfMRI_fcnxpro122_falffPoint023_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint023.tempright
rsfMRI_fcnxpro122_alffPoint023_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint023.tempright
rsfMRI_fcnxpro122_perafPoint023_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint023.tempright
rsfMRI_fcnxpro122_falffPoint024_FPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint024.fpoleright
rsfMRI_fcnxpro122_alffPoint024_FPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint024.fpoleright
rsfMRI_fcnxpro122_perafPoint024_FPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint024.fpoleright
rsfMRI_fcnxpro122_falffPoint025_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint025.iplright
rsfMRI_fcnxpro122_alffPoint025_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint025.iplright
rsfMRI_fcnxpro122_perafPoint025_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint025.iplright
rsfMRI_fcnxpro122_falffPoint026_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint026.iplright
rsfMRI_fcnxpro122_alffPoint026_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint026.iplright
rsfMRI_fcnxpro122_perafPoint026_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint026.iplright
rsfMRI_fcnxpro122_falffPoint027_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint027.iplright
rsfMRI_fcnxpro122_alffPoint027_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint027.iplright
rsfMRI_fcnxpro122_perafPoint027_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint027.iplright
rsfMRI_fcnxpro122_falffPoint028_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint028.pccright
rsfMRI_fcnxpro122_alffPoint028_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint028.pccright
rsfMRI_fcnxpro122_perafPoint028_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint028.pccright
rsfMRI_fcnxpro122_falffPoint029_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint029.pccright
rsfMRI_fcnxpro122_alffPoint029_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint029.pccright
rsfMRI_fcnxpro122_perafPoint029_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint029.pccright
rsfMRI_fcnxpro122_falffPoint030_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint030.pccright
rsfMRI_fcnxpro122_alffPoint030_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint030.pccright
rsfMRI_fcnxpro122_perafPoint030_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint030.pccright
rsfMRI_fcnxpro122_falffPoint031_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint031.pccright
rsfMRI_fcnxpro122_alffPoint031_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint031.pccright
rsfMRI_fcnxpro122_perafPoint031_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint031.pccright
rsfMRI_fcnxpro122_falffPoint032_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint032.pccright
rsfMRI_fcnxpro122_alffPoint032_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint032.pccright
rsfMRI_fcnxpro122_perafPoint032_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint032.pccright
rsfMRI_fcnxpro122_falffPoint033_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint033.pccright
rsfMRI_fcnxpro122_alffPoint033_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint033.pccright
rsfMRI_fcnxpro122_perafPoint033_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint033.pccright
rsfMRI_fcnxpro122_falffPoint034_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint034.pccright
rsfMRI_fcnxpro122_alffPoint034_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint034.pccright
rsfMRI_fcnxpro122_perafPoint034_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint034.pccright
rsfMRI_fcnxpro122_falffPoint035_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint035.pfcdright
rsfMRI_fcnxpro122_alffPoint035_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint035.pfcdright
rsfMRI_fcnxpro122_perafPoint035_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint035.pfcdright
rsfMRI_fcnxpro122_falffPoint036_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint036.pfcdright
rsfMRI_fcnxpro122_alffPoint036_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint036.pfcdright
rsfMRI_fcnxpro122_perafPoint036_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint036.pfcdright
rsfMRI_fcnxpro122_falffPoint037_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint037.pfcdright
rsfMRI_fcnxpro122_alffPoint037_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint037.pfcdright
rsfMRI_fcnxpro122_perafPoint037_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint037.pfcdright
rsfMRI_fcnxpro122_falffPoint038_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint038.pfcdright
rsfMRI_fcnxpro122_alffPoint038_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint038.pfcdright
rsfMRI_fcnxpro122_perafPoint038_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint038.pfcdright
rsfMRI_fcnxpro122_falffPoint039_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint039.pfcmright
rsfMRI_fcnxpro122_alffPoint039_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint039.pfcmright
rsfMRI_fcnxpro122_perafPoint039_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint039.pfcmright
rsfMRI_fcnxpro122_falffPoint040_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint040.pfcmright
rsfMRI_fcnxpro122_alffPoint040_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint040.pfcmright
rsfMRI_fcnxpro122_perafPoint040_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint040.pfcmright
rsfMRI_fcnxpro122_falffPoint041_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint041.pfcmright
rsfMRI_fcnxpro122_alffPoint041_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint041.pfcmright
rsfMRI_fcnxpro122_perafPoint041_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint041.pfcmright
rsfMRI_fcnxpro122_falffPoint042_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint042.pfcmright
rsfMRI_fcnxpro122_alffPoint042_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint042.pfcmright
rsfMRI_fcnxpro122_perafPoint042_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint042.pfcmright
rsfMRI_fcnxpro122_falffPoint043_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint043.pfcmright
rsfMRI_fcnxpro122_alffPoint043_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint043.pfcmright
rsfMRI_fcnxpro122_perafPoint043_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint043.pfcmright
rsfMRI_fcnxpro122_falffPoint044_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint044.pcunright
rsfMRI_fcnxpro122_alffPoint044_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint044.pcunright
rsfMRI_fcnxpro122_perafPoint044_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint044.pcunright
rsfMRI_fcnxpro122_falffPoint045_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint045.pcunright
rsfMRI_fcnxpro122_alffPoint045_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint045.pcunright
rsfMRI_fcnxpro122_perafPoint045_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint045.pcunright
rsfMRI_fcnxpro122_falffPoint046_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint046.pcunright
rsfMRI_fcnxpro122_alffPoint046_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint046.pcunright
rsfMRI_fcnxpro122_perafPoint046_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint046.pcunright
rsfMRI_fcnxpro122_falffPoint047_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint047.pccright
rsfMRI_fcnxpro122_alffPoint047_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint047.pccright
rsfMRI_fcnxpro122_perafPoint047_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint047.pccright
rsfMRI_fcnxpro122_falffPoint048_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint048.splright
rsfMRI_fcnxpro122_alffPoint048_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint048.splright
rsfMRI_fcnxpro122_perafPoint048_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint048.splright
rsfMRI_fcnxpro122_falffPoint049_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint049.pcunright
rsfMRI_fcnxpro122_alffPoint049_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint049.pcunright
rsfMRI_fcnxpro122_perafPoint049_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint049.pcunright
rsfMRI_fcnxpro122_falffPoint050_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint050.pcunright
rsfMRI_fcnxpro122_alffPoint050_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint050.pcunright
rsfMRI_fcnxpro122_perafPoint050_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint050.pcunright
rsfMRI_fcnxpro122_falffPoint051_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint051.pcunright
rsfMRI_fcnxpro122_alffPoint051_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint051.pcunright
rsfMRI_fcnxpro122_perafPoint051_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint051.pcunright
rsfMRI_fcnxpro122_falffPoint052_FPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint052.fpoleright
rsfMRI_fcnxpro122_alffPoint052_FPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint052.fpoleright
rsfMRI_fcnxpro122_perafPoint052_FPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint052.fpoleright
rsfMRI_fcnxpro122_falffPoint053_FPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint053.fpoleright
rsfMRI_fcnxpro122_alffPoint053_FPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint053.fpoleright
rsfMRI_fcnxpro122_perafPoint053_FPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint053.fpoleright
rsfMRI_fcnxpro122_falffPoint054_FrMedright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint054.frmedright
rsfMRI_fcnxpro122_alffPoint054_FrMedright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint054.frmedright
rsfMRI_fcnxpro122_perafPoint054_FrMedright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint054.frmedright
rsfMRI_fcnxpro122_falffPoint055_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint055.iplright
rsfMRI_fcnxpro122_alffPoint055_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint055.iplright
rsfMRI_fcnxpro122_perafPoint055_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint055.iplright
rsfMRI_fcnxpro122_falffPoint056_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint056.ipsright
rsfMRI_fcnxpro122_alffPoint056_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint056.ipsright
rsfMRI_fcnxpro122_perafPoint056_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint056.ipsright
rsfMRI_fcnxpro122_falffPoint057_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint057.ipsright
rsfMRI_fcnxpro122_alffPoint057_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint057.ipsright
rsfMRI_fcnxpro122_perafPoint057_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint057.ipsright
rsfMRI_fcnxpro122_falffPoint058_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint058.pfcdright
rsfMRI_fcnxpro122_alffPoint058_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint058.pfcdright
rsfMRI_fcnxpro122_perafPoint058_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint058.pfcdright
rsfMRI_fcnxpro122_falffPoint059_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint059.pfclright
rsfMRI_fcnxpro122_alffPoint059_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint059.pfclright
rsfMRI_fcnxpro122_perafPoint059_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint059.pfclright
rsfMRI_fcnxpro122_falffPoint060_PFCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint060.pfcvright
rsfMRI_fcnxpro122_alffPoint060_PFCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint060.pfcvright
rsfMRI_fcnxpro122_perafPoint060_PFCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint060.pfcvright
rsfMRI_fcnxpro122_falffPoint061_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint061.tempright
rsfMRI_fcnxpro122_alffPoint061_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint061.tempright
rsfMRI_fcnxpro122_perafPoint061_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint061.tempright
rsfMRI_fcnxpro122_falffPoint062_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint062.tempright
rsfMRI_fcnxpro122_alffPoint062_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint062.tempright
rsfMRI_fcnxpro122_perafPoint062_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint062.tempright
rsfMRI_fcnxpro122_falffPoint063_Cingmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint063.cingmright
rsfMRI_fcnxpro122_alffPoint063_Cingmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint063.cingmright
rsfMRI_fcnxpro122_perafPoint063_Cingmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint063.cingmright
rsfMRI_fcnxpro122_falffPoint064_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint064.ipsright
rsfMRI_fcnxpro122_alffPoint064_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint064.ipsright
rsfMRI_fcnxpro122_perafPoint064_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint064.ipsright
rsfMRI_fcnxpro122_falffPoint065_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint065.ipsright
rsfMRI_fcnxpro122_alffPoint065_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint065.ipsright
rsfMRI_fcnxpro122_perafPoint065_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint065.ipsright
rsfMRI_fcnxpro122_falffPoint066_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint066.ipsright
rsfMRI_fcnxpro122_alffPoint066_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint066.ipsright
rsfMRI_fcnxpro122_perafPoint066_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint066.ipsright
rsfMRI_fcnxpro122_falffPoint067_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint067.ipsright
rsfMRI_fcnxpro122_alffPoint067_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint067.ipsright
rsfMRI_fcnxpro122_perafPoint067_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint067.ipsright
rsfMRI_fcnxpro122_falffPoint068_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint068.ipsright
rsfMRI_fcnxpro122_alffPoint068_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint068.ipsright
rsfMRI_fcnxpro122_perafPoint068_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint068.ipsright
rsfMRI_fcnxpro122_falffPoint069_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint069.pfcdright
rsfMRI_fcnxpro122_alffPoint069_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint069.pfcdright
rsfMRI_fcnxpro122_perafPoint069_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint069.pfcdright
rsfMRI_fcnxpro122_falffPoint070_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint070.pfclright
rsfMRI_fcnxpro122_alffPoint070_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint070.pfclright
rsfMRI_fcnxpro122_perafPoint070_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint070.pfclright
rsfMRI_fcnxpro122_falffPoint071_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint071.pfclright
rsfMRI_fcnxpro122_alffPoint071_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint071.pfclright
rsfMRI_fcnxpro122_perafPoint071_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint071.pfclright
rsfMRI_fcnxpro122_falffPoint072_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint072.pfclright
rsfMRI_fcnxpro122_alffPoint072_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint072.pfclright
rsfMRI_fcnxpro122_perafPoint072_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint072.pfclright
rsfMRI_fcnxpro122_falffPoint073_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint073.pfclright
rsfMRI_fcnxpro122_alffPoint073_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint073.pfclright
rsfMRI_fcnxpro122_perafPoint073_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint073.pfclright
rsfMRI_fcnxpro122_falffPoint074_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint074.pfclright
rsfMRI_fcnxpro122_alffPoint074_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint074.pfclright
rsfMRI_fcnxpro122_perafPoint074_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint074.pfclright
rsfMRI_fcnxpro122_falffPoint075_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint075.pfclright
rsfMRI_fcnxpro122_alffPoint075_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint075.pfclright
rsfMRI_fcnxpro122_perafPoint075_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint075.pfclright
rsfMRI_fcnxpro122_falffPoint076_PrCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint076.prcvright
rsfMRI_fcnxpro122_alffPoint076_PrCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint076.prcvright
rsfMRI_fcnxpro122_perafPoint076_PrCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint076.prcvright
rsfMRI_fcnxpro122_falffPoint077_PrCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint077.prcvright
rsfMRI_fcnxpro122_alffPoint077_PrCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint077.prcvright
rsfMRI_fcnxpro122_perafPoint077_PrCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint077.prcvright
rsfMRI_fcnxpro122_falffPoint078_PrCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint078.prcvright
rsfMRI_fcnxpro122_alffPoint078_PrCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint078.prcvright
rsfMRI_fcnxpro122_perafPoint078_PrCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint078.prcvright
rsfMRI_fcnxpro122_falffPoint079_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint079.splright
rsfMRI_fcnxpro122_alffPoint079_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint079.splright
rsfMRI_fcnxpro122_perafPoint079_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint079.splright
rsfMRI_fcnxpro122_falffPoint080_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint080.tempoccright
rsfMRI_fcnxpro122_alffPoint080_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint080.tempoccright
rsfMRI_fcnxpro122_perafPoint080_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint080.tempoccright
rsfMRI_fcnxpro122_falffPoint081_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint081.insright
rsfMRI_fcnxpro122_alffPoint081_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint081.insright
rsfMRI_fcnxpro122_perafPoint081_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint081.insright
rsfMRI_fcnxpro122_falffPoint082_PHCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint082.phcright
rsfMRI_fcnxpro122_alffPoint082_PHCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint082.phcright
rsfMRI_fcnxpro122_perafPoint082_PHCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint082.phcright
rsfMRI_fcnxpro122_falffPoint083_PHCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint083.phcright
rsfMRI_fcnxpro122_alffPoint083_PHCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint083.phcright
rsfMRI_fcnxpro122_perafPoint083_PHCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint083.phcright
rsfMRI_fcnxpro122_falffPoint084_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint084.stright
rsfMRI_fcnxpro122_alffPoint084_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint084.stright
rsfMRI_fcnxpro122_perafPoint084_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint084.stright
rsfMRI_fcnxpro122_falffPoint085_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint085.temppoleright
rsfMRI_fcnxpro122_alffPoint085_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint085.temppoleright
rsfMRI_fcnxpro122_perafPoint085_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint085.temppoleright
rsfMRI_fcnxpro122_falffPoint086_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint086.temppoleright
rsfMRI_fcnxpro122_alffPoint086_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint086.temppoleright
rsfMRI_fcnxpro122_perafPoint086_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint086.temppoleright
rsfMRI_fcnxpro122_falffPoint087_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint087.temppoleright
rsfMRI_fcnxpro122_alffPoint087_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint087.temppoleright
rsfMRI_fcnxpro122_perafPoint087_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint087.temppoleright
rsfMRI_fcnxpro122_falffPoint088_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint088.temppoleright
rsfMRI_fcnxpro122_alffPoint088_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint088.temppoleright
rsfMRI_fcnxpro122_perafPoint088_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint088.temppoleright
rsfMRI_fcnxpro122_falffPoint089_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint089.temppoleright
rsfMRI_fcnxpro122_alffPoint089_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint089.temppoleright
rsfMRI_fcnxpro122_perafPoint089_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint089.temppoleright
rsfMRI_fcnxpro122_falffPoint090_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint090.tempright
rsfMRI_fcnxpro122_alffPoint090_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint090.tempright
rsfMRI_fcnxpro122_perafPoint090_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint090.tempright
rsfMRI_fcnxpro122_falffPoint091_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint091.tempright
rsfMRI_fcnxpro122_alffPoint091_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint091.tempright
rsfMRI_fcnxpro122_perafPoint091_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint091.tempright
rsfMRI_fcnxpro122_falffPoint092_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint092.tempright
rsfMRI_fcnxpro122_alffPoint092_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint092.tempright
rsfMRI_fcnxpro122_perafPoint092_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint092.tempright
rsfMRI_fcnxpro122_falffPoint093_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint093.tempright
rsfMRI_fcnxpro122_alffPoint093_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint093.tempright
rsfMRI_fcnxpro122_perafPoint093_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint093.tempright
rsfMRI_fcnxpro122_falffPoint094_FPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint094.fpoleright
rsfMRI_fcnxpro122_alffPoint094_FPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint094.fpoleright
rsfMRI_fcnxpro122_perafPoint094_FPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint094.fpoleright
rsfMRI_fcnxpro122_falffPoint095_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint095.ofcright
rsfMRI_fcnxpro122_alffPoint095_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint095.ofcright
rsfMRI_fcnxpro122_perafPoint095_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint095.ofcright
rsfMRI_fcnxpro122_falffPoint096_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint096.ofcright
rsfMRI_fcnxpro122_alffPoint096_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint096.ofcright
rsfMRI_fcnxpro122_perafPoint096_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint096.ofcright
rsfMRI_fcnxpro122_falffPoint097_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint097.ofcright
rsfMRI_fcnxpro122_alffPoint097_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint097.ofcright
rsfMRI_fcnxpro122_perafPoint097_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint097.ofcright
rsfMRI_fcnxpro122_falffPoint098_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint098.ofcright
rsfMRI_fcnxpro122_alffPoint098_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint098.ofcright
rsfMRI_fcnxpro122_perafPoint098_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint098.ofcright
rsfMRI_fcnxpro122_falffPoint099_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint099.ofcright
rsfMRI_fcnxpro122_alffPoint099_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint099.ofcright
rsfMRI_fcnxpro122_perafPoint099_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint099.ofcright
rsfMRI_fcnxpro122_falffPoint100_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint100.ofcright
rsfMRI_fcnxpro122_alffPoint100_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint100.ofcright
rsfMRI_fcnxpro122_perafPoint100_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint100.ofcright
rsfMRI_fcnxpro122_falffPoint101_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint101.pfcmright
rsfMRI_fcnxpro122_alffPoint101_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint101.pfcmright
rsfMRI_fcnxpro122_perafPoint101_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint101.pfcmright
rsfMRI_fcnxpro122_falffPoint102_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint102.pfcmright
rsfMRI_fcnxpro122_alffPoint102_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint102.pfcmright
rsfMRI_fcnxpro122_perafPoint102_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint102.pfcmright
rsfMRI_fcnxpro122_falffPoint103_FrMedright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint103.frmedright
rsfMRI_fcnxpro122_alffPoint103_FrMedright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint103.frmedright
rsfMRI_fcnxpro122_perafPoint103_FrMedright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint103.frmedright
rsfMRI_fcnxpro122_falffPoint104_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint104.insright
rsfMRI_fcnxpro122_alffPoint104_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint104.insright
rsfMRI_fcnxpro122_perafPoint104_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint104.insright
rsfMRI_fcnxpro122_falffPoint105_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint105.insright
rsfMRI_fcnxpro122_alffPoint105_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint105.insright
rsfMRI_fcnxpro122_perafPoint105_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint105.insright
rsfMRI_fcnxpro122_falffPoint106_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint106.insright
rsfMRI_fcnxpro122_alffPoint106_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint106.insright
rsfMRI_fcnxpro122_perafPoint106_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint106.insright
rsfMRI_fcnxpro122_falffPoint107_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint107.pfclright
rsfMRI_fcnxpro122_alffPoint107_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint107.pfclright
rsfMRI_fcnxpro122_perafPoint107_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint107.pfclright
rsfMRI_fcnxpro122_falffPoint108_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint108.pfclright
rsfMRI_fcnxpro122_alffPoint108_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint108.pfclright
rsfMRI_fcnxpro122_perafPoint108_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint108.pfclright
rsfMRI_fcnxpro122_falffPoint109_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint109.pfcmright
rsfMRI_fcnxpro122_alffPoint109_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint109.pfcmright
rsfMRI_fcnxpro122_perafPoint109_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint109.pfcmright
rsfMRI_fcnxpro122_falffPoint110_FrMedright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint110.frmedright
rsfMRI_fcnxpro122_alffPoint110_FrMedright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint110.frmedright
rsfMRI_fcnxpro122_perafPoint110_FrMedright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint110.frmedright
rsfMRI_fcnxpro122_falffPoint111_FrMedright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint111.frmedright
rsfMRI_fcnxpro122_alffPoint111_FrMedright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint111.frmedright
rsfMRI_fcnxpro122_perafPoint111_FrMedright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint111.frmedright
rsfMRI_fcnxpro122_falffPoint112_FrMedright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint112.frmedright
rsfMRI_fcnxpro122_alffPoint112_FrMedright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint112.frmedright
rsfMRI_fcnxpro122_perafPoint112_FrMedright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint112.frmedright
rsfMRI_fcnxpro122_falffPoint113_FrOperright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint113.froperright
rsfMRI_fcnxpro122_alffPoint113_FrOperright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint113.froperright
rsfMRI_fcnxpro122_perafPoint113_FrOperright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint113.froperright
rsfMRI_fcnxpro122_falffPoint114_FrOperright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint114.froperright
rsfMRI_fcnxpro122_alffPoint114_FrOperright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint114.froperright
rsfMRI_fcnxpro122_perafPoint114_FrOperright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint114.froperright
rsfMRI_fcnxpro122_falffPoint115_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint115.iplright
rsfMRI_fcnxpro122_alffPoint115_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint115.iplright
rsfMRI_fcnxpro122_perafPoint115_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint115.iplright
rsfMRI_fcnxpro122_falffPoint116_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint116.iplright
rsfMRI_fcnxpro122_alffPoint116_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint116.iplright
rsfMRI_fcnxpro122_perafPoint116_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint116.iplright
rsfMRI_fcnxpro122_falffPoint117_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint117.insright
rsfMRI_fcnxpro122_alffPoint117_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint117.insright
rsfMRI_fcnxpro122_perafPoint117_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint117.insright
rsfMRI_fcnxpro122_falffPoint118_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint118.insright
rsfMRI_fcnxpro122_alffPoint118_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint118.insright
rsfMRI_fcnxpro122_perafPoint118_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint118.insright
rsfMRI_fcnxpro122_falffPoint119_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint119.insright
rsfMRI_fcnxpro122_alffPoint119_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint119.insright
rsfMRI_fcnxpro122_perafPoint119_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint119.insright
rsfMRI_fcnxpro122_falffPoint120_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint120.insright
rsfMRI_fcnxpro122_alffPoint120_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint120.insright
rsfMRI_fcnxpro122_perafPoint120_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint120.insright
rsfMRI_fcnxpro122_falffPoint121_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint121.insright
rsfMRI_fcnxpro122_alffPoint121_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint121.insright
rsfMRI_fcnxpro122_perafPoint121_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint121.insright
rsfMRI_fcnxpro122_falffPoint122_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint122.splright
rsfMRI_fcnxpro122_alffPoint122_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint122.splright
rsfMRI_fcnxpro122_perafPoint122_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint122.splright
rsfMRI_fcnxpro122_falffPoint123_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint123.splright
rsfMRI_fcnxpro122_alffPoint123_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint123.splright
rsfMRI_fcnxpro122_perafPoint123_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint123.splright
rsfMRI_fcnxpro122_falffPoint124_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint124.splright
rsfMRI_fcnxpro122_alffPoint124_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint124.splright
rsfMRI_fcnxpro122_perafPoint124_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint124.splright
rsfMRI_fcnxpro122_falffPoint125_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint125.iplright
rsfMRI_fcnxpro122_alffPoint125_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint125.iplright
rsfMRI_fcnxpro122_perafPoint125_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint125.iplright
rsfMRI_fcnxpro122_falffPoint126_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint126.iplright
rsfMRI_fcnxpro122_alffPoint126_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint126.iplright
rsfMRI_fcnxpro122_perafPoint126_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint126.iplright
rsfMRI_fcnxpro122_falffPoint127_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint127.pfcdright
rsfMRI_fcnxpro122_alffPoint127_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint127.pfcdright
rsfMRI_fcnxpro122_perafPoint127_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint127.pfcdright
rsfMRI_fcnxpro122_falffPoint128_PostCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint128.postcright
rsfMRI_fcnxpro122_alffPoint128_PostCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint128.postcright
rsfMRI_fcnxpro122_perafPoint128_PostCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint128.postcright
rsfMRI_fcnxpro122_falffPoint129_PostCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint129.postcright
rsfMRI_fcnxpro122_alffPoint129_PostCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint129.postcright
rsfMRI_fcnxpro122_perafPoint129_PostCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint129.postcright
rsfMRI_fcnxpro122_falffPoint130_PostCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint130.postcright
rsfMRI_fcnxpro122_alffPoint130_PostCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint130.postcright
rsfMRI_fcnxpro122_perafPoint130_PostCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint130.postcright
rsfMRI_fcnxpro122_falffPoint131_PrCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint131.prcdright
rsfMRI_fcnxpro122_alffPoint131_PrCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint131.prcdright
rsfMRI_fcnxpro122_perafPoint131_PrCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint131.prcdright
rsfMRI_fcnxpro122_falffPoint132_PrCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint132.prcdright
rsfMRI_fcnxpro122_alffPoint132_PrCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint132.prcdright
rsfMRI_fcnxpro122_perafPoint132_PrCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint132.prcdright
rsfMRI_fcnxpro122_falffPoint133_PrCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint133.prcdright
rsfMRI_fcnxpro122_alffPoint133_PrCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint133.prcdright
rsfMRI_fcnxpro122_perafPoint133_PrCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint133.prcdright
rsfMRI_fcnxpro122_falffPoint134_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint134.splright
rsfMRI_fcnxpro122_alffPoint134_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint134.splright
rsfMRI_fcnxpro122_perafPoint134_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint134.splright
rsfMRI_fcnxpro122_falffPoint135_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint135.splright
rsfMRI_fcnxpro122_alffPoint135_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint135.splright
rsfMRI_fcnxpro122_perafPoint135_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint135.splright
rsfMRI_fcnxpro122_falffPoint136_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint136.splright
rsfMRI_fcnxpro122_alffPoint136_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint136.splright
rsfMRI_fcnxpro122_perafPoint136_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint136.splright
rsfMRI_fcnxpro122_falffPoint137_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint137.splright
rsfMRI_fcnxpro122_alffPoint137_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint137.splright
rsfMRI_fcnxpro122_perafPoint137_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint137.splright
rsfMRI_fcnxpro122_falffPoint138_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint138.tempoccright
rsfMRI_fcnxpro122_alffPoint138_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint138.tempoccright
rsfMRI_fcnxpro122_perafPoint138_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint138.tempoccright
rsfMRI_fcnxpro122_falffPoint139_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint139.exstrright
rsfMRI_fcnxpro122_alffPoint139_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint139.exstrright
rsfMRI_fcnxpro122_perafPoint139_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint139.exstrright
rsfMRI_fcnxpro122_falffPoint140_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint140.exstrright
rsfMRI_fcnxpro122_alffPoint140_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint140.exstrright
rsfMRI_fcnxpro122_perafPoint140_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint140.exstrright
rsfMRI_fcnxpro122_falffPoint141_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint141.exstrright
rsfMRI_fcnxpro122_alffPoint141_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint141.exstrright
rsfMRI_fcnxpro122_perafPoint141_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint141.exstrright
rsfMRI_fcnxpro122_falffPoint142_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint142.exstrright
rsfMRI_fcnxpro122_alffPoint142_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint142.exstrright
rsfMRI_fcnxpro122_perafPoint142_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint142.exstrright
rsfMRI_fcnxpro122_falffPoint143_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint143.ipsright
rsfMRI_fcnxpro122_alffPoint143_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint143.ipsright
rsfMRI_fcnxpro122_perafPoint143_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint143.ipsright
rsfMRI_fcnxpro122_falffPoint144_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint144.splright
rsfMRI_fcnxpro122_alffPoint144_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint144.splright
rsfMRI_fcnxpro122_perafPoint144_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint144.splright
rsfMRI_fcnxpro122_falffPoint145_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint145.splright
rsfMRI_fcnxpro122_alffPoint145_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint145.splright
rsfMRI_fcnxpro122_perafPoint145_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint145.splright
rsfMRI_fcnxpro122_falffPoint146_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint146.splright
rsfMRI_fcnxpro122_alffPoint146_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint146.splright
rsfMRI_fcnxpro122_perafPoint146_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint146.splright
rsfMRI_fcnxpro122_falffPoint147_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint147.splright
rsfMRI_fcnxpro122_alffPoint147_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint147.splright
rsfMRI_fcnxpro122_perafPoint147_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint147.splright
rsfMRI_fcnxpro122_falffPoint148_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint148.splright
rsfMRI_fcnxpro122_alffPoint148_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint148.splright
rsfMRI_fcnxpro122_perafPoint148_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint148.splright
rsfMRI_fcnxpro122_falffPoint149_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint149.splright
rsfMRI_fcnxpro122_alffPoint149_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint149.splright
rsfMRI_fcnxpro122_perafPoint149_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint149.splright
rsfMRI_fcnxpro122_falffPoint150_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint150.tempoccright
rsfMRI_fcnxpro122_alffPoint150_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint150.tempoccright
rsfMRI_fcnxpro122_perafPoint150_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint150.tempoccright
rsfMRI_fcnxpro122_falffPoint151_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint151.tempoccright
rsfMRI_fcnxpro122_alffPoint151_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint151.tempoccright
rsfMRI_fcnxpro122_perafPoint151_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint151.tempoccright
rsfMRI_fcnxpro122_falffPoint152_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint152.tempoccright
rsfMRI_fcnxpro122_alffPoint152_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint152.tempoccright
rsfMRI_fcnxpro122_perafPoint152_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint152.tempoccright
rsfMRI_fcnxpro122_falffPoint153_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint153.tempoccright
rsfMRI_fcnxpro122_alffPoint153_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint153.tempoccright
rsfMRI_fcnxpro122_perafPoint153_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint153.tempoccright
rsfMRI_fcnxpro122_falffPoint154_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint154.tempoccright
rsfMRI_fcnxpro122_alffPoint154_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint154.tempoccright
rsfMRI_fcnxpro122_perafPoint154_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint154.tempoccright
rsfMRI_fcnxpro122_falffPoint155_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint155.tempoccright
rsfMRI_fcnxpro122_alffPoint155_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint155.tempoccright
rsfMRI_fcnxpro122_perafPoint155_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint155.tempoccright
rsfMRI_fcnxpro122_falffPoint156_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint156.tempoccright
rsfMRI_fcnxpro122_alffPoint156_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint156.tempoccright
rsfMRI_fcnxpro122_perafPoint156_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint156.tempoccright
rsfMRI_fcnxpro122_falffPoint157_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint157.tempoccright
rsfMRI_fcnxpro122_alffPoint157_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint157.tempoccright
rsfMRI_fcnxpro122_perafPoint157_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint157.tempoccright
rsfMRI_fcnxpro122_falffPoint158_1right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint158.1right
rsfMRI_fcnxpro122_alffPoint158_1right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint158.1right
rsfMRI_fcnxpro122_perafPoint158_1right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint158.1right
rsfMRI_fcnxpro122_falffPoint159_2right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint159.2right
rsfMRI_fcnxpro122_alffPoint159_2right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint159.2right
rsfMRI_fcnxpro122_perafPoint159_2right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint159.2right
rsfMRI_fcnxpro122_falffPoint160_3right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint160.3right
rsfMRI_fcnxpro122_alffPoint160_3right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint160.3right
rsfMRI_fcnxpro122_perafPoint160_3right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint160.3right
rsfMRI_fcnxpro122_falffPoint161_4right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint161.4right
rsfMRI_fcnxpro122_alffPoint161_4right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint161.4right
rsfMRI_fcnxpro122_perafPoint161_4right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint161.4right
rsfMRI_fcnxpro122_falffPoint162_5right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint162.5right
rsfMRI_fcnxpro122_alffPoint162_5right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint162.5right
rsfMRI_fcnxpro122_perafPoint162_5right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint162.5right
rsfMRI_fcnxpro122_falffPoint163_6right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint163.6right
rsfMRI_fcnxpro122_alffPoint163_6right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint163.6right
rsfMRI_fcnxpro122_perafPoint163_6right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint163.6right
rsfMRI_fcnxpro122_falffPoint164_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint164.iplright
rsfMRI_fcnxpro122_alffPoint164_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint164.iplright
rsfMRI_fcnxpro122_perafPoint164_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint164.iplright
rsfMRI_fcnxpro122_falffPoint165_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint165.insright
rsfMRI_fcnxpro122_alffPoint165_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint165.insright
rsfMRI_fcnxpro122_perafPoint165_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint165.insright
rsfMRI_fcnxpro122_falffPoint166_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint166.insright
rsfMRI_fcnxpro122_alffPoint166_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint166.insright
rsfMRI_fcnxpro122_perafPoint166_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint166.insright
rsfMRI_fcnxpro122_falffPoint167_ParOperright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint167.paroperright
rsfMRI_fcnxpro122_alffPoint167_ParOperright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint167.paroperright
rsfMRI_fcnxpro122_perafPoint167_ParOperright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint167.paroperright
rsfMRI_fcnxpro122_falffPoint168_ParOperright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint168.paroperright
rsfMRI_fcnxpro122_alffPoint168_ParOperright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint168.paroperright
rsfMRI_fcnxpro122_perafPoint168_ParOperright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint168.paroperright
rsfMRI_fcnxpro122_falffPoint169_ParOperright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint169.paroperright
rsfMRI_fcnxpro122_alffPoint169_ParOperright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint169.paroperright
rsfMRI_fcnxpro122_perafPoint169_ParOperright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint169.paroperright
rsfMRI_fcnxpro122_falffPoint170_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint170.stright
rsfMRI_fcnxpro122_alffPoint170_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint170.stright
rsfMRI_fcnxpro122_perafPoint170_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint170.stright
rsfMRI_fcnxpro122_falffPoint171_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint171.stright
rsfMRI_fcnxpro122_alffPoint171_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint171.stright
rsfMRI_fcnxpro122_perafPoint171_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint171.stright
rsfMRI_fcnxpro122_falffPoint172_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint172.stright
rsfMRI_fcnxpro122_alffPoint172_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint172.stright
rsfMRI_fcnxpro122_perafPoint172_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint172.stright
rsfMRI_fcnxpro122_falffPoint173_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint173.stright
rsfMRI_fcnxpro122_alffPoint173_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint173.stright
rsfMRI_fcnxpro122_perafPoint173_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint173.stright
rsfMRI_fcnxpro122_falffPoint174_1right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint174.1right
rsfMRI_fcnxpro122_alffPoint174_1right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint174.1right
rsfMRI_fcnxpro122_perafPoint174_1right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint174.1right
rsfMRI_fcnxpro122_falffPoint175_10right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint175.10right
rsfMRI_fcnxpro122_alffPoint175_10right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint175.10right
rsfMRI_fcnxpro122_perafPoint175_10right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint175.10right
rsfMRI_fcnxpro122_falffPoint176_11right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint176.11right
rsfMRI_fcnxpro122_alffPoint176_11right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint176.11right
rsfMRI_fcnxpro122_perafPoint176_11right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint176.11right
rsfMRI_fcnxpro122_falffPoint177_12right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint177.12right
rsfMRI_fcnxpro122_alffPoint177_12right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint177.12right
rsfMRI_fcnxpro122_perafPoint177_12right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint177.12right
rsfMRI_fcnxpro122_falffPoint178_13right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint178.13right
rsfMRI_fcnxpro122_alffPoint178_13right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint178.13right
rsfMRI_fcnxpro122_perafPoint178_13right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint178.13right
rsfMRI_fcnxpro122_falffPoint179_14right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint179.14right
rsfMRI_fcnxpro122_alffPoint179_14right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint179.14right
rsfMRI_fcnxpro122_perafPoint179_14right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint179.14right
rsfMRI_fcnxpro122_falffPoint180_15right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint180.15right
rsfMRI_fcnxpro122_alffPoint180_15right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint180.15right
rsfMRI_fcnxpro122_perafPoint180_15right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint180.15right
rsfMRI_fcnxpro122_falffPoint181_16right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint181.16right
rsfMRI_fcnxpro122_alffPoint181_16right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint181.16right
rsfMRI_fcnxpro122_perafPoint181_16right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint181.16right
rsfMRI_fcnxpro122_falffPoint182_17right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint182.17right
rsfMRI_fcnxpro122_alffPoint182_17right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint182.17right
rsfMRI_fcnxpro122_perafPoint182_17right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint182.17right
rsfMRI_fcnxpro122_falffPoint183_18right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint183.18right
rsfMRI_fcnxpro122_alffPoint183_18right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint183.18right
rsfMRI_fcnxpro122_perafPoint183_18right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint183.18right
rsfMRI_fcnxpro122_falffPoint184_19right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint184.19right
rsfMRI_fcnxpro122_alffPoint184_19right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint184.19right
rsfMRI_fcnxpro122_perafPoint184_19right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint184.19right
rsfMRI_fcnxpro122_falffPoint185_2right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint185.2right
rsfMRI_fcnxpro122_alffPoint185_2right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint185.2right
rsfMRI_fcnxpro122_perafPoint185_2right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint185.2right
rsfMRI_fcnxpro122_falffPoint186_20right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint186.20right
rsfMRI_fcnxpro122_alffPoint186_20right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint186.20right
rsfMRI_fcnxpro122_perafPoint186_20right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint186.20right
rsfMRI_fcnxpro122_falffPoint187_21right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint187.21right
rsfMRI_fcnxpro122_alffPoint187_21right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint187.21right
rsfMRI_fcnxpro122_perafPoint187_21right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint187.21right
rsfMRI_fcnxpro122_falffPoint188_22right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint188.22right
rsfMRI_fcnxpro122_alffPoint188_22right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint188.22right
rsfMRI_fcnxpro122_perafPoint188_22right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint188.22right
rsfMRI_fcnxpro122_falffPoint189_23right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint189.23right
rsfMRI_fcnxpro122_alffPoint189_23right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint189.23right
rsfMRI_fcnxpro122_perafPoint189_23right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint189.23right
rsfMRI_fcnxpro122_falffPoint190_24right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint190.24right
rsfMRI_fcnxpro122_alffPoint190_24right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint190.24right
rsfMRI_fcnxpro122_perafPoint190_24right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint190.24right
rsfMRI_fcnxpro122_falffPoint191_25right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint191.25right
rsfMRI_fcnxpro122_alffPoint191_25right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint191.25right
rsfMRI_fcnxpro122_perafPoint191_25right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint191.25right
rsfMRI_fcnxpro122_falffPoint192_26right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint192.26right
rsfMRI_fcnxpro122_alffPoint192_26right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint192.26right
rsfMRI_fcnxpro122_perafPoint192_26right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint192.26right
rsfMRI_fcnxpro122_falffPoint193_27right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint193.27right
rsfMRI_fcnxpro122_alffPoint193_27right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint193.27right
rsfMRI_fcnxpro122_perafPoint193_27right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint193.27right
rsfMRI_fcnxpro122_falffPoint194_28right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint194.28right
rsfMRI_fcnxpro122_alffPoint194_28right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint194.28right
rsfMRI_fcnxpro122_perafPoint194_28right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint194.28right
rsfMRI_fcnxpro122_falffPoint195_29right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint195.29right
rsfMRI_fcnxpro122_alffPoint195_29right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint195.29right
rsfMRI_fcnxpro122_perafPoint195_29right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint195.29right
rsfMRI_fcnxpro122_falffPoint196_3right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint196.3right
rsfMRI_fcnxpro122_alffPoint196_3right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint196.3right
rsfMRI_fcnxpro122_perafPoint196_3right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint196.3right
rsfMRI_fcnxpro122_falffPoint197_4right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint197.4right
rsfMRI_fcnxpro122_alffPoint197_4right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint197.4right
rsfMRI_fcnxpro122_perafPoint197_4right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint197.4right
rsfMRI_fcnxpro122_falffPoint198_5right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint198.5right
rsfMRI_fcnxpro122_alffPoint198_5right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint198.5right
rsfMRI_fcnxpro122_perafPoint198_5right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint198.5right
rsfMRI_fcnxpro122_falffPoint199_6right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint199.6right
rsfMRI_fcnxpro122_alffPoint199_6right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint199.6right
rsfMRI_fcnxpro122_perafPoint199_6right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint199.6right
rsfMRI_fcnxpro122_falffPoint200_7right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint200.7right
rsfMRI_fcnxpro122_alffPoint200_7right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint200.7right
rsfMRI_fcnxpro122_perafPoint200_7right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint200.7right
rsfMRI_fcnxpro122_falffPoint201_8right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint201.8right
rsfMRI_fcnxpro122_alffPoint201_8right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint201.8right
rsfMRI_fcnxpro122_perafPoint201_8right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint201.8right
rsfMRI_fcnxpro122_falffPoint202_9right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint202.9right
rsfMRI_fcnxpro122_alffPoint202_9right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint202.9right
rsfMRI_fcnxpro122_perafPoint202_9right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint202.9right
rsfMRI_fcnxpro122_falffPoint203_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint203.splright
rsfMRI_fcnxpro122_alffPoint203_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint203.splright
rsfMRI_fcnxpro122_perafPoint203_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint203.splright
rsfMRI_fcnxpro122_falffPoint204_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint204.exstrright
rsfMRI_fcnxpro122_alffPoint204_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint204.exstrright
rsfMRI_fcnxpro122_perafPoint204_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint204.exstrright
rsfMRI_fcnxpro122_falffPoint205_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint205.exstrinfright
rsfMRI_fcnxpro122_alffPoint205_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint205.exstrinfright
rsfMRI_fcnxpro122_perafPoint205_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint205.exstrinfright
rsfMRI_fcnxpro122_falffPoint206_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint206.exstrinfright
rsfMRI_fcnxpro122_alffPoint206_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint206.exstrinfright
rsfMRI_fcnxpro122_perafPoint206_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint206.exstrinfright
rsfMRI_fcnxpro122_falffPoint207_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint207.exstrinfright
rsfMRI_fcnxpro122_alffPoint207_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint207.exstrinfright
rsfMRI_fcnxpro122_perafPoint207_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint207.exstrinfright
rsfMRI_fcnxpro122_falffPoint208_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint208.exstrinfright
rsfMRI_fcnxpro122_alffPoint208_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint208.exstrinfright
rsfMRI_fcnxpro122_perafPoint208_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint208.exstrinfright
rsfMRI_fcnxpro122_falffPoint209_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint209.exstrinfright
rsfMRI_fcnxpro122_alffPoint209_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint209.exstrinfright
rsfMRI_fcnxpro122_perafPoint209_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint209.exstrinfright
rsfMRI_fcnxpro122_falffPoint210_ExStrSupright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint210.exstrsupright
rsfMRI_fcnxpro122_alffPoint210_ExStrSupright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint210.exstrsupright
rsfMRI_fcnxpro122_perafPoint210_ExStrSupright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint210.exstrsupright
rsfMRI_fcnxpro122_falffPoint211_ExStrSupright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint211.exstrsupright
rsfMRI_fcnxpro122_alffPoint211_ExStrSupright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint211.exstrsupright
rsfMRI_fcnxpro122_perafPoint211_ExStrSupright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint211.exstrsupright
rsfMRI_fcnxpro122_falffPoint212_ExStrSupright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint212.exstrsupright
rsfMRI_fcnxpro122_alffPoint212_ExStrSupright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint212.exstrsupright
rsfMRI_fcnxpro122_perafPoint212_ExStrSupright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint212.exstrsupright
rsfMRI_fcnxpro122_falffPoint213_Striateright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint213.striateright
rsfMRI_fcnxpro122_alffPoint213_Striateright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint213.striateright
rsfMRI_fcnxpro122_perafPoint213_Striateright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint213.striateright
rsfMRI_fcnxpro122_falffPoint214_Striateright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint214.striateright
rsfMRI_fcnxpro122_alffPoint214_Striateright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint214.striateright
rsfMRI_fcnxpro122_perafPoint214_Striateright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint214.striateright
rsfMRI_fcnxpro122_falffPoint215_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint215.exstrinfright
rsfMRI_fcnxpro122_alffPoint215_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint215.exstrinfright
rsfMRI_fcnxpro122_perafPoint215_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint215.exstrinfright
rsfMRI_fcnxpro122_falffPoint216_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint216.exstrright
rsfMRI_fcnxpro122_alffPoint216_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint216.exstrright
rsfMRI_fcnxpro122_perafPoint216_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint216.exstrright
rsfMRI_fcnxpro122_falffPoint217_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint217.exstrright
rsfMRI_fcnxpro122_alffPoint217_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint217.exstrright
rsfMRI_fcnxpro122_perafPoint217_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint217.exstrright
rsfMRI_fcnxpro122_falffPoint218_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint218.exstrright
rsfMRI_fcnxpro122_alffPoint218_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint218.exstrright
rsfMRI_fcnxpro122_perafPoint218_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint218.exstrright
rsfMRI_fcnxpro122_falffPoint219_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint219.exstrright
rsfMRI_fcnxpro122_alffPoint219_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint219.exstrright
rsfMRI_fcnxpro122_perafPoint219_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint219.exstrright
rsfMRI_fcnxpro122_falffPoint220_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint220.exstrright
rsfMRI_fcnxpro122_alffPoint220_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint220.exstrright
rsfMRI_fcnxpro122_perafPoint220_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint220.exstrright
rsfMRI_fcnxpro122_falffPoint221_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint221.exstrright
rsfMRI_fcnxpro122_alffPoint221_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint221.exstrright
rsfMRI_fcnxpro122_perafPoint221_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint221.exstrright
rsfMRI_fcnxpro122_falffPoint222_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint222.exstrright
rsfMRI_fcnxpro122_alffPoint222_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint222.exstrright
rsfMRI_fcnxpro122_perafPoint222_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint222.exstrright
rsfMRI_fcnxpro122_falffPoint223_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint223.exstrright
rsfMRI_fcnxpro122_alffPoint223_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint223.exstrright
rsfMRI_fcnxpro122_perafPoint223_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint223.exstrright
rsfMRI_fcnxpro122_falffPoint224_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint224.exstrright
rsfMRI_fcnxpro122_alffPoint224_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint224.exstrright
rsfMRI_fcnxpro122_perafPoint224_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint224.exstrright
rsfMRI_fcnxpro122_falffPoint225_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint225.exstrright
rsfMRI_fcnxpro122_alffPoint225_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint225.exstrright
rsfMRI_fcnxpro122_perafPoint225_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint225.exstrright
rsfMRI_fcnxpro122_falffPoint226_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint226.exstrright
rsfMRI_fcnxpro122_alffPoint226_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint226.exstrright
rsfMRI_fcnxpro122_perafPoint226_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint226.exstrright
rsfMRI_fcnxpro122_falffPoint227_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint227.exstrright
rsfMRI_fcnxpro122_alffPoint227_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint227.exstrright
rsfMRI_fcnxpro122_perafPoint227_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint227.exstrright
rsfMRI_fcnxpro122_falffPoint228_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint228.exstrright
rsfMRI_fcnxpro122_alffPoint228_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint228.exstrright
rsfMRI_fcnxpro122_perafPoint228_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint228.exstrright
rsfMRI_fcnxpro122_falffPoint229_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint229.exstrright
rsfMRI_fcnxpro122_alffPoint229_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint229.exstrright
rsfMRI_fcnxpro122_perafPoint229_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint229.exstrright
rsfMRI_fcnxpro122_falffPoint230_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint230.exstrright
rsfMRI_fcnxpro122_alffPoint230_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint230.exstrright
rsfMRI_fcnxpro122_perafPoint230_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint230.exstrright
rsfMRI_fcnxpro122_falffPoint231_Striateright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint231.striateright
rsfMRI_fcnxpro122_alffPoint231_Striateright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint231.striateright
rsfMRI_fcnxpro122_perafPoint231_Striateright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint231.striateright
rsfMRI_fcnxpro122_falffPoint232_Striateright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint232.striateright
rsfMRI_fcnxpro122_alffPoint232_Striateright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint232.striateright
rsfMRI_fcnxpro122_perafPoint232_Striateright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint232.striateright
rsfMRI_fcnxpro122_falffPoint233_BNSTRPuLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint233.bnstrpuleft
rsfMRI_fcnxpro122_alffPoint233_BNSTRPuLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint233.bnstrpuleft
rsfMRI_fcnxpro122_perafPoint233_BNSTRPuLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint233.bnstrpuleft
rsfMRI_fcnxpro122_falffPoint234_BNSTRCaLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint234.bnstrcaleft
rsfMRI_fcnxpro122_alffPoint234_BNSTRCaLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint234.bnstrcaleft
rsfMRI_fcnxpro122_perafPoint234_BNSTRCaLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint234.bnstrcaleft
rsfMRI_fcnxpro122_falffPoint235_BNSTRNACLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint235.bnstrnacleft
rsfMRI_fcnxpro122_alffPoint235_BNSTRNACLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint235.bnstrnacleft
rsfMRI_fcnxpro122_perafPoint235_BNSTRNACLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint235.bnstrnacleft
rsfMRI_fcnxpro122_falffPoint236_EXALeft
restingStatefMRI
​
yeo_homotopic
ignore
unlabeled / likely somatosensory
rsf.p1.falffpoint236.exaleft
rsfMRI_fcnxpro122_alffPoint236_EXALeft
restingStatefMRI
​
yeo_homotopic
ignore
unlabeled / likely somatosensory
rsf.p1.alffpoint236.exaleft
rsfMRI_fcnxpro122_perafPoint236_EXALeft
restingStatefMRI
​
yeo_homotopic
ignore
unlabeled / likely somatosensory
rsf.p1.perafpoint236.exaleft
rsfMRI_fcnxpro122_falffPoint237_BNGPGPeLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint237.bngpgpeleft
rsfMRI_fcnxpro122_alffPoint237_BNGPGPeLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint237.bngpgpeleft
rsfMRI_fcnxpro122_perafPoint237_BNGPGPeLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint237.bngpgpeleft
rsfMRI_fcnxpro122_falffPoint238_BNGPGPiLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint238.bngpgpileft
rsfMRI_fcnxpro122_alffPoint238_BNGPGPiLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint238.bngpgpileft
rsfMRI_fcnxpro122_perafPoint238_BNGPGPiLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint238.bngpgpileft
rsfMRI_fcnxpro122_falffPoint239_MTgSNSNcLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint239.mtgsnsncleft
rsfMRI_fcnxpro122_alffPoint239_MTgSNSNcLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint239.mtgsnsncleft
rsfMRI_fcnxpro122_perafPoint239_MTgSNSNcLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint239.mtgsnsncleft
rsfMRI_fcnxpro122_falffPoint240_MTgRNLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint240.mtgrnleft
rsfMRI_fcnxpro122_alffPoint240_MTgRNLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint240.mtgrnleft
rsfMRI_fcnxpro122_perafPoint240_MTgRNLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint240.mtgrnleft
rsfMRI_fcnxpro122_falffPoint241_MTgSNSNrLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint241.mtgsnsnrleft
rsfMRI_fcnxpro122_alffPoint241_MTgSNSNrLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint241.mtgsnsnrleft
rsfMRI_fcnxpro122_perafPoint241_MTgSNSNrLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint241.mtgsnsnrleft
rsfMRI_fcnxpro122_falffPoint242_MTgVTRPBPLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro122_alffPoint242_MTgVTRPBPLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro122_perafPoint242_MTgVTRPBPLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint242.mtgvtrpbpleft
rsfMRI_fcnxpro122_falffPoint243_MTgVTRVTALeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro122_alffPoint243_MTgVTRVTALeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro122_perafPoint243_MTgVTRVTALeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint243.mtgvtrvtaleft
rsfMRI_fcnxpro122_falffPoint244_BNGPVePLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint244.bngpvepleft
rsfMRI_fcnxpro122_alffPoint244_BNGPVePLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint244.bngpvepleft
rsfMRI_fcnxpro122_perafPoint244_BNGPVePLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint244.bngpvepleft
rsfMRI_fcnxpro122_falffPoint245_THMETHHNLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint245.thmethhnleft
rsfMRI_fcnxpro122_alffPoint245_THMETHHNLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint245.thmethhnleft
rsfMRI_fcnxpro122_perafPoint245_THMETHHNLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint245.thmethhnleft
rsfMRI_fcnxpro122_falffPoint246_DieHTHLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint246.diehthleft
rsfMRI_fcnxpro122_alffPoint246_DieHTHLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint246.diehthleft
rsfMRI_fcnxpro122_perafPoint246_DieHTHLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint246.diehthleft
rsfMRI_fcnxpro122_falffPoint247_DieHTHMNLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint247.diehthmnleft
rsfMRI_fcnxpro122_alffPoint247_DieHTHMNLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint247.diehthmnleft
rsfMRI_fcnxpro122_perafPoint247_DieHTHMNLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint247.diehthmnleft
rsfMRI_fcnxpro122_falffPoint248_DieSTHLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint248.diesthleft
rsfMRI_fcnxpro122_alffPoint248_DieSTHLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint248.diesthleft
rsfMRI_fcnxpro122_perafPoint248_DieSTHLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint248.diesthleft
rsfMRI_fcnxpro122_falffPoint249_BNSTRPuRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint249.bnstrpuright
rsfMRI_fcnxpro122_alffPoint249_BNSTRPuRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint249.bnstrpuright
rsfMRI_fcnxpro122_perafPoint249_BNSTRPuRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint249.bnstrpuright
rsfMRI_fcnxpro122_falffPoint250_BNSTRCaRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint250.bnstrcaright
rsfMRI_fcnxpro122_alffPoint250_BNSTRCaRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint250.bnstrcaright
rsfMRI_fcnxpro122_perafPoint250_BNSTRCaRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint250.bnstrcaright
rsfMRI_fcnxpro122_falffPoint251_BNSTRNACRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint251.bnstrnacright
rsfMRI_fcnxpro122_alffPoint251_BNSTRNACRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint251.bnstrnacright
rsfMRI_fcnxpro122_perafPoint251_BNSTRNACRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint251.bnstrnacright
rsfMRI_fcnxpro122_falffPoint252_EXARight
restingStatefMRI
​
yeo_homotopic
ignore
unlabeled / likely somatosensory
rsf.p1.falffpoint252.exaright
rsfMRI_fcnxpro122_alffPoint252_EXARight
restingStatefMRI
​
yeo_homotopic
ignore
unlabeled / likely somatosensory
rsf.p1.alffpoint252.exaright
rsfMRI_fcnxpro122_perafPoint252_EXARight
restingStatefMRI
​
yeo_homotopic
ignore
unlabeled / likely somatosensory
rsf.p1.perafpoint252.exaright
rsfMRI_fcnxpro122_falffPoint253_BNGPGPeRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint253.bngpgperight
rsfMRI_fcnxpro122_alffPoint253_BNGPGPeRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint253.bngpgperight
rsfMRI_fcnxpro122_perafPoint253_BNGPGPeRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint253.bngpgperight
rsfMRI_fcnxpro122_falffPoint254_BNGPGPiRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint254.bngpgpiright
rsfMRI_fcnxpro122_alffPoint254_BNGPGPiRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint254.bngpgpiright
rsfMRI_fcnxpro122_perafPoint254_BNGPGPiRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint254.bngpgpiright
rsfMRI_fcnxpro122_falffPoint255_MTgSNSNcRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint255.mtgsnsncright
rsfMRI_fcnxpro122_alffPoint255_MTgSNSNcRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint255.mtgsnsncright
rsfMRI_fcnxpro122_perafPoint255_MTgSNSNcRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint255.mtgsnsncright
rsfMRI_fcnxpro122_falffPoint256_MTgRNRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint256.mtgrnright
rsfMRI_fcnxpro122_alffPoint256_MTgRNRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint256.mtgrnright
rsfMRI_fcnxpro122_perafPoint256_MTgRNRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint256.mtgrnright
rsfMRI_fcnxpro122_falffPoint257_MTgSNSNrRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint257.mtgsnsnrright
rsfMRI_fcnxpro122_alffPoint257_MTgSNSNrRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint257.mtgsnsnrright
rsfMRI_fcnxpro122_perafPoint257_MTgSNSNrRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint257.mtgsnsnrright
rsfMRI_fcnxpro122_falffPoint258_MTgVTRPBPRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint258.mtgvtrpbpright
rsfMRI_fcnxpro122_alffPoint258_MTgVTRPBPRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint258.mtgvtrpbpright
rsfMRI_fcnxpro122_perafPoint258_MTgVTRPBPRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint258.mtgvtrpbpright
rsfMRI_fcnxpro122_falffPoint259_MTgVTRVTARight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint259.mtgvtrvtaright
rsfMRI_fcnxpro122_alffPoint259_MTgVTRVTARight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint259.mtgvtrvtaright
rsfMRI_fcnxpro122_perafPoint259_MTgVTRVTARight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint259.mtgvtrvtaright
rsfMRI_fcnxpro122_falffPoint260_BNGPVePRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint260.bngpvepright
rsfMRI_fcnxpro122_alffPoint260_BNGPVePRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint260.bngpvepright
rsfMRI_fcnxpro122_perafPoint260_BNGPVePRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint260.bngpvepright
rsfMRI_fcnxpro122_falffPoint261_THMETHHNRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint261.thmethhnright
rsfMRI_fcnxpro122_alffPoint261_THMETHHNRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint261.thmethhnright
rsfMRI_fcnxpro122_perafPoint261_THMETHHNRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint261.thmethhnright
rsfMRI_fcnxpro122_falffPoint262_DieHTHRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint262.diehthright
rsfMRI_fcnxpro122_alffPoint262_DieHTHRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint262.diehthright
rsfMRI_fcnxpro122_perafPoint262_DieHTHRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint262.diehthright
rsfMRI_fcnxpro122_falffPoint263_DieHTHMNRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint263.diehthmnright
rsfMRI_fcnxpro122_alffPoint263_DieHTHMNRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint263.diehthmnright
rsfMRI_fcnxpro122_perafPoint263_DieHTHMNRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint263.diehthmnright
rsfMRI_fcnxpro122_falffPoint264_DieSTHRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint264.diesthright
rsfMRI_fcnxpro122_alffPoint264_DieSTHRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint264.diesthright
rsfMRI_fcnxpro122_perafPoint264_DieSTHRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint264.diesthright
rsfMRI_fcnxpro122_falffPoint265_ReferenceRegionLeft
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint265.referenceregionleft
rsfMRI_fcnxpro122_alffPoint265_ReferenceRegionLeft
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint265.referenceregionleft
rsfMRI_fcnxpro122_perafPoint265_ReferenceRegionLeft
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint265.referenceregionleft
rsfMRI_fcnxpro122_falffPoint266_ReferenceRegionRight
restingStatefMRI
​
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.p1.falffpoint266.referenceregionright
rsfMRI_fcnxpro122_alffPoint266_ReferenceRegionRight
restingStatefMRI
​
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.p1.alffpoint266.referenceregionright
rsfMRI_fcnxpro122_perafPoint266_ReferenceRegionRight
restingStatefMRI
​
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.p1.perafpoint266.referenceregionright
rsfMRI_fcnxpro122_DefaultMode_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.defaultmode.mean
rsfMRI_fcnxpro122_Visual_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.visual.mean
rsfMRI_fcnxpro122_motion_corrected_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.motion.corrected.mean
rsfMRI_fcnxpro122_PerAF_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.p1.peraf.mean
rsfMRI_fcnxpro122_tsnr_mean
restingStatefMRI
​
yeo_homotopic
mean TSNR in time series
​
rsf.p1.tsnr.mean
rsfMRI_fcnxpro122_ssnr_mean
restingStatefMRI
​
yeo_homotopic
mean spatial SNR in mean bold
​
rsf.p1.ssnr.mean
rsfMRI_fcnxpro122_dvars_mean
restingStatefMRI
​
yeo_homotopic
mean DVARS
​
rsf.p1.dvars.mean
rsfMRI_fcnxpro122_bandpass_freq_0
restingStatefMRI
​
yeo_homotopic
band pass frequency limit
​
rsf.p1.bandpass.freq.0
rsfMRI_fcnxpro122_bandpass_freq_1
restingStatefMRI
​
yeo_homotopic
band pass frequency limit
​
rsf.p1.bandpass.freq.1
rsfMRI_fcnxpro122_censor
restingStatefMRI
​
yeo_homotopic
ignore
​
rsf.p1.censor
rsfMRI_fcnxpro122_spatial_smoothing
restingStatefMRI
​
yeo_homotopic
spatial smoothing parameter
​
rsf.p1.spatial.smoothing
rsfMRI_fcnxpro122_outlier_threshold
restingStatefMRI
​
yeo_homotopic
outlier threshold parameter
​
rsf.p1.outlier.threshold
rsfMRI_fcnxpro122_FD_threshold
restingStatefMRI
​
yeo_homotopic
FD threshold paramter
​
rsf.p1.fd.threshold
rsfMRI_fcnxpro122_high_motion_count
restingStatefMRI
​
yeo_homotopic
high motion count
​
rsf.p1.high.motion.count
rsfMRI_fcnxpro122_high_motion_pct
restingStatefMRI
​
yeo_homotopic
percent high motion count
​
rsf.p1.high.motion.pct
rsfMRI_fcnxpro122_despiking_count_summary
restingStatefMRI
​
yeo_homotopic
changes made in despiking
​
rsf.p1.despiking.count.summary
rsfMRI_fcnxpro122_FD_max
restingStatefMRI
​
yeo_homotopic
max framewise displacement
​
rsf.p1.fd.max
rsfMRI_fcnxpro122_FD_mean
restingStatefMRI
​
yeo_homotopic
mean framewise displacement
​
rsf.p1.fd.mean
rsfMRI_fcnxpro122_FD_sd
restingStatefMRI
​
yeo_homotopic
global sd of image
​
rsf.p1.fd.sd
rsfMRI_fcnxpro122_bold_evr
restingStatefMRI
​
yeo_homotopic
eigenvector ratio for mean bold
​
rsf.p1.bold.evr
rsfMRI_fcnxpro122_n_outliers
restingStatefMRI
​
yeo_homotopic
number of outlier volumes
​
rsf.p1.n.outliers
rsfMRI_fcnxpro122_nc_wm
restingStatefMRI
​
yeo_homotopic
number of white matter compcor components
​
rsf.p1.nc.wm
rsfMRI_fcnxpro122_nc_csf
restingStatefMRI
​
yeo_homotopic
number of csf compcor components
​
rsf.p1.nc.csf
rsfMRI_fcnxpro122_minutes_original_data
restingStatefMRI
​
yeo_homotopic
minutes of rs imaging
​
rsf.p1.minutes.original.data
rsfMRI_fcnxpro122_minutes_censored_data
restingStatefMRI
​
yeo_homotopic
minutes of rs imaging after censoring
​
rsf.p1.minutes.censored.data
rsfMRI_fcnxpro122_TempPar_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.temppar
rsfMRI_fcnxpro122_TempPar_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.defaultc
rsfMRI_fcnxpro122_TempPar_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.defaultb
rsfMRI_fcnxpro122_TempPar_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.defaulta
rsfMRI_fcnxpro122_TempPar_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.contc
rsfMRI_fcnxpro122_TempPar_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.contb
rsfMRI_fcnxpro122_TempPar_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.conta
rsfMRI_fcnxpro122_TempPar_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.limbica
rsfMRI_fcnxpro122_TempPar_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.limbicb
rsfMRI_fcnxpro122_TempPar_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.salventattnb
rsfMRI_fcnxpro122_TempPar_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.salventattna
rsfMRI_fcnxpro122_TempPar_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.dorsattnb
rsfMRI_fcnxpro122_TempPar_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.dorsattna
rsfMRI_fcnxpro122_TempPar_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.sommotb
rsfMRI_fcnxpro122_TempPar_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.sommota
rsfMRI_fcnxpro122_TempPar_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.visperi
rsfMRI_fcnxpro122_TempPar_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.viscent
rsfMRI_fcnxpro122_TempPar_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.striatum
rsfMRI_fcnxpro122_TempPar_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.dopamine
rsfMRI_fcnxpro122_TempPar_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.citlimbic
rsfMRI_fcnxpro122_TempPar_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.basalganglia
rsfMRI_fcnxpro122_TempPar_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.temppar.2.midbrain
rsfMRI_fcnxpro122_DefaultC_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.temppar
rsfMRI_fcnxpro122_DefaultC_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.defaultc
rsfMRI_fcnxpro122_DefaultC_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.defaultb
rsfMRI_fcnxpro122_DefaultC_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.defaulta
rsfMRI_fcnxpro122_DefaultC_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.contc
rsfMRI_fcnxpro122_DefaultC_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.contb
rsfMRI_fcnxpro122_DefaultC_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.conta
rsfMRI_fcnxpro122_DefaultC_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.limbica
rsfMRI_fcnxpro122_DefaultC_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.limbicb
rsfMRI_fcnxpro122_DefaultC_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.salventattnb
rsfMRI_fcnxpro122_DefaultC_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.salventattna
rsfMRI_fcnxpro122_DefaultC_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.dorsattnb
rsfMRI_fcnxpro122_DefaultC_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.dorsattna
rsfMRI_fcnxpro122_DefaultC_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.sommotb
rsfMRI_fcnxpro122_DefaultC_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.sommota
rsfMRI_fcnxpro122_DefaultC_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.visperi
rsfMRI_fcnxpro122_DefaultC_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.viscent
rsfMRI_fcnxpro122_DefaultC_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.striatum
rsfMRI_fcnxpro122_DefaultC_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.dopamine
rsfMRI_fcnxpro122_DefaultC_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.citlimbic
rsfMRI_fcnxpro122_DefaultC_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.basalganglia
rsfMRI_fcnxpro122_DefaultC_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultc.2.midbrain
rsfMRI_fcnxpro122_DefaultB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.temppar
rsfMRI_fcnxpro122_DefaultB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.defaultc
rsfMRI_fcnxpro122_DefaultB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.defaultb
rsfMRI_fcnxpro122_DefaultB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.defaulta
rsfMRI_fcnxpro122_DefaultB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.contc
rsfMRI_fcnxpro122_DefaultB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.contb
rsfMRI_fcnxpro122_DefaultB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.conta
rsfMRI_fcnxpro122_DefaultB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.limbica
rsfMRI_fcnxpro122_DefaultB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.limbicb
rsfMRI_fcnxpro122_DefaultB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.salventattnb
rsfMRI_fcnxpro122_DefaultB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.salventattna
rsfMRI_fcnxpro122_DefaultB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.dorsattnb
rsfMRI_fcnxpro122_DefaultB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.dorsattna
rsfMRI_fcnxpro122_DefaultB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.sommotb
rsfMRI_fcnxpro122_DefaultB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.sommota
rsfMRI_fcnxpro122_DefaultB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.visperi
rsfMRI_fcnxpro122_DefaultB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.viscent
rsfMRI_fcnxpro122_DefaultB_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.striatum
rsfMRI_fcnxpro122_DefaultB_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.dopamine
rsfMRI_fcnxpro122_DefaultB_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.citlimbic
rsfMRI_fcnxpro122_DefaultB_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.basalganglia
rsfMRI_fcnxpro122_DefaultB_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaultb.2.midbrain
rsfMRI_fcnxpro122_DefaultA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.temppar
rsfMRI_fcnxpro122_DefaultA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.defaultc
rsfMRI_fcnxpro122_DefaultA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.defaultb
rsfMRI_fcnxpro122_DefaultA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.defaulta
rsfMRI_fcnxpro122_DefaultA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.contc
rsfMRI_fcnxpro122_DefaultA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.contb
rsfMRI_fcnxpro122_DefaultA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.conta
rsfMRI_fcnxpro122_DefaultA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.limbica
rsfMRI_fcnxpro122_DefaultA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.limbicb
rsfMRI_fcnxpro122_DefaultA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.salventattnb
rsfMRI_fcnxpro122_DefaultA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.salventattna
rsfMRI_fcnxpro122_DefaultA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.dorsattnb
rsfMRI_fcnxpro122_DefaultA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.dorsattna
rsfMRI_fcnxpro122_DefaultA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.sommotb
rsfMRI_fcnxpro122_DefaultA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.sommota
rsfMRI_fcnxpro122_DefaultA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.visperi
rsfMRI_fcnxpro122_DefaultA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.viscent
rsfMRI_fcnxpro122_DefaultA_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.striatum
rsfMRI_fcnxpro122_DefaultA_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.dopamine
rsfMRI_fcnxpro122_DefaultA_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.citlimbic
rsfMRI_fcnxpro122_DefaultA_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.basalganglia
rsfMRI_fcnxpro122_DefaultA_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.defaulta.2.midbrain
rsfMRI_fcnxpro122_ContC_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.temppar
rsfMRI_fcnxpro122_ContC_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.defaultc
rsfMRI_fcnxpro122_ContC_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.defaultb
rsfMRI_fcnxpro122_ContC_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.defaulta
rsfMRI_fcnxpro122_ContC_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.contc
rsfMRI_fcnxpro122_ContC_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.contb
rsfMRI_fcnxpro122_ContC_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.conta
rsfMRI_fcnxpro122_ContC_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.limbica
rsfMRI_fcnxpro122_ContC_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.limbicb
rsfMRI_fcnxpro122_ContC_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.salventattnb
rsfMRI_fcnxpro122_ContC_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.salventattna
rsfMRI_fcnxpro122_ContC_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.dorsattnb
rsfMRI_fcnxpro122_ContC_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.dorsattna
rsfMRI_fcnxpro122_ContC_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.sommotb
rsfMRI_fcnxpro122_ContC_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.sommota
rsfMRI_fcnxpro122_ContC_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.visperi
rsfMRI_fcnxpro122_ContC_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.viscent
rsfMRI_fcnxpro122_ContC_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.striatum
rsfMRI_fcnxpro122_ContC_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.dopamine
rsfMRI_fcnxpro122_ContC_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.citlimbic
rsfMRI_fcnxpro122_ContC_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.basalganglia
rsfMRI_fcnxpro122_ContC_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contc.2.midbrain
rsfMRI_fcnxpro122_ContB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.temppar
rsfMRI_fcnxpro122_ContB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.defaultc
rsfMRI_fcnxpro122_ContB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.defaultb
rsfMRI_fcnxpro122_ContB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.defaulta
rsfMRI_fcnxpro122_ContB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.contc
rsfMRI_fcnxpro122_ContB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.contb
rsfMRI_fcnxpro122_ContB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.conta
rsfMRI_fcnxpro122_ContB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.limbica
rsfMRI_fcnxpro122_ContB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.limbicb
rsfMRI_fcnxpro122_ContB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.salventattnb
rsfMRI_fcnxpro122_ContB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.salventattna
rsfMRI_fcnxpro122_ContB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.dorsattnb
rsfMRI_fcnxpro122_ContB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.dorsattna
rsfMRI_fcnxpro122_ContB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.sommotb
rsfMRI_fcnxpro122_ContB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.sommota
rsfMRI_fcnxpro122_ContB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.visperi
rsfMRI_fcnxpro122_ContB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.viscent
rsfMRI_fcnxpro122_ContB_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.striatum
rsfMRI_fcnxpro122_ContB_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.dopamine
rsfMRI_fcnxpro122_ContB_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.citlimbic
rsfMRI_fcnxpro122_ContB_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.basalganglia
rsfMRI_fcnxpro122_ContB_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.contb.2.midbrain
rsfMRI_fcnxpro122_ContA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.temppar
rsfMRI_fcnxpro122_ContA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.defaultc
rsfMRI_fcnxpro122_ContA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.defaultb
rsfMRI_fcnxpro122_ContA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.defaulta
rsfMRI_fcnxpro122_ContA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.contc
rsfMRI_fcnxpro122_ContA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.contb
rsfMRI_fcnxpro122_ContA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.conta
rsfMRI_fcnxpro122_ContA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.limbica
rsfMRI_fcnxpro122_ContA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.limbicb
rsfMRI_fcnxpro122_ContA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.salventattnb
rsfMRI_fcnxpro122_ContA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.salventattna
rsfMRI_fcnxpro122_ContA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.dorsattnb
rsfMRI_fcnxpro122_ContA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.dorsattna
rsfMRI_fcnxpro122_ContA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.sommotb
rsfMRI_fcnxpro122_ContA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.sommota
rsfMRI_fcnxpro122_ContA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.visperi
rsfMRI_fcnxpro122_ContA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.viscent
rsfMRI_fcnxpro122_ContA_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.striatum
rsfMRI_fcnxpro122_ContA_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.dopamine
rsfMRI_fcnxpro122_ContA_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.citlimbic
rsfMRI_fcnxpro122_ContA_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.basalganglia
rsfMRI_fcnxpro122_ContA_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.conta.2.midbrain
rsfMRI_fcnxpro122_LimbicA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.temppar
rsfMRI_fcnxpro122_LimbicA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.defaultc
rsfMRI_fcnxpro122_LimbicA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.defaultb
rsfMRI_fcnxpro122_LimbicA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.defaulta
rsfMRI_fcnxpro122_LimbicA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.contc
rsfMRI_fcnxpro122_LimbicA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.contb
rsfMRI_fcnxpro122_LimbicA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.conta
rsfMRI_fcnxpro122_LimbicA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.limbica
rsfMRI_fcnxpro122_LimbicA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.limbicb
rsfMRI_fcnxpro122_LimbicA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.salventattnb
rsfMRI_fcnxpro122_LimbicA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.salventattna
rsfMRI_fcnxpro122_LimbicA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.dorsattnb
rsfMRI_fcnxpro122_LimbicA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.dorsattna
rsfMRI_fcnxpro122_LimbicA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.sommotb
rsfMRI_fcnxpro122_LimbicA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.sommota
rsfMRI_fcnxpro122_LimbicA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.visperi
rsfMRI_fcnxpro122_LimbicA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.viscent
rsfMRI_fcnxpro122_LimbicA_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.striatum
rsfMRI_fcnxpro122_LimbicA_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.dopamine
rsfMRI_fcnxpro122_LimbicA_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.citlimbic
rsfMRI_fcnxpro122_LimbicA_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.basalganglia
rsfMRI_fcnxpro122_LimbicA_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbica.2.midbrain
rsfMRI_fcnxpro122_LimbicB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.temppar
rsfMRI_fcnxpro122_LimbicB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.defaultc
rsfMRI_fcnxpro122_LimbicB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.defaultb
rsfMRI_fcnxpro122_LimbicB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.defaulta
rsfMRI_fcnxpro122_LimbicB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.contc
rsfMRI_fcnxpro122_LimbicB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.contb
rsfMRI_fcnxpro122_LimbicB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.conta
rsfMRI_fcnxpro122_LimbicB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.limbica
rsfMRI_fcnxpro122_LimbicB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.limbicb
rsfMRI_fcnxpro122_LimbicB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.salventattnb
rsfMRI_fcnxpro122_LimbicB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.salventattna
rsfMRI_fcnxpro122_LimbicB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.dorsattnb
rsfMRI_fcnxpro122_LimbicB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.dorsattna
rsfMRI_fcnxpro122_LimbicB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.sommotb
rsfMRI_fcnxpro122_LimbicB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.sommota
rsfMRI_fcnxpro122_LimbicB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.visperi
rsfMRI_fcnxpro122_LimbicB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.viscent
rsfMRI_fcnxpro122_LimbicB_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.striatum
rsfMRI_fcnxpro122_LimbicB_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.dopamine
rsfMRI_fcnxpro122_LimbicB_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.citlimbic
rsfMRI_fcnxpro122_LimbicB_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.basalganglia
rsfMRI_fcnxpro122_LimbicB_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.limbicb.2.midbrain
rsfMRI_fcnxpro122_SalVentAttnB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.temppar
rsfMRI_fcnxpro122_SalVentAttnB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.defaultc
rsfMRI_fcnxpro122_SalVentAttnB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.defaultb
rsfMRI_fcnxpro122_SalVentAttnB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.defaulta
rsfMRI_fcnxpro122_SalVentAttnB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.contc
rsfMRI_fcnxpro122_SalVentAttnB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.contb
rsfMRI_fcnxpro122_SalVentAttnB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.conta
rsfMRI_fcnxpro122_SalVentAttnB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.limbica
rsfMRI_fcnxpro122_SalVentAttnB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.limbicb
rsfMRI_fcnxpro122_SalVentAttnB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.salventattnb
rsfMRI_fcnxpro122_SalVentAttnB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.salventattna
rsfMRI_fcnxpro122_SalVentAttnB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.dorsattnb
rsfMRI_fcnxpro122_SalVentAttnB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.dorsattna
rsfMRI_fcnxpro122_SalVentAttnB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.sommotb
rsfMRI_fcnxpro122_SalVentAttnB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.sommota
rsfMRI_fcnxpro122_SalVentAttnB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.visperi
rsfMRI_fcnxpro122_SalVentAttnB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.viscent
rsfMRI_fcnxpro122_SalVentAttnB_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.striatum
rsfMRI_fcnxpro122_SalVentAttnB_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.dopamine
rsfMRI_fcnxpro122_SalVentAttnB_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.citlimbic
rsfMRI_fcnxpro122_SalVentAttnB_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.basalganglia
rsfMRI_fcnxpro122_SalVentAttnB_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattnb.2.midbrain
rsfMRI_fcnxpro122_SalVentAttnA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.temppar
rsfMRI_fcnxpro122_SalVentAttnA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.defaultc
rsfMRI_fcnxpro122_SalVentAttnA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.defaultb
rsfMRI_fcnxpro122_SalVentAttnA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.defaulta
rsfMRI_fcnxpro122_SalVentAttnA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.contc
rsfMRI_fcnxpro122_SalVentAttnA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.contb
rsfMRI_fcnxpro122_SalVentAttnA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.conta
rsfMRI_fcnxpro122_SalVentAttnA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.limbica
rsfMRI_fcnxpro122_SalVentAttnA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.limbicb
rsfMRI_fcnxpro122_SalVentAttnA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.salventattnb
rsfMRI_fcnxpro122_SalVentAttnA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.salventattna
rsfMRI_fcnxpro122_SalVentAttnA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.dorsattnb
rsfMRI_fcnxpro122_SalVentAttnA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.dorsattna
rsfMRI_fcnxpro122_SalVentAttnA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.sommotb
rsfMRI_fcnxpro122_SalVentAttnA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.sommota
rsfMRI_fcnxpro122_SalVentAttnA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.visperi
rsfMRI_fcnxpro122_SalVentAttnA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.viscent
rsfMRI_fcnxpro122_SalVentAttnA_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.striatum
rsfMRI_fcnxpro122_SalVentAttnA_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.dopamine
rsfMRI_fcnxpro122_SalVentAttnA_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.citlimbic
rsfMRI_fcnxpro122_SalVentAttnA_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.basalganglia
rsfMRI_fcnxpro122_SalVentAttnA_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.salventattna.2.midbrain
rsfMRI_fcnxpro122_DorsAttnB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.temppar
rsfMRI_fcnxpro122_DorsAttnB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.defaultc
rsfMRI_fcnxpro122_DorsAttnB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.defaultb
rsfMRI_fcnxpro122_DorsAttnB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.defaulta
rsfMRI_fcnxpro122_DorsAttnB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.contc
rsfMRI_fcnxpro122_DorsAttnB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.contb
rsfMRI_fcnxpro122_DorsAttnB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.conta
rsfMRI_fcnxpro122_DorsAttnB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.limbica
rsfMRI_fcnxpro122_DorsAttnB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.limbicb
rsfMRI_fcnxpro122_DorsAttnB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.salventattnb
rsfMRI_fcnxpro122_DorsAttnB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.salventattna
rsfMRI_fcnxpro122_DorsAttnB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.dorsattnb
rsfMRI_fcnxpro122_DorsAttnB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.dorsattna
rsfMRI_fcnxpro122_DorsAttnB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.sommotb
rsfMRI_fcnxpro122_DorsAttnB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.sommota
rsfMRI_fcnxpro122_DorsAttnB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.visperi
rsfMRI_fcnxpro122_DorsAttnB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.viscent
rsfMRI_fcnxpro122_DorsAttnB_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.striatum
rsfMRI_fcnxpro122_DorsAttnB_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.dopamine
rsfMRI_fcnxpro122_DorsAttnB_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.citlimbic
rsfMRI_fcnxpro122_DorsAttnB_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.basalganglia
rsfMRI_fcnxpro122_DorsAttnB_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattnb.2.midbrain
rsfMRI_fcnxpro122_DorsAttnA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.temppar
rsfMRI_fcnxpro122_DorsAttnA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.defaultc
rsfMRI_fcnxpro122_DorsAttnA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.defaultb
rsfMRI_fcnxpro122_DorsAttnA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.defaulta
rsfMRI_fcnxpro122_DorsAttnA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.contc
rsfMRI_fcnxpro122_DorsAttnA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.contb
rsfMRI_fcnxpro122_DorsAttnA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.conta
rsfMRI_fcnxpro122_DorsAttnA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.limbica
rsfMRI_fcnxpro122_DorsAttnA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.limbicb
rsfMRI_fcnxpro122_DorsAttnA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.salventattnb
rsfMRI_fcnxpro122_DorsAttnA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.salventattna
rsfMRI_fcnxpro122_DorsAttnA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.dorsattnb
rsfMRI_fcnxpro122_DorsAttnA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.dorsattna
rsfMRI_fcnxpro122_DorsAttnA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.sommotb
rsfMRI_fcnxpro122_DorsAttnA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.sommota
rsfMRI_fcnxpro122_DorsAttnA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.visperi
rsfMRI_fcnxpro122_DorsAttnA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.viscent
rsfMRI_fcnxpro122_DorsAttnA_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.striatum
rsfMRI_fcnxpro122_DorsAttnA_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.dopamine
rsfMRI_fcnxpro122_DorsAttnA_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.citlimbic
rsfMRI_fcnxpro122_DorsAttnA_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.basalganglia
rsfMRI_fcnxpro122_DorsAttnA_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dorsattna.2.midbrain
rsfMRI_fcnxpro122_SomMotB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.temppar
rsfMRI_fcnxpro122_SomMotB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.defaultc
rsfMRI_fcnxpro122_SomMotB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.defaultb
rsfMRI_fcnxpro122_SomMotB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.defaulta
rsfMRI_fcnxpro122_SomMotB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.contc
rsfMRI_fcnxpro122_SomMotB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.contb
rsfMRI_fcnxpro122_SomMotB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.conta
rsfMRI_fcnxpro122_SomMotB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.limbica
rsfMRI_fcnxpro122_SomMotB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.limbicb
rsfMRI_fcnxpro122_SomMotB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.salventattnb
rsfMRI_fcnxpro122_SomMotB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.salventattna
rsfMRI_fcnxpro122_SomMotB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.dorsattnb
rsfMRI_fcnxpro122_SomMotB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.dorsattna
rsfMRI_fcnxpro122_SomMotB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.sommotb
rsfMRI_fcnxpro122_SomMotB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.sommota
rsfMRI_fcnxpro122_SomMotB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.visperi
rsfMRI_fcnxpro122_SomMotB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.viscent
rsfMRI_fcnxpro122_SomMotB_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.striatum
rsfMRI_fcnxpro122_SomMotB_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.dopamine
rsfMRI_fcnxpro122_SomMotB_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.citlimbic
rsfMRI_fcnxpro122_SomMotB_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.basalganglia
rsfMRI_fcnxpro122_SomMotB_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommotb.2.midbrain
rsfMRI_fcnxpro122_SomMotA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.temppar
rsfMRI_fcnxpro122_SomMotA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.defaultc
rsfMRI_fcnxpro122_SomMotA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.defaultb
rsfMRI_fcnxpro122_SomMotA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.defaulta
rsfMRI_fcnxpro122_SomMotA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.contc
rsfMRI_fcnxpro122_SomMotA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.contb
rsfMRI_fcnxpro122_SomMotA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.conta
rsfMRI_fcnxpro122_SomMotA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.limbica
rsfMRI_fcnxpro122_SomMotA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.limbicb
rsfMRI_fcnxpro122_SomMotA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.salventattnb
rsfMRI_fcnxpro122_SomMotA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.salventattna
rsfMRI_fcnxpro122_SomMotA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.dorsattnb
rsfMRI_fcnxpro122_SomMotA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.dorsattna
rsfMRI_fcnxpro122_SomMotA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.sommotb
rsfMRI_fcnxpro122_SomMotA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.sommota
rsfMRI_fcnxpro122_SomMotA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.visperi
rsfMRI_fcnxpro122_SomMotA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.viscent
rsfMRI_fcnxpro122_SomMotA_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.striatum
rsfMRI_fcnxpro122_SomMotA_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.dopamine
rsfMRI_fcnxpro122_SomMotA_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.citlimbic
rsfMRI_fcnxpro122_SomMotA_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.basalganglia
rsfMRI_fcnxpro122_SomMotA_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.sommota.2.midbrain
rsfMRI_fcnxpro122_VisPeri_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.temppar
rsfMRI_fcnxpro122_VisPeri_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.defaultc
rsfMRI_fcnxpro122_VisPeri_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.defaultb
rsfMRI_fcnxpro122_VisPeri_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.defaulta
rsfMRI_fcnxpro122_VisPeri_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.contc
rsfMRI_fcnxpro122_VisPeri_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.contb
rsfMRI_fcnxpro122_VisPeri_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.conta
rsfMRI_fcnxpro122_VisPeri_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.limbica
rsfMRI_fcnxpro122_VisPeri_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.limbicb
rsfMRI_fcnxpro122_VisPeri_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.salventattnb
rsfMRI_fcnxpro122_VisPeri_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.salventattna
rsfMRI_fcnxpro122_VisPeri_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.dorsattnb
rsfMRI_fcnxpro122_VisPeri_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.dorsattna
rsfMRI_fcnxpro122_VisPeri_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.sommotb
rsfMRI_fcnxpro122_VisPeri_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.sommota
rsfMRI_fcnxpro122_VisPeri_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.visperi
rsfMRI_fcnxpro122_VisPeri_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.viscent
rsfMRI_fcnxpro122_VisPeri_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.striatum
rsfMRI_fcnxpro122_VisPeri_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.dopamine
rsfMRI_fcnxpro122_VisPeri_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.citlimbic
rsfMRI_fcnxpro122_VisPeri_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.basalganglia
rsfMRI_fcnxpro122_VisPeri_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.visperi.2.midbrain
rsfMRI_fcnxpro122_VisCent_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.temppar
rsfMRI_fcnxpro122_VisCent_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.defaultc
rsfMRI_fcnxpro122_VisCent_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.defaultb
rsfMRI_fcnxpro122_VisCent_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.defaulta
rsfMRI_fcnxpro122_VisCent_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.contc
rsfMRI_fcnxpro122_VisCent_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.contb
rsfMRI_fcnxpro122_VisCent_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.conta
rsfMRI_fcnxpro122_VisCent_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.limbica
rsfMRI_fcnxpro122_VisCent_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.limbicb
rsfMRI_fcnxpro122_VisCent_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.salventattnb
rsfMRI_fcnxpro122_VisCent_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.salventattna
rsfMRI_fcnxpro122_VisCent_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.dorsattnb
rsfMRI_fcnxpro122_VisCent_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.dorsattna
rsfMRI_fcnxpro122_VisCent_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.sommotb
rsfMRI_fcnxpro122_VisCent_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.sommota
rsfMRI_fcnxpro122_VisCent_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.visperi
rsfMRI_fcnxpro122_VisCent_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.viscent
rsfMRI_fcnxpro122_VisCent_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.striatum
rsfMRI_fcnxpro122_VisCent_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.dopamine
rsfMRI_fcnxpro122_VisCent_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.citlimbic
rsfMRI_fcnxpro122_VisCent_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.basalganglia
rsfMRI_fcnxpro122_VisCent_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.viscent.2.midbrain
rsfMRI_fcnxpro122_Striatum_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.temppar
rsfMRI_fcnxpro122_Striatum_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.defaultc
rsfMRI_fcnxpro122_Striatum_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.defaultb
rsfMRI_fcnxpro122_Striatum_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.defaulta
rsfMRI_fcnxpro122_Striatum_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.contc
rsfMRI_fcnxpro122_Striatum_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.contb
rsfMRI_fcnxpro122_Striatum_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.conta
rsfMRI_fcnxpro122_Striatum_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.limbica
rsfMRI_fcnxpro122_Striatum_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.limbicb
rsfMRI_fcnxpro122_Striatum_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.salventattnb
rsfMRI_fcnxpro122_Striatum_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.salventattna
rsfMRI_fcnxpro122_Striatum_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.dorsattnb
rsfMRI_fcnxpro122_Striatum_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.dorsattna
rsfMRI_fcnxpro122_Striatum_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.sommotb
rsfMRI_fcnxpro122_Striatum_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.sommota
rsfMRI_fcnxpro122_Striatum_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.visperi
rsfMRI_fcnxpro122_Striatum_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.viscent
rsfMRI_fcnxpro122_Striatum_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.striatum
rsfMRI_fcnxpro122_Striatum_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.dopamine
rsfMRI_fcnxpro122_Striatum_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.citlimbic
rsfMRI_fcnxpro122_Striatum_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.basalganglia
rsfMRI_fcnxpro122_Striatum_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.striatum.2.midbrain
rsfMRI_fcnxpro122_Dopamine_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.temppar
rsfMRI_fcnxpro122_Dopamine_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.defaultc
rsfMRI_fcnxpro122_Dopamine_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.defaultb
rsfMRI_fcnxpro122_Dopamine_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.defaulta
rsfMRI_fcnxpro122_Dopamine_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.contc
rsfMRI_fcnxpro122_Dopamine_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.contb
rsfMRI_fcnxpro122_Dopamine_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.conta
rsfMRI_fcnxpro122_Dopamine_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.limbica
rsfMRI_fcnxpro122_Dopamine_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.limbicb
rsfMRI_fcnxpro122_Dopamine_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.salventattnb
rsfMRI_fcnxpro122_Dopamine_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.salventattna
rsfMRI_fcnxpro122_Dopamine_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.dorsattnb
rsfMRI_fcnxpro122_Dopamine_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.dorsattna
rsfMRI_fcnxpro122_Dopamine_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.sommotb
rsfMRI_fcnxpro122_Dopamine_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.sommota
rsfMRI_fcnxpro122_Dopamine_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.visperi
rsfMRI_fcnxpro122_Dopamine_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.viscent
rsfMRI_fcnxpro122_Dopamine_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.striatum
rsfMRI_fcnxpro122_Dopamine_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.dopamine
rsfMRI_fcnxpro122_Dopamine_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.citlimbic
rsfMRI_fcnxpro122_Dopamine_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.basalganglia
rsfMRI_fcnxpro122_Dopamine_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.dopamine.2.midbrain
rsfMRI_fcnxpro122_CITLimbic_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.temppar
rsfMRI_fcnxpro122_CITLimbic_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.defaultc
rsfMRI_fcnxpro122_CITLimbic_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.defaultb
rsfMRI_fcnxpro122_CITLimbic_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.defaulta
rsfMRI_fcnxpro122_CITLimbic_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.contc
rsfMRI_fcnxpro122_CITLimbic_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.contb
rsfMRI_fcnxpro122_CITLimbic_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.conta
rsfMRI_fcnxpro122_CITLimbic_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.limbica
rsfMRI_fcnxpro122_CITLimbic_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.limbicb
rsfMRI_fcnxpro122_CITLimbic_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.salventattnb
rsfMRI_fcnxpro122_CITLimbic_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.salventattna
rsfMRI_fcnxpro122_CITLimbic_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.dorsattnb
rsfMRI_fcnxpro122_CITLimbic_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.dorsattna
rsfMRI_fcnxpro122_CITLimbic_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.sommotb
rsfMRI_fcnxpro122_CITLimbic_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.sommota
rsfMRI_fcnxpro122_CITLimbic_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.visperi
rsfMRI_fcnxpro122_CITLimbic_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.viscent
rsfMRI_fcnxpro122_CITLimbic_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.striatum
rsfMRI_fcnxpro122_CITLimbic_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.dopamine
rsfMRI_fcnxpro122_CITLimbic_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.citlimbic
rsfMRI_fcnxpro122_CITLimbic_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.basalganglia
rsfMRI_fcnxpro122_CITLimbic_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.citlimbic.2.midbrain
rsfMRI_fcnxpro122_BasalGanglia_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.temppar
rsfMRI_fcnxpro122_BasalGanglia_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.defaultc
rsfMRI_fcnxpro122_BasalGanglia_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.defaultb
rsfMRI_fcnxpro122_BasalGanglia_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.defaulta
rsfMRI_fcnxpro122_BasalGanglia_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.contc
rsfMRI_fcnxpro122_BasalGanglia_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.contb
rsfMRI_fcnxpro122_BasalGanglia_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.conta
rsfMRI_fcnxpro122_BasalGanglia_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.limbica
rsfMRI_fcnxpro122_BasalGanglia_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.limbicb
rsfMRI_fcnxpro122_BasalGanglia_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.salventattnb
rsfMRI_fcnxpro122_BasalGanglia_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.salventattna
rsfMRI_fcnxpro122_BasalGanglia_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.dorsattnb
rsfMRI_fcnxpro122_BasalGanglia_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.dorsattna
rsfMRI_fcnxpro122_BasalGanglia_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.sommotb
rsfMRI_fcnxpro122_BasalGanglia_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.sommota
rsfMRI_fcnxpro122_BasalGanglia_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.visperi
rsfMRI_fcnxpro122_BasalGanglia_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.viscent
rsfMRI_fcnxpro122_BasalGanglia_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.striatum
rsfMRI_fcnxpro122_BasalGanglia_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.dopamine
rsfMRI_fcnxpro122_BasalGanglia_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.citlimbic
rsfMRI_fcnxpro122_BasalGanglia_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.basalganglia
rsfMRI_fcnxpro122_BasalGanglia_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.basalganglia.2.midbrain
rsfMRI_fcnxpro122_MidBrain_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.temppar
rsfMRI_fcnxpro122_MidBrain_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.defaultc
rsfMRI_fcnxpro122_MidBrain_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.defaultb
rsfMRI_fcnxpro122_MidBrain_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.defaulta
rsfMRI_fcnxpro122_MidBrain_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.contc
rsfMRI_fcnxpro122_MidBrain_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.contb
rsfMRI_fcnxpro122_MidBrain_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.conta
rsfMRI_fcnxpro122_MidBrain_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.limbica
rsfMRI_fcnxpro122_MidBrain_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.limbicb
rsfMRI_fcnxpro122_MidBrain_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.salventattnb
rsfMRI_fcnxpro122_MidBrain_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.salventattna
rsfMRI_fcnxpro122_MidBrain_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.dorsattnb
rsfMRI_fcnxpro122_MidBrain_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.dorsattna
rsfMRI_fcnxpro122_MidBrain_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.sommotb
rsfMRI_fcnxpro122_MidBrain_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.sommota
rsfMRI_fcnxpro122_MidBrain_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.visperi
rsfMRI_fcnxpro122_MidBrain_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.viscent
rsfMRI_fcnxpro122_MidBrain_2_Striatum
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.striatum
rsfMRI_fcnxpro122_MidBrain_2_Dopamine
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.dopamine
rsfMRI_fcnxpro122_MidBrain_2_CITLimbic
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.citlimbic
rsfMRI_fcnxpro122_MidBrain_2_BasalGanglia
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.basalganglia
rsfMRI_fcnxpro122_MidBrain_2_MidBrain
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.p1.midbrain.2.midbrain
NM2DMT_mean_bn_gp_gpe_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
globus pallidus externa
nm2dmt.mean.bn.gp.gpe.left
NM2DMT_mean_bn_gp_gpe_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
globus pallidus externa
nm2dmt.mean.bn.gp.gpe.right
NM2DMT_mean_bn_gp_gpi_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
globus pallidus interna
nm2dmt.mean.bn.gp.gpi.left
NM2DMT_mean_bn_gp_gpi_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
globus pallidus interna
nm2dmt.mean.bn.gp.gpi.right
NM2DMT_mean_bn_str_pu_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
putamen
nm2dmt.mean.bn.str.pu.left
NM2DMT_mean_bn_str_pu_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
putamen
nm2dmt.mean.bn.str.pu.right
NM2DMT_mean_mtg_rn_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
red nucleus
nm2dmt.mean.mtg.rn.left
NM2DMT_mean_mtg_rn_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
red nucleus
nm2dmt.mean.mtg.rn.right
NM2DMT_mean_mtg_sn_snc_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
Substantia Nigra pars compacta
nm2dmt.mean.snc.left
NM2DMT_mean_mtg_sn_snc_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
Substantia Nigra pars compacta
nm2dmt.mean.snc.right
NM2DMT_mean_mtg_sn_snr_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
Substantia Nigra pars reticulated
nm2dmt.mean.snr.left
NM2DMT_mean_mtg_sn_snr_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
Substantia Nigra pars reticulated
nm2dmt.mean.snr.right
NM2DMT_mean_referenceregion_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
​
nm2dmt.mean.referenceregion.left
NM2DMT_mean_referenceregion_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
​
nm2dmt.mean.referenceregion.right
NM2DMT_NM_avg_mean
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.avg.mean
NM2DMT_NM_avg_cropped_mean
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.avg.cropped.mean
NM2DMT_NM_labels_mean
Neuromelanin
​
ANTs
​
​
nm2dmt.nm.labels.mean
NM2DMT_NM_midbrainROI_mean
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.midbrainroi.mean
NM2DMT_t1_to_NM_mean
Neuromelanin
​
ANTs
​
​
nm2dmt.t1.to.nm.mean
NM2DMT_t1_to_NM_transform_mean
Neuromelanin
​
ANTs
​
​
nm2dmt.t1.to.nm.transform.mean
NM2DMT_NM_volume_substantianigra
Neuromelanin
​
ANTs
geometry/volume
NM2DMT NMsubstantianigra
nm2dmt.nm.volume.substantianigra
NM2DMT_NM_volume_substantianigra_2std
Neuromelanin
​
ANTs
geometry/volume
NM2DMT NMsubstantianigra 2std
nm2dmt.nm.volume.substantianigra.2std
NM2DMT_NM_intmean_substantianigra_2std
Neuromelanin
​
ANTs
​
​
nm2dmt.nm.intmean.substantianigra.2std
NM2DMT_NM_intsum_substantianigra_2std
Neuromelanin
​
ANTs
​
​
nm2dmt.nm.intsum.substantianigra.2std
NM2DMT_NM_volume_substantianigra_3std
Neuromelanin
​
ANTs
geometry/volume
NM2DMT NMsubstantianigra 3std
nm2dmt.nm.volume.substantianigra.3std
NM2DMT_NM_volume_substantianigra_4std
Neuromelanin
​
ANTs
geometry/volume
NM2DMT NMsubstantianigra 4std
nm2dmt.nm.volume.substantianigra.4std
NM2DMT_NM_q0pt05
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
nm2dmt.nm.q0pt05
NM2DMT_NM_q0pt10
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
nm2dmt.nm.q0pt10
NM2DMT_NM_q0pt90
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
nm2dmt.nm.q0pt90
NM2DMT_NM_q0pt95
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
nm2dmt.nm.q0pt95
NM2DMT_NM_substantianigra_z_coordinate
Neuromelanin
​
ANTs
Estimate of the normalize (zero to one) z-coordinate of the substantia nigra in a neuromelanin scan; higher values mean higher in the slab
​
nm2dmt.nm.substantianigra.z.coordinate
NM2DMT_NM_evr
Neuromelanin
​
ANTs
QC
​
nm2dmt.nm.evr
NM2DMT_NM_count
Neuromelanin
​
ANTs
count of neuromelanin scans that were averaged at this date
​
nm2dmt.nm.count
DTI_mean_fa.anterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
anterior corona radiata
dti.fa.ant.cor.rad.left
DTI_mean_fa.anterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
anterior corona radiata
dti.fa.ant.cor.rad.right
DTI_mean_fa.anterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
anterior limb of internal capsule
dti.fa.ant.int.cap.left
DTI_mean_fa.anterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
anterior limb of internal capsule
dti.fa.ant.int.cap.right
DTI_mean_fa.body_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
body of corpus callosum
dti.fa.body.of.corpus.callosum
DTI_mean_fa.cerebral_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
cerebral peduncle
dti.fa.cerebral.peduncle.left
DTI_mean_fa.cerebral_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
cerebral peduncle
dti.fa.cerebral.peduncle.right
DTI_mean_fa.cingulum_.cingulate_gyrus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
cingulum cingulate gyrus
dti.fa.cingulum.cingulate.gyrus.left
DTI_mean_fa.cingulum_.cingulate_gyrus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
cingulum cingulate gyrus
dti.fa.cingulum.cingulate.gyrus.right
DTI_mean_fa.cingulum_.hippocampus..left.jhu_icbm_labels_1mm
DTI
left
desikan-killiany-tourville
fractional anisotropy
hippocampus
dti.fa.cingulum.hippocampus.left
DTI_mean_fa.cingulum_.hippocampus..right.jhu_icbm_labels_1mm
DTI
right
desikan-killiany-tourville
fractional anisotropy
hippocampus
dti.fa.cingulum.hippocampus.right
DTI_mean_fa.corticospinal_tract.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
corticospinal tract
dti.fa.corticospinal.tract.left
DTI_mean_fa.corticospinal_tract.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
corticospinal tract
dti.fa.corticospinal.tract.right
DTI_mean_fa.external_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
external capsule
dti.fa.ext.cap.left
DTI_mean_fa.external_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
external capsule
dti.fa.ext.cap.right
DTI_mean_fa.fornix_.column_and_body_of_fornix..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
fornix column and body of fornix
dti.fa.fornix.column.and.body.of.fornix.
DTI_mean_fa.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
fornix cres stria terminalis can not be resolved with current resolution
dti.fa.fornixleft
DTI_mean_fa.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
fornix cres stria terminalis can not be resolved with current resolution
dti.fa.fornixright
DTI_mean_fa.genu_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
genu of corpus callosum
dti.fa.genu.of.corpus.callosum
DTI_mean_fa.inferior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
inferior cerebellar peduncle
dti.fa.inf.cereb.ped.left
DTI_mean_fa.inferior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
inferior cerebellar peduncle
dti.fa.inf.cereb.ped.right
DTI_mean_fa.inferior_fronto.occipital_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
inferior fronto occipital fasciculus
dti.fa.inf.frnt.occ.fasciculus.left
DTI_mean_fa.inferior_fronto.occipital_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
inferior fronto occipital fasciculus
dti.fa.inf.frnt.occ.fasciculus.right
DTI_mean_fa.medial_lemniscus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
medial lemniscus
dti.fa.medial.lemniscus.left
DTI_mean_fa.medial_lemniscus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
medial lemniscus
dti.fa.medial.lemniscus.right
DTI_mean_fa.middle_cerebellar_peduncle.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
middle cerebellar peduncle
dti.fa.middle.cereb.ped
DTI_mean_fa.pontine_crossing_tract_.a_part_of_mcp..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
pontine crossing tract a part of mcp
dti.fa.pontine.
DTI_mean_fa.posterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
posterior corona radiata
dti.fa.post.cor.rad.left
DTI_mean_fa.posterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
posterior corona radiata
dti.fa.post.cor.rad.right
DTI_mean_fa.posterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
posterior limb of internal capsule
dti.fa.post.int.cap.left
DTI_mean_fa.posterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
posterior limb of internal capsule
dti.fa.post.int.cap.right
DTI_mean_fa.posterior_thalamic_radiation_.include_optic_radiation..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
posterior thalamic radiation include optic radiation
dti.fa.post.thalamic.radiation.left
DTI_mean_fa.posterior_thalamic_radiation_.include_optic_radiation..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
posterior thalamic radiation include optic radiation
dti.fa.post.thalamic.radiation.right
DTI_mean_fa.retrolenticular_part_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
retrolenticular part of internal capsule
dti.fa.rent.int.cap.left
DTI_mean_fa.retrolenticular_part_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
retrolenticular part of internal capsule
dti.fa.rent.int.cap.right
DTI_mean_fa.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
sagittal stratum include inferior longitidinal fasciculus and inferior fronto occipital fasciculus
dti.fa.ilf.and.ifoleft
DTI_mean_fa.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
sagittal stratum include inferior longitidinal fasciculus and inferior fronto occipital fasciculus
dti.fa.ilf.and.iforight
DTI_mean_fa.splenium_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
splenium of corpus callosum
dti.fa.splenium.of.corpus.callosum
DTI_mean_fa.superior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
superior cerebellar peduncle
dti.fa.sup.cereb.ped.left
DTI_mean_fa.superior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
superior cerebellar peduncle
dti.fa.sup.cereb.ped.right
DTI_mean_fa.superior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
superior corona radiata
dti.fa.sup.cor.rad.left
DTI_mean_fa.superior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
superior corona radiata
dti.fa.sup.cor.rad.right
DTI_mean_fa.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
superior fronto occipital fasciculus could be a part of anterior internal capsule
dti.fa.sup.frnt.occ.fasc.left
DTI_mean_fa.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
superior fronto occipital fasciculus could be a part of anterior internal capsule
dti.fa.sup.frnt.occ.fasc.right
DTI_mean_fa.superior_longitudinal_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
superior longitudinal fasciculus
dti.fa.sup.l.fasc.left
DTI_mean_fa.superior_longitudinal_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
superior longitudinal fasciculus
dti.fa.sup.l.fasc.right
DTI_mean_fa.tapetum.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
tapetum
dti.fa.tapetum.left
DTI_mean_fa.tapetum.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
tapetum
dti.fa.tapetum.right
DTI_mean_fa.uncinate_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
uncinate fasciculus
dti.fa.uncinate.fasciculus.left
DTI_mean_fa.uncinate_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
uncinate fasciculus
dti.fa.uncinate.fasciculus.right
DTI_mean_fa.unclassified.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
unclassified
dti.fa.unclassified
DTI_mean_md.anterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
anterior corona radiata
dti.mean.md.ant.cor.rad.left
DTI_mean_md.anterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
anterior corona radiata
dti.mean.md.ant.cor.rad.right
DTI_mean_md.anterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
anterior limb of internal capsule
dti.mean.md.ant.int.cap.left
DTI_mean_md.anterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
anterior limb of internal capsule
dti.mean.md.ant.int.cap.right
DTI_mean_md.body_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
body of corpus callosum
dti.mean.md.body.of.corpus.callosum
DTI_mean_md.cerebral_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
cerebral peduncle
dti.mean.md.cerebral.peduncle.left
DTI_mean_md.cerebral_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
cerebral peduncle
dti.mean.md.cerebral.peduncle.right
DTI_mean_md.cingulum_.cingulate_gyrus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
cingulum cingulate gyrus
dti.mean.md.cingulum.cingulate.gyrus.left
DTI_mean_md.cingulum_.cingulate_gyrus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
cingulum cingulate gyrus
dti.mean.md.cingulum.cingulate.gyrus.right
DTI_mean_md.cingulum_.hippocampus..left.jhu_icbm_labels_1mm
DTI
left
desikan-killiany-tourville
mean diffusion
hippocampus
dti.mean.md.cingulum.hippocampus.left
DTI_mean_md.cingulum_.hippocampus..right.jhu_icbm_labels_1mm
DTI
right
desikan-killiany-tourville
mean diffusion
hippocampus
dti.mean.md.cingulum.hippocampus.right
DTI_mean_md.corticospinal_tract.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
corticospinal tract
dti.mean.md.corticospinal.tract.left
DTI_mean_md.corticospinal_tract.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
corticospinal tract
dti.mean.md.corticospinal.tract.right
DTI_mean_md.external_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
external capsule
dti.mean.md.ext.cap.left
DTI_mean_md.external_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
external capsule
dti.mean.md.ext.cap.right
DTI_mean_md.fornix_.column_and_body_of_fornix..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
fornix column and body of fornix
dti.mean.md.fornix.column.and.body.of.fornix.
DTI_mean_md.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
fornix cres stria terminalis can not be resolved with current resolution
dti.mean.md.fornixleft
DTI_mean_md.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
fornix cres stria terminalis can not be resolved with current resolution
dti.mean.md.fornixright
DTI_mean_md.genu_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
genu of corpus callosum
dti.mean.md.genu.of.corpus.callosum
DTI_mean_md.inferior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
inferior cerebellar peduncle
dti.mean.md.inf.cereb.ped.left
DTI_mean_md.inferior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
inferior cerebellar peduncle
dti.mean.md.inf.cereb.ped.right
DTI_mean_md.inferior_fronto.occipital_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
inferior fronto occipital fasciculus
dti.mean.md.inf.frnt.occ.fasciculus.left
DTI_mean_md.inferior_fronto.occipital_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
inferior fronto occipital fasciculus
dti.mean.md.inf.frnt.occ.fasciculus.right
DTI_mean_md.medial_lemniscus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
medial lemniscus
dti.mean.md.medial.lemniscus.left
DTI_mean_md.medial_lemniscus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
medial lemniscus
dti.mean.md.medial.lemniscus.right
DTI_mean_md.middle_cerebellar_peduncle.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
middle cerebellar peduncle
dti.mean.md.middle.cereb.ped
DTI_mean_md.pontine_crossing_tract_.a_part_of_mcp..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
pontine crossing tract a part of mcp
dti.mean.md.pontine.
DTI_mean_md.posterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
posterior corona radiata
dti.mean.md.post.cor.rad.left
DTI_mean_md.posterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
posterior corona radiata
dti.mean.md.post.cor.rad.right
DTI_mean_md.posterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
posterior limb of internal capsule
dti.mean.md.post.int.cap.left
DTI_mean_md.posterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
posterior limb of internal capsule
dti.mean.md.post.int.cap.right
DTI_mean_md.posterior_thalamic_radiation_.include_optic_radiation..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
posterior thalamic radiation include optic radiation
dti.mean.md.post.thalamic.radiation.left
DTI_mean_md.posterior_thalamic_radiation_.include_optic_radiation..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
posterior thalamic radiation include optic radiation
dti.mean.md.post.thalamic.radiation.right
DTI_mean_md.retrolenticular_part_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
retrolenticular part of internal capsule
dti.mean.md.rent.int.cap.left
DTI_mean_md.retrolenticular_part_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
retrolenticular part of internal capsule
dti.mean.md.rent.int.cap.right
DTI_mean_md.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
sagittal stratum include inferior longitidinal fasciculus and inferior fronto occipital fasciculus
dti.mean.md.ilf.and.ifoleft
DTI_mean_md.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
sagittal stratum include inferior longitidinal fasciculus and inferior fronto occipital fasciculus
dti.mean.md.ilf.and.iforight
DTI_mean_md.splenium_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
splenium of corpus callosum
dti.mean.md.splenium.of.corpus.callosum
DTI_mean_md.superior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
superior cerebellar peduncle
dti.mean.md.sup.cereb.ped.left
DTI_mean_md.superior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
superior cerebellar peduncle
dti.mean.md.sup.cereb.ped.right
DTI_mean_md.superior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
superior corona radiata
dti.mean.md.sup.cor.rad.left
DTI_mean_md.superior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
superior corona radiata
dti.mean.md.sup.cor.rad.right
DTI_mean_md.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
superior fronto occipital fasciculus could be a part of anterior internal capsule
dti.mean.md.sup.frnt.occ.fasc.left
DTI_mean_md.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
superior fronto occipital fasciculus could be a part of anterior internal capsule
dti.mean.md.sup.frnt.occ.fasc.right
DTI_mean_md.superior_longitudinal_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
superior longitudinal fasciculus
dti.mean.md.sup.l.fasc.left
DTI_mean_md.superior_longitudinal_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
superior longitudinal fasciculus
dti.mean.md.sup.l.fasc.right
DTI_mean_md.tapetum.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
tapetum
dti.mean.md.tapetum.left
DTI_mean_md.tapetum.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
tapetum
dti.mean.md.tapetum.right
DTI_mean_md.uncinate_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
uncinate fasciculus
dti.mean.md.uncinate.fasciculus.left
DTI_mean_md.uncinate_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
uncinate fasciculus
dti.mean.md.uncinate.fasciculus.right
DTI_mean_md.unclassified.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
unclassified
dti.mean.md.unclassified
DTI_mean_fa_background
DTI
​
ANTs
fractional anisotropy
background
dti.fa.background
DTI_mean_fa_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
caudal anterior cingulate
dti.fa.left.caudal.ant.cingulate
DTI_mean_fa_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
caudal middle frontal
dti.fa.left.caudal.middle.frontal
DTI_mean_fa_left_cuneus
DTI
left
desikan-killiany-tourville
fractional anisotropy
cuneus
dti.fa.left.cuneus
DTI_mean_fa_left_entorhinal
DTI
left
desikan-killiany-tourville
fractional anisotropy
entorhinal
dti.fa.left.entorhinal
DTI_mean_fa_left_fusiform
DTI
left
desikan-killiany-tourville
fractional anisotropy
fusiform
dti.fa.left.fusiform
DTI_mean_fa_left_inferior_parietal
DTI
left
desikan-killiany-tourville
fractional anisotropy
inferior parietal
dti.fa.left.inf.parietal
DTI_mean_fa_left_inferior_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
inferior temporal
dti.fa.left.inf.temporal
DTI_mean_fa_left_insula
DTI
left
desikan-killiany-tourville
fractional anisotropy
insula
dti.fa.left.insula
DTI_mean_fa_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
isthmus cingulate
dti.fa.left.isthmus.cingulate
DTI_mean_fa_left_lateral_occipital
DTI
left
desikan-killiany-tourville
fractional anisotropy
lateral occipital
dti.fa.left.lateral.occipital
DTI_mean_fa_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
lateral orbitofrontal
dti.fa.left.lateral.orbitofrontal
DTI_mean_fa_left_lingual
DTI
left
desikan-killiany-tourville
fractional anisotropy
lingual
dti.fa.left.lingual
DTI_mean_fa_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
medial orbitofrontal
dti.fa.left.medial.orbitofrontal
DTI_mean_fa_left_middle_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
middle temporal
dti.fa.left.middle.temporal
DTI_mean_fa_left_paracentral
DTI
left
desikan-killiany-tourville
fractional anisotropy
paracentral
dti.fa.left.paracent
DTI_mean_fa_left_parahippocampal
DTI
left
desikan-killiany-tourville
fractional anisotropy
parahippocampal
dti.fa.left.parahippocampal
DTI_mean_fa_left_pars_opercularis
DTI
left
desikan-killiany-tourville
fractional anisotropy
pars opercularis
dti.fa.left.pars.opercularis
DTI_mean_fa_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
fractional anisotropy
pars orbitalis
dti.fa.left.pars.orbitalis
DTI_mean_fa_left_pars_triangularis
DTI
left
desikan-killiany-tourville
fractional anisotropy
pars triangularis
dti.fa.left.pars.triangularis
DTI_mean_fa_left_pericalcarine
DTI
left
desikan-killiany-tourville
fractional anisotropy
pericalcarine
dti.fa.left.pericalcarine
DTI_mean_fa_left_postcentral
DTI
left
desikan-killiany-tourville
fractional anisotropy
postcentral
dti.fa.left.postcent
DTI_mean_fa_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
posterior cingulate
dti.fa.left.post.cingulate
DTI_mean_fa_left_precentral
DTI
left
desikan-killiany-tourville
fractional anisotropy
precentral
dti.fa.left.precent
DTI_mean_fa_left_precuneus
DTI
left
desikan-killiany-tourville
fractional anisotropy
precuneus
dti.fa.left.precuneus
DTI_mean_fa_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
rostral anterior cingulate
dti.fa.left.rostral.ant.cingulate
DTI_mean_fa_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
rostral middle frontal
dti.fa.left.rostral.middle.frontal
DTI_mean_fa_left_superior_frontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
superior frontal
dti.fa.left.sup.frontal
DTI_mean_fa_left_superior_parietal
DTI
left
desikan-killiany-tourville
fractional anisotropy
superior parietal
dti.fa.left.sup.parietal
DTI_mean_fa_left_superior_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
superior temporal
dti.fa.left.sup.temporal
DTI_mean_fa_left_supramarginal
DTI
left
desikan-killiany-tourville
fractional anisotropy
supramarginal
dti.fa.left.supramarginal
DTI_mean_fa_left_transverse_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
transverse temporal
dti.fa.left.transverse.temporal
DTI_mean_fa_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
caudal anterior cingulate
dti.fa.right.caudal.ant.cingulate
DTI_mean_fa_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
caudal middle frontal
dti.fa.right.caudal.middle.frontal
DTI_mean_fa_right_cuneus
DTI
right
desikan-killiany-tourville
fractional anisotropy
cuneus
dti.fa.right.cuneus
DTI_mean_fa_right_entorhinal
DTI
right
desikan-killiany-tourville
fractional anisotropy
entorhinal
dti.fa.right.entorhinal
DTI_mean_fa_right_fusiform
DTI
right
desikan-killiany-tourville
fractional anisotropy
fusiform
dti.fa.right.fusiform
DTI_mean_fa_right_inferior_parietal
DTI
right
desikan-killiany-tourville
fractional anisotropy
inferior parietal
dti.fa.right.inf.parietal
DTI_mean_fa_right_inferior_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
inferior temporal
dti.fa.right.inf.temporal
DTI_mean_fa_right_insula
DTI
right
desikan-killiany-tourville
fractional anisotropy
insula
dti.fa.right.insula
DTI_mean_fa_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
isthmus cingulate
dti.fa.right.isthmus.cingulate
DTI_mean_fa_right_lateral_occipital
DTI
right
desikan-killiany-tourville
fractional anisotropy
lateral occipital
dti.fa.right.lateral.occipital
DTI_mean_fa_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
lateral orbitofrontal
dti.fa.right.lateral.orbitofrontal
DTI_mean_fa_right_lingual
DTI
right
desikan-killiany-tourville
fractional anisotropy
lingual
dti.fa.right.lingual
DTI_mean_fa_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
medial orbitofrontal
dti.fa.right.medial.orbitofrontal
DTI_mean_fa_right_middle_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
middle temporal
dti.fa.right.middle.temporal
DTI_mean_fa_right_paracentral
DTI
right
desikan-killiany-tourville
fractional anisotropy
paracentral
dti.fa.right.paracent
DTI_mean_fa_right_parahippocampal
DTI
right
desikan-killiany-tourville
fractional anisotropy
parahippocampal
dti.fa.right.parahippocampal
DTI_mean_fa_right_pars_opercularis
DTI
right
desikan-killiany-tourville
fractional anisotropy
pars opercularis
dti.fa.right.pars.opercularis
DTI_mean_fa_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
fractional anisotropy
pars orbitalis
dti.fa.right.pars.orbitalis
DTI_mean_fa_right_pars_triangularis
DTI
right
desikan-killiany-tourville
fractional anisotropy
pars triangularis
dti.fa.right.pars.triangularis
DTI_mean_fa_right_pericalcarine
DTI
right
desikan-killiany-tourville
fractional anisotropy
pericalcarine
dti.fa.right.pericalcarine
DTI_mean_fa_right_postcentral
DTI
right
desikan-killiany-tourville
fractional anisotropy
postcentral
dti.fa.right.postcent
DTI_mean_fa_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
posterior cingulate
dti.fa.right.post.cingulate
DTI_mean_fa_right_precentral
DTI
right
desikan-killiany-tourville
fractional anisotropy
precentral
dti.fa.right.precent
DTI_mean_fa_right_precuneus
DTI
right
desikan-killiany-tourville
fractional anisotropy
precuneus
dti.fa.right.precuneus
DTI_mean_fa_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
rostral anterior cingulate
dti.fa.right.rostral.ant.cingulate
DTI_mean_fa_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
rostral middle frontal
dti.fa.right.rostral.middle.frontal
DTI_mean_fa_right_superior_frontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
superior frontal
dti.fa.right.sup.frontal
DTI_mean_fa_right_superior_parietal
DTI
right
desikan-killiany-tourville
fractional anisotropy
superior parietal
dti.fa.right.sup.parietal
DTI_mean_fa_right_superior_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
superior temporal
dti.fa.right.sup.temporal
DTI_mean_fa_right_supramarginal
DTI
right
desikan-killiany-tourville
fractional anisotropy
supramarginal
dti.fa.right.supramarginal
DTI_mean_fa_right_transverse_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
transverse temporal
dti.fa.right.transverse.temporal
DTI_volume_fa_background
DTI
​
ANTs
geometry/volume
background
dti.volume.fa.background
DTI_volume_fa_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
dti.volume.fa.left.caudal.ant.cingulate
DTI_volume_fa_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
dti.volume.fa.left.caudal.middle.frontal
DTI_volume_fa_left_cuneus
DTI
left
desikan-killiany-tourville
geometry/volume
cuneus
dti.volume.fa.left.cuneus
DTI_volume_fa_left_entorhinal
DTI
left
desikan-killiany-tourville
geometry/volume
entorhinal
dti.volume.fa.left.entorhinal
DTI_volume_fa_left_fusiform
DTI
left
desikan-killiany-tourville
geometry/volume
fusiform
dti.volume.fa.left.fusiform
DTI_volume_fa_left_inferior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior parietal
dti.volume.fa.left.inf.parietal
DTI_volume_fa_left_inferior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior temporal
dti.volume.fa.left.inf.temporal
DTI_volume_fa_left_insula
DTI
left
desikan-killiany-tourville
geometry/volume
insula
dti.volume.fa.left.insula
DTI_volume_fa_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
dti.volume.fa.left.isthmus.cingulate
DTI_volume_fa_left_lateral_occipital
DTI
left
desikan-killiany-tourville
geometry/volume
lateral occipital
dti.volume.fa.left.lateral.occipital
DTI_volume_fa_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
dti.volume.fa.left.lateral.orbitofrontal
DTI_volume_fa_left_lingual
DTI
left
desikan-killiany-tourville
geometry/volume
lingual
dti.volume.fa.left.lingual
DTI_volume_fa_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
dti.volume.fa.left.medial.orbitofrontal
DTI_volume_fa_left_middle_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
middle temporal
dti.volume.fa.left.middle.temporal
DTI_volume_fa_left_paracentral
DTI
left
desikan-killiany-tourville
geometry/volume
paracentral
dti.volume.fa.left.paracent
DTI_volume_fa_left_parahippocampal
DTI
left
desikan-killiany-tourville
geometry/volume
parahippocampal
dti.volume.fa.left.parahippocampal
DTI_volume_fa_left_pars_opercularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars opercularis
dti.volume.fa.left.pars.opercularis
DTI_volume_fa_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
dti.volume.fa.left.pars.orbitalis
DTI_volume_fa_left_pars_triangularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars triangularis
dti.volume.fa.left.pars.triangularis
DTI_volume_fa_left_pericalcarine
DTI
left
desikan-killiany-tourville
geometry/volume
pericalcarine
dti.volume.fa.left.pericalcarine
DTI_volume_fa_left_postcentral
DTI
left
desikan-killiany-tourville
geometry/volume
postcentral
dti.volume.fa.left.postcent
DTI_volume_fa_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
dti.volume.fa.left.post.cingulate
DTI_volume_fa_left_precentral
DTI
left
desikan-killiany-tourville
geometry/volume
precentral
dti.volume.fa.left.precent
DTI_volume_fa_left_precuneus
DTI
left
desikan-killiany-tourville
geometry/volume
precuneus
dti.volume.fa.left.precuneus
DTI_volume_fa_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
dti.volume.fa.left.rostral.ant.cingulate
DTI_volume_fa_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
dti.volume.fa.left.rostral.middle.frontal
DTI_volume_fa_left_superior_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
superior frontal
dti.volume.fa.left.sup.frontal
DTI_volume_fa_left_superior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
superior parietal
dti.volume.fa.left.sup.parietal
DTI_volume_fa_left_superior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
superior temporal
dti.volume.fa.left.sup.temporal
DTI_volume_fa_left_supramarginal
DTI
left
desikan-killiany-tourville
geometry/volume
supramarginal
dti.volume.fa.left.supramarginal
DTI_volume_fa_left_transverse_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
transverse temporal
dti.volume.fa.left.transverse.temporal
DTI_volume_fa_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
dti.volume.fa.right.caudal.ant.cingulate
DTI_volume_fa_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
dti.volume.fa.right.caudal.middle.frontal
DTI_volume_fa_right_cuneus
DTI
right
desikan-killiany-tourville
geometry/volume
cuneus
dti.volume.fa.right.cuneus
DTI_volume_fa_right_entorhinal
DTI
right
desikan-killiany-tourville
geometry/volume
entorhinal
dti.volume.fa.right.entorhinal
DTI_volume_fa_right_fusiform
DTI
right
desikan-killiany-tourville
geometry/volume
fusiform
dti.volume.fa.right.fusiform
DTI_volume_fa_right_inferior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior parietal
dti.volume.fa.right.inf.parietal
DTI_volume_fa_right_inferior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior temporal
dti.volume.fa.right.inf.temporal
DTI_volume_fa_right_insula
DTI
right
desikan-killiany-tourville
geometry/volume
insula
dti.volume.fa.right.insula
DTI_volume_fa_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
dti.volume.fa.right.isthmus.cingulate
DTI_volume_fa_right_lateral_occipital
DTI
right
desikan-killiany-tourville
geometry/volume
lateral occipital
dti.volume.fa.right.lateral.occipital
DTI_volume_fa_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
dti.volume.fa.right.lateral.orbitofrontal
DTI_volume_fa_right_lingual
DTI
right
desikan-killiany-tourville
geometry/volume
lingual
dti.volume.fa.right.lingual
DTI_volume_fa_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
dti.volume.fa.right.medial.orbitofrontal
DTI_volume_fa_right_middle_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
middle temporal
dti.volume.fa.right.middle.temporal
DTI_volume_fa_right_paracentral
DTI
right
desikan-killiany-tourville
geometry/volume
paracentral
dti.volume.fa.right.paracent
DTI_volume_fa_right_parahippocampal
DTI
right
desikan-killiany-tourville
geometry/volume
parahippocampal
dti.volume.fa.right.parahippocampal
DTI_volume_fa_right_pars_opercularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars opercularis
dti.volume.fa.right.pars.opercularis
DTI_volume_fa_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
dti.volume.fa.right.pars.orbitalis
DTI_volume_fa_right_pars_triangularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars triangularis
dti.volume.fa.right.pars.triangularis
DTI_volume_fa_right_pericalcarine
DTI
right
desikan-killiany-tourville
geometry/volume
pericalcarine
dti.volume.fa.right.pericalcarine
DTI_volume_fa_right_postcentral
DTI
right
desikan-killiany-tourville
geometry/volume
postcentral
dti.volume.fa.right.postcent
DTI_volume_fa_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
dti.volume.fa.right.post.cingulate
DTI_volume_fa_right_precentral
DTI
right
desikan-killiany-tourville
geometry/volume
precentral
dti.volume.fa.right.precent
DTI_volume_fa_right_precuneus
DTI
right
desikan-killiany-tourville
geometry/volume
precuneus
dti.volume.fa.right.precuneus
DTI_volume_fa_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
dti.volume.fa.right.rostral.ant.cingulate
DTI_volume_fa_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
dti.volume.fa.right.rostral.middle.frontal
DTI_volume_fa_right_superior_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
superior frontal
dti.volume.fa.right.sup.frontal
DTI_volume_fa_right_superior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
superior parietal
dti.volume.fa.right.sup.parietal
DTI_volume_fa_right_superior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
superior temporal
dti.volume.fa.right.sup.temporal
DTI_volume_fa_right_supramarginal
DTI
right
desikan-killiany-tourville
geometry/volume
supramarginal
dti.volume.fa.right.supramarginal
DTI_volume_fa_right_transverse_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
transverse temporal
dti.volume.fa.right.transverse.temporal
DTI_mean_fa_deep_bn_gp_gpe_left
DTI
left
CIT168
fractional anisotropy
globus pallidus externa
dti.fa.deep.bn.gp.gpe.left
DTI_mean_fa_deep_bn_gp_gpe_right
DTI
right
CIT168
fractional anisotropy
globus pallidus externa
dti.fa.deep.bn.gp.gpe.right
DTI_mean_fa_deep_bn_gp_gpi_left
DTI
left
CIT168
fractional anisotropy
globus pallidus interna
dti.fa.deep.bn.gp.gpi.left
DTI_mean_fa_deep_bn_gp_gpi_right
DTI
right
CIT168
fractional anisotropy
globus pallidus interna
dti.fa.deep.bn.gp.gpi.right
DTI_mean_fa_deep_bn_str_ca_left
DTI
left
CIT168
fractional anisotropy
caudate
dti.fa.deep.bn.str.ca.left
DTI_mean_fa_deep_bn_str_ca_right
DTI
right
CIT168
fractional anisotropy
caudate
dti.fa.deep.bn.str.ca.right
DTI_mean_fa_deep_bn_str_pu_left
DTI
left
CIT168
fractional anisotropy
putamen
dti.fa.deep.bn.str.pu.left
DTI_mean_fa_deep_bn_str_pu_right
DTI
right
CIT168
fractional anisotropy
putamen
dti.fa.deep.bn.str.pu.right
DTI_mean_fa_deep_mtg_rn_left
DTI
left
CIT168
fractional anisotropy
red nucleus
dti.fa.deep.mtg.rn.left
DTI_mean_fa_deep_mtg_rn_right
DTI
right
CIT168
fractional anisotropy
red nucleus
dti.fa.deep.mtg.rn.right
DTI_mean_fa_deep_mtg_sn_snc_left
DTI
left
CIT168
fractional anisotropy
Substantia Nigra pars compacta
dti.fa.deep.snc.left
DTI_mean_fa_deep_mtg_sn_snc_right
DTI
right
CIT168
fractional anisotropy
Substantia Nigra pars compacta
dti.fa.deep.snc.right
DTI_mean_fa_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.fa.deep.snr.left
DTI_mean_fa_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.fa.deep.snr.right
DTI_mean_fa_deep_referenceregion_left
DTI
left
CIT168
fractional anisotropy
​
dti.fa.deep.referenceregion.left
DTI_mean_fa_deep_referenceregion_right
DTI
right
CIT168
fractional anisotropy
​
dti.fa.deep.referenceregion.right
DTI_volume_fa_deep_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
dti.volume.fa.deep.bn.gp.gpe.left
DTI_volume_fa_deep_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
dti.volume.fa.deep.bn.gp.gpe.right
DTI_volume_fa_deep_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
dti.volume.fa.deep.bn.gp.gpi.left
DTI_volume_fa_deep_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
dti.volume.fa.deep.bn.gp.gpi.right
DTI_volume_fa_deep_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
dti.volume.fa.deep.bn.str.ca.left
DTI_volume_fa_deep_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
dti.volume.fa.deep.bn.str.ca.right
DTI_volume_fa_deep_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
dti.volume.fa.deep.bn.str.pu.left
DTI_volume_fa_deep_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
dti.volume.fa.deep.bn.str.pu.right
DTI_volume_fa_deep_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
dti.volume.fa.deep.mtg.rn.left
DTI_volume_fa_deep_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
dti.volume.fa.deep.mtg.rn.right
DTI_volume_fa_deep_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.fa.deep.snc.left
DTI_volume_fa_deep_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.fa.deep.snc.right
DTI_volume_fa_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.fa.deep.snr.left
DTI_volume_fa_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.fa.deep.snr.right
DTI_volume_fa_deep_referenceregion_left
DTI
left
CIT168
geometry/volume
​
dti.volume.fa.deep.referenceregion.left
DTI_volume_fa_deep_referenceregion_right
DTI
right
CIT168
geometry/volume
​
dti.volume.fa.deep.referenceregion.right
DTI_mean_fa_bn_gp_gpe_left
DTI
left
CIT168
fractional anisotropy
globus pallidus externa
dti.fa.bn.gp.gpe.left
DTI_mean_fa_bn_gp_gpe_right
DTI
right
CIT168
fractional anisotropy
globus pallidus externa
dti.fa.bn.gp.gpe.right
DTI_mean_fa_bn_gp_gpi_left
DTI
left
CIT168
fractional anisotropy
globus pallidus interna
dti.fa.bn.gp.gpi.left
DTI_mean_fa_bn_gp_gpi_right
DTI
right
CIT168
fractional anisotropy
globus pallidus interna
dti.fa.bn.gp.gpi.right
DTI_mean_fa_bn_gp_vep_left
DTI
left
CIT168
fractional anisotropy
ventral pallidum
dti.fa.bn.gp.vep.left
DTI_mean_fa_bn_gp_vep_right
DTI
right
CIT168
fractional anisotropy
ventral pallidum
dti.fa.bn.gp.vep.right
DTI_mean_fa_bn_str_ca_left
DTI
left
CIT168
fractional anisotropy
caudate
dti.fa.bn.str.ca.left
DTI_mean_fa_bn_str_ca_right
DTI
right
CIT168
fractional anisotropy
caudate
dti.fa.bn.str.ca.right
DTI_mean_fa_bn_str_nac_left
DTI
left
CIT168
fractional anisotropy
Nucleus Accumbens
dti.fa.bn.str.nac.left
DTI_mean_fa_bn_str_nac_right
DTI
right
CIT168
fractional anisotropy
Nucleus Accumbens
dti.fa.bn.str.nac.right
DTI_mean_fa_bn_str_pu_left
DTI
left
CIT168
fractional anisotropy
putamen
dti.fa.bn.str.pu.left
DTI_mean_fa_bn_str_pu_right
DTI
right
CIT168
fractional anisotropy
putamen
dti.fa.bn.str.pu.right
DTI_mean_fa_die_hth_left
DTI
left
CIT168
fractional anisotropy
Hypothalamus
dti.fa.die.hth.left
DTI_mean_fa_die_hth_mn_left
DTI
left
CIT168
fractional anisotropy
mammillary nucleus
dti.fa.die.hth.mn.left
DTI_mean_fa_die_hth_mn_right
DTI
right
CIT168
fractional anisotropy
mammillary nucleus
dti.fa.die.hth.mn.right
DTI_mean_fa_die_hth_right
DTI
right
CIT168
fractional anisotropy
Hypothalamus
dti.fa.die.hth.right
DTI_mean_fa_die_sth_left
DTI
left
CIT168
fractional anisotropy
Subthalamic Nucleus
dti.fa.die.sth.left
DTI_mean_fa_die_sth_right
DTI
right
CIT168
fractional anisotropy
Subthalamic Nucleus
dti.fa.die.sth.right
DTI_mean_fa_exa_left
DTI
left
CIT168
fractional anisotropy
extended amygdala
dti.fa.exa.left
DTI_mean_fa_exa_right
DTI
right
CIT168
fractional anisotropy
extended amygdala
dti.fa.exa.right
DTI_mean_fa_mtg_rn_left
DTI
left
CIT168
fractional anisotropy
red nucleus
dti.fa.mtg.rn.left
DTI_mean_fa_mtg_rn_right
DTI
right
CIT168
fractional anisotropy
red nucleus
dti.fa.mtg.rn.right
DTI_mean_fa_mtg_sn_snc_left
DTI
left
CIT168
fractional anisotropy
Substantia Nigra pars compacta
dti.fa.snc.left
DTI_mean_fa_mtg_sn_snc_right
DTI
right
CIT168
fractional anisotropy
Substantia Nigra pars compacta
dti.fa.snc.right
DTI_mean_fa_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.fa.snr.left
DTI_mean_fa_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.fa.snr.right
DTI_mean_fa_mtg_vtr_pbp_left
DTI
left
CIT168
fractional anisotropy
Parabrachial Pigmented Nucleus
dti.fa.mtg.vtr.pbp.left
DTI_mean_fa_mtg_vtr_pbp_right
DTI
right
CIT168
fractional anisotropy
Parabrachial Pigmented Nucleus
dti.fa.mtg.vtr.pbp.right
DTI_mean_fa_mtg_vtr_vta_left
DTI
left
CIT168
fractional anisotropy
Ventral Tegmental Area
dti.fa.mtg.vtr.vta.left
DTI_mean_fa_mtg_vtr_vta_right
DTI
right
CIT168
fractional anisotropy
Ventral Tegmental Area
dti.fa.mtg.vtr.vta.right
DTI_mean_fa_referenceregion_left
DTI
left
CIT168
fractional anisotropy
​
dti.fa.referenceregion.left
DTI_mean_fa_referenceregion_right
DTI
right
CIT168
fractional anisotropy
​
dti.fa.referenceregion.right
DTI_mean_fa_thm_eth_hn_left
DTI
left
CIT168
fractional anisotropy
Habenular Nuclei
dti.fa.thm.eth.hn.left
DTI_mean_fa_thm_eth_hn_right
DTI
right
CIT168
fractional anisotropy
Habenular Nuclei
dti.fa.thm.eth.hn.right
DTI_volume_fa_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
dti.volume.fa.bn.gp.gpe.left
DTI_volume_fa_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
dti.volume.fa.bn.gp.gpe.right
DTI_volume_fa_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
dti.volume.fa.bn.gp.gpi.left
DTI_volume_fa_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
dti.volume.fa.bn.gp.gpi.right
DTI_volume_fa_bn_gp_vep_left
DTI
left
CIT168
geometry/volume
ventral pallidum
dti.volume.fa.bn.gp.vep.left
DTI_volume_fa_bn_gp_vep_right
DTI
right
CIT168
geometry/volume
ventral pallidum
dti.volume.fa.bn.gp.vep.right
DTI_volume_fa_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
dti.volume.fa.bn.str.ca.left
DTI_volume_fa_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
dti.volume.fa.bn.str.ca.right
DTI_volume_fa_bn_str_nac_left
DTI
left
CIT168
geometry/volume
Nucleus Accumbens
dti.volume.fa.bn.str.nac.left
DTI_volume_fa_bn_str_nac_right
DTI
right
CIT168
geometry/volume
Nucleus Accumbens
dti.volume.fa.bn.str.nac.right
DTI_volume_fa_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
dti.volume.fa.bn.str.pu.left
DTI_volume_fa_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
dti.volume.fa.bn.str.pu.right
DTI_volume_fa_die_hth_left
DTI
left
CIT168
geometry/volume
Hypothalamus
dti.volume.fa.die.hth.left
DTI_volume_fa_die_hth_mn_left
DTI
left
CIT168
geometry/volume
mammillary nucleus
dti.volume.fa.die.hth.mn.left
DTI_volume_fa_die_hth_mn_right
DTI
right
CIT168
geometry/volume
mammillary nucleus
dti.volume.fa.die.hth.mn.right
DTI_volume_fa_die_hth_right
DTI
right
CIT168
geometry/volume
Hypothalamus
dti.volume.fa.die.hth.right
DTI_volume_fa_die_sth_left
DTI
left
CIT168
geometry/volume
Subthalamic Nucleus
dti.volume.fa.die.sth.left
DTI_volume_fa_die_sth_right
DTI
right
CIT168
geometry/volume
Subthalamic Nucleus
dti.volume.fa.die.sth.right
DTI_volume_fa_exa_left
DTI
left
CIT168
geometry/volume
extended amygdala
dti.volume.fa.exa.left
DTI_volume_fa_exa_right
DTI
right
CIT168
geometry/volume
extended amygdala
dti.volume.fa.exa.right
DTI_volume_fa_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
dti.volume.fa.mtg.rn.left
DTI_volume_fa_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
dti.volume.fa.mtg.rn.right
DTI_volume_fa_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.fa.snc.left
DTI_volume_fa_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.fa.snc.right
DTI_volume_fa_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.fa.snr.left
DTI_volume_fa_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.fa.snr.right
DTI_volume_fa_mtg_vtr_pbp_left
DTI
left
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
dti.volume.fa.mtg.vtr.pbp.left
DTI_volume_fa_mtg_vtr_pbp_right
DTI
right
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
dti.volume.fa.mtg.vtr.pbp.right
DTI_volume_fa_mtg_vtr_vta_left
DTI
left
CIT168
geometry/volume
Ventral Tegmental Area
dti.volume.fa.mtg.vtr.vta.left
DTI_volume_fa_mtg_vtr_vta_right
DTI
right
CIT168
geometry/volume
Ventral Tegmental Area
dti.volume.fa.mtg.vtr.vta.right
DTI_volume_fa_referenceregion_left
DTI
left
CIT168
geometry/volume
​
dti.volume.fa.referenceregion.left
DTI_volume_fa_referenceregion_right
DTI
right
CIT168
geometry/volume
​
dti.volume.fa.referenceregion.right
DTI_volume_fa_thm_eth_hn_left
DTI
left
CIT168
geometry/volume
Habenular Nuclei
dti.volume.fa.thm.eth.hn.left
DTI_volume_fa_thm_eth_hn_right
DTI
right
CIT168
geometry/volume
Habenular Nuclei
dti.volume.fa.thm.eth.hn.right
DTI_mean_fa_ch13_left
DTI
left
BF
fractional anisotropy
basal nucleus ch1 to ch3
dti.fa.ch13.left
DTI_mean_fa_ch13_right
DTI
right
BF
fractional anisotropy
basal nucleus ch1 to ch3
dti.fa.ch13.right
DTI_mean_fa_nbm_left_ant
DTI
left
BF
fractional anisotropy
basal nucleus anterior ch4
dti.fa.nbm.left.ant
DTI_mean_fa_nbm_left_mid
DTI
left
BF
fractional anisotropy
basal nucleus middle ch4
dti.fa.nbm.left.mid
DTI_mean_fa_nbm_left_pos
DTI
left
BF
fractional anisotropy
basal nucleus posterior ch4
dti.fa.nbm.left.pos
DTI_mean_fa_nbm_right_ant
DTI
right
BF
fractional anisotropy
basal nucleus anterior ch4
dti.fa.nbm.right.ant
DTI_mean_fa_nbm_right_mid
DTI
right
BF
fractional anisotropy
basal nucleus middle ch4
dti.fa.nbm.right.mid
DTI_mean_fa_nbm_right_pos
DTI
right
BF
fractional anisotropy
basal nucleus posterior ch4
dti.fa.nbm.right.pos
DTI_volume_fa_ch13_left
DTI
left
BF
geometry/volume
basal nucleus ch1 to ch3
dti.volume.fa.ch13.left
DTI_volume_fa_ch13_right
DTI
right
BF
geometry/volume
basal nucleus ch1 to ch3
dti.volume.fa.ch13.right
DTI_volume_fa_nbm_left_ant
DTI
left
BF
geometry/volume
basal nucleus anterior ch4
dti.volume.fa.nbm.left.ant
DTI_volume_fa_nbm_left_mid
DTI
left
BF
geometry/volume
basal nucleus middle ch4
dti.volume.fa.nbm.left.mid
DTI_volume_fa_nbm_left_pos
DTI
left
BF
geometry/volume
basal nucleus posterior ch4
dti.volume.fa.nbm.left.pos
DTI_volume_fa_nbm_right_ant
DTI
right
BF
geometry/volume
basal nucleus anterior ch4
dti.volume.fa.nbm.right.ant
DTI_volume_fa_nbm_right_mid
DTI
right
BF
geometry/volume
basal nucleus middle ch4
dti.volume.fa.nbm.right.mid
DTI_volume_fa_nbm_right_pos
DTI
right
BF
geometry/volume
basal nucleus posterior ch4
dti.volume.fa.nbm.right.pos
DTI_mean_md_background
DTI
​
ANTs
mean diffusion
background
dti.mean.md.background
DTI_mean_md_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
caudal anterior cingulate
dti.mean.md.left.caudal.ant.cingulate
DTI_mean_md_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
mean diffusion
caudal middle frontal
dti.mean.md.left.caudal.middle.frontal
DTI_mean_md_left_cuneus
DTI
left
desikan-killiany-tourville
mean diffusion
cuneus
dti.mean.md.left.cuneus
DTI_mean_md_left_entorhinal
DTI
left
desikan-killiany-tourville
mean diffusion
entorhinal
dti.mean.md.left.entorhinal
DTI_mean_md_left_fusiform
DTI
left
desikan-killiany-tourville
mean diffusion
fusiform
dti.mean.md.left.fusiform
DTI_mean_md_left_inferior_parietal
DTI
left
desikan-killiany-tourville
mean diffusion
inferior parietal
dti.mean.md.left.inf.parietal
DTI_mean_md_left_inferior_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
inferior temporal
dti.mean.md.left.inf.temporal
DTI_mean_md_left_insula
DTI
left
desikan-killiany-tourville
mean diffusion
insula
dti.mean.md.left.insula
DTI_mean_md_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
isthmus cingulate
dti.mean.md.left.isthmus.cingulate
DTI_mean_md_left_lateral_occipital
DTI
left
desikan-killiany-tourville
mean diffusion
lateral occipital
dti.mean.md.left.lateral.occipital
DTI_mean_md_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
mean diffusion
lateral orbitofrontal
dti.mean.md.left.lateral.orbitofrontal
DTI_mean_md_left_lingual
DTI
left
desikan-killiany-tourville
mean diffusion
lingual
dti.mean.md.left.lingual
DTI_mean_md_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
mean diffusion
medial orbitofrontal
dti.mean.md.left.medial.orbitofrontal
DTI_mean_md_left_middle_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
middle temporal
dti.mean.md.left.middle.temporal
DTI_mean_md_left_paracentral
DTI
left
desikan-killiany-tourville
mean diffusion
paracentral
dti.mean.md.left.paracent
DTI_mean_md_left_parahippocampal
DTI
left
desikan-killiany-tourville
mean diffusion
parahippocampal
dti.mean.md.left.parahippocampal
DTI_mean_md_left_pars_opercularis
DTI
left
desikan-killiany-tourville
mean diffusion
pars opercularis
dti.mean.md.left.pars.opercularis
DTI_mean_md_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
mean diffusion
pars orbitalis
dti.mean.md.left.pars.orbitalis
DTI_mean_md_left_pars_triangularis
DTI
left
desikan-killiany-tourville
mean diffusion
pars triangularis
dti.mean.md.left.pars.triangularis
DTI_mean_md_left_pericalcarine
DTI
left
desikan-killiany-tourville
mean diffusion
pericalcarine
dti.mean.md.left.pericalcarine
DTI_mean_md_left_postcentral
DTI
left
desikan-killiany-tourville
mean diffusion
postcentral
dti.mean.md.left.postcent
DTI_mean_md_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
posterior cingulate
dti.mean.md.left.post.cingulate
DTI_mean_md_left_precentral
DTI
left
desikan-killiany-tourville
mean diffusion
precentral
dti.mean.md.left.precent
DTI_mean_md_left_precuneus
DTI
left
desikan-killiany-tourville
mean diffusion
precuneus
dti.mean.md.left.precuneus
DTI_mean_md_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
rostral anterior cingulate
dti.mean.md.left.rostral.ant.cingulate
DTI_mean_md_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
mean diffusion
rostral middle frontal
dti.mean.md.left.rostral.middle.frontal
DTI_mean_md_left_superior_frontal
DTI
left
desikan-killiany-tourville
mean diffusion
superior frontal
dti.mean.md.left.sup.frontal
DTI_mean_md_left_superior_parietal
DTI
left
desikan-killiany-tourville
mean diffusion
superior parietal
dti.mean.md.left.sup.parietal
DTI_mean_md_left_superior_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
superior temporal
dti.mean.md.left.sup.temporal
DTI_mean_md_left_supramarginal
DTI
left
desikan-killiany-tourville
mean diffusion
supramarginal
dti.mean.md.left.supramarginal
DTI_mean_md_left_transverse_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
transverse temporal
dti.mean.md.left.transverse.temporal
DTI_mean_md_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
caudal anterior cingulate
dti.mean.md.right.caudal.ant.cingulate
DTI_mean_md_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
mean diffusion
caudal middle frontal
dti.mean.md.right.caudal.middle.frontal
DTI_mean_md_right_cuneus
DTI
right
desikan-killiany-tourville
mean diffusion
cuneus
dti.mean.md.right.cuneus
DTI_mean_md_right_entorhinal
DTI
right
desikan-killiany-tourville
mean diffusion
entorhinal
dti.mean.md.right.entorhinal
DTI_mean_md_right_fusiform
DTI
right
desikan-killiany-tourville
mean diffusion
fusiform
dti.mean.md.right.fusiform
DTI_mean_md_right_inferior_parietal
DTI
right
desikan-killiany-tourville
mean diffusion
inferior parietal
dti.mean.md.right.inf.parietal
DTI_mean_md_right_inferior_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
inferior temporal
dti.mean.md.right.inf.temporal
DTI_mean_md_right_insula
DTI
right
desikan-killiany-tourville
mean diffusion
insula
dti.mean.md.right.insula
DTI_mean_md_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
isthmus cingulate
dti.mean.md.right.isthmus.cingulate
DTI_mean_md_right_lateral_occipital
DTI
right
desikan-killiany-tourville
mean diffusion
lateral occipital
dti.mean.md.right.lateral.occipital
DTI_mean_md_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
mean diffusion
lateral orbitofrontal
dti.mean.md.right.lateral.orbitofrontal
DTI_mean_md_right_lingual
DTI
right
desikan-killiany-tourville
mean diffusion
lingual
dti.mean.md.right.lingual
DTI_mean_md_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
mean diffusion
medial orbitofrontal
dti.mean.md.right.medial.orbitofrontal
DTI_mean_md_right_middle_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
middle temporal
dti.mean.md.right.middle.temporal
DTI_mean_md_right_paracentral
DTI
right
desikan-killiany-tourville
mean diffusion
paracentral
dti.mean.md.right.paracent
DTI_mean_md_right_parahippocampal
DTI
right
desikan-killiany-tourville
mean diffusion
parahippocampal
dti.mean.md.right.parahippocampal
DTI_mean_md_right_pars_opercularis
DTI
right
desikan-killiany-tourville
mean diffusion
pars opercularis
dti.mean.md.right.pars.opercularis
DTI_mean_md_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
mean diffusion
pars orbitalis
dti.mean.md.right.pars.orbitalis
DTI_mean_md_right_pars_triangularis
DTI
right
desikan-killiany-tourville
mean diffusion
pars triangularis
dti.mean.md.right.pars.triangularis
DTI_mean_md_right_pericalcarine
DTI
right
desikan-killiany-tourville
mean diffusion
pericalcarine
dti.mean.md.right.pericalcarine
DTI_mean_md_right_postcentral
DTI
right
desikan-killiany-tourville
mean diffusion
postcentral
dti.mean.md.right.postcent
DTI_mean_md_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
posterior cingulate
dti.mean.md.right.post.cingulate
DTI_mean_md_right_precentral
DTI
right
desikan-killiany-tourville
mean diffusion
precentral
dti.mean.md.right.precent
DTI_mean_md_right_precuneus
DTI
right
desikan-killiany-tourville
mean diffusion
precuneus
dti.mean.md.right.precuneus
DTI_mean_md_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
rostral anterior cingulate
dti.mean.md.right.rostral.ant.cingulate
DTI_mean_md_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
mean diffusion
rostral middle frontal
dti.mean.md.right.rostral.middle.frontal
DTI_mean_md_right_superior_frontal
DTI
right
desikan-killiany-tourville
mean diffusion
superior frontal
dti.mean.md.right.sup.frontal
DTI_mean_md_right_superior_parietal
DTI
right
desikan-killiany-tourville
mean diffusion
superior parietal
dti.mean.md.right.sup.parietal
DTI_mean_md_right_superior_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
superior temporal
dti.mean.md.right.sup.temporal
DTI_mean_md_right_supramarginal
DTI
right
desikan-killiany-tourville
mean diffusion
supramarginal
dti.mean.md.right.supramarginal
DTI_mean_md_right_transverse_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
transverse temporal
dti.mean.md.right.transverse.temporal
DTI_volume_md_background
DTI
​
ANTs
geometry/volume
background
dti.volume.md.background
DTI_volume_md_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
dti.volume.md.left.caudal.ant.cingulate
DTI_volume_md_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
dti.volume.md.left.caudal.middle.frontal
DTI_volume_md_left_cuneus
DTI
left
desikan-killiany-tourville
geometry/volume
cuneus
dti.volume.md.left.cuneus
DTI_volume_md_left_entorhinal
DTI
left
desikan-killiany-tourville
geometry/volume
entorhinal
dti.volume.md.left.entorhinal
DTI_volume_md_left_fusiform
DTI
left
desikan-killiany-tourville
geometry/volume
fusiform
dti.volume.md.left.fusiform
DTI_volume_md_left_inferior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior parietal
dti.volume.md.left.inf.parietal
DTI_volume_md_left_inferior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior temporal
dti.volume.md.left.inf.temporal
DTI_volume_md_left_insula
DTI
left
desikan-killiany-tourville
geometry/volume
insula
dti.volume.md.left.insula
DTI_volume_md_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
dti.volume.md.left.isthmus.cingulate
DTI_volume_md_left_lateral_occipital
DTI
left
desikan-killiany-tourville
geometry/volume
lateral occipital
dti.volume.md.left.lateral.occipital
DTI_volume_md_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
dti.volume.md.left.lateral.orbitofrontal
DTI_volume_md_left_lingual
DTI
left
desikan-killiany-tourville
geometry/volume
lingual
dti.volume.md.left.lingual
DTI_volume_md_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
dti.volume.md.left.medial.orbitofrontal
DTI_volume_md_left_middle_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
middle temporal
dti.volume.md.left.middle.temporal
DTI_volume_md_left_paracentral
DTI
left
desikan-killiany-tourville
geometry/volume
paracentral
dti.volume.md.left.paracent
DTI_volume_md_left_parahippocampal
DTI
left
desikan-killiany-tourville
geometry/volume
parahippocampal
dti.volume.md.left.parahippocampal
DTI_volume_md_left_pars_opercularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars opercularis
dti.volume.md.left.pars.opercularis
DTI_volume_md_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
dti.volume.md.left.pars.orbitalis
DTI_volume_md_left_pars_triangularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars triangularis
dti.volume.md.left.pars.triangularis
DTI_volume_md_left_pericalcarine
DTI
left
desikan-killiany-tourville
geometry/volume
pericalcarine
dti.volume.md.left.pericalcarine
DTI_volume_md_left_postcentral
DTI
left
desikan-killiany-tourville
geometry/volume
postcentral
dti.volume.md.left.postcent
DTI_volume_md_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
dti.volume.md.left.post.cingulate
DTI_volume_md_left_precentral
DTI
left
desikan-killiany-tourville
geometry/volume
precentral
dti.volume.md.left.precent
DTI_volume_md_left_precuneus
DTI
left
desikan-killiany-tourville
geometry/volume
precuneus
dti.volume.md.left.precuneus
DTI_volume_md_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
dti.volume.md.left.rostral.ant.cingulate
DTI_volume_md_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
dti.volume.md.left.rostral.middle.frontal
DTI_volume_md_left_superior_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
superior frontal
dti.volume.md.left.sup.frontal
DTI_volume_md_left_superior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
superior parietal
dti.volume.md.left.sup.parietal
DTI_volume_md_left_superior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
superior temporal
dti.volume.md.left.sup.temporal
DTI_volume_md_left_supramarginal
DTI
left
desikan-killiany-tourville
geometry/volume
supramarginal
dti.volume.md.left.supramarginal
DTI_volume_md_left_transverse_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
transverse temporal
dti.volume.md.left.transverse.temporal
DTI_volume_md_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
dti.volume.md.right.caudal.ant.cingulate
DTI_volume_md_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
dti.volume.md.right.caudal.middle.frontal
DTI_volume_md_right_cuneus
DTI
right
desikan-killiany-tourville
geometry/volume
cuneus
dti.volume.md.right.cuneus
DTI_volume_md_right_entorhinal
DTI
right
desikan-killiany-tourville
geometry/volume
entorhinal
dti.volume.md.right.entorhinal
DTI_volume_md_right_fusiform
DTI
right
desikan-killiany-tourville
geometry/volume
fusiform
dti.volume.md.right.fusiform
DTI_volume_md_right_inferior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior parietal
dti.volume.md.right.inf.parietal
DTI_volume_md_right_inferior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior temporal
dti.volume.md.right.inf.temporal
DTI_volume_md_right_insula
DTI
right
desikan-killiany-tourville
geometry/volume
insula
dti.volume.md.right.insula
DTI_volume_md_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
dti.volume.md.right.isthmus.cingulate
DTI_volume_md_right_lateral_occipital
DTI
right
desikan-killiany-tourville
geometry/volume
lateral occipital
dti.volume.md.right.lateral.occipital
DTI_volume_md_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
dti.volume.md.right.lateral.orbitofrontal
DTI_volume_md_right_lingual
DTI
right
desikan-killiany-tourville
geometry/volume
lingual
dti.volume.md.right.lingual
DTI_volume_md_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
dti.volume.md.right.medial.orbitofrontal
DTI_volume_md_right_middle_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
middle temporal
dti.volume.md.right.middle.temporal
DTI_volume_md_right_paracentral
DTI
right
desikan-killiany-tourville
geometry/volume
paracentral
dti.volume.md.right.paracent
DTI_volume_md_right_parahippocampal
DTI
right
desikan-killiany-tourville
geometry/volume
parahippocampal
dti.volume.md.right.parahippocampal
DTI_volume_md_right_pars_opercularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars opercularis
dti.volume.md.right.pars.opercularis
DTI_volume_md_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
dti.volume.md.right.pars.orbitalis
DTI_volume_md_right_pars_triangularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars triangularis
dti.volume.md.right.pars.triangularis
DTI_volume_md_right_pericalcarine
DTI
right
desikan-killiany-tourville
geometry/volume
pericalcarine
dti.volume.md.right.pericalcarine
DTI_volume_md_right_postcentral
DTI
right
desikan-killiany-tourville
geometry/volume
postcentral
dti.volume.md.right.postcent
DTI_volume_md_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
dti.volume.md.right.post.cingulate
DTI_volume_md_right_precentral
DTI
right
desikan-killiany-tourville
geometry/volume
precentral
dti.volume.md.right.precent
DTI_volume_md_right_precuneus
DTI
right
desikan-killiany-tourville
geometry/volume
precuneus
dti.volume.md.right.precuneus
DTI_volume_md_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
dti.volume.md.right.rostral.ant.cingulate
DTI_volume_md_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
dti.volume.md.right.rostral.middle.frontal
DTI_volume_md_right_superior_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
superior frontal
dti.volume.md.right.sup.frontal
DTI_volume_md_right_superior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
superior parietal
dti.volume.md.right.sup.parietal
DTI_volume_md_right_superior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
superior temporal
dti.volume.md.right.sup.temporal
DTI_volume_md_right_supramarginal
DTI
right
desikan-killiany-tourville
geometry/volume
supramarginal
dti.volume.md.right.supramarginal
DTI_volume_md_right_transverse_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
transverse temporal
dti.volume.md.right.transverse.temporal
DTI_mean_md_deep_bn_gp_gpe_left
DTI
left
CIT168
mean diffusion
globus pallidus externa
dti.mean.md.deep.bn.gp.gpe.left
DTI_mean_md_deep_bn_gp_gpe_right
DTI
right
CIT168
mean diffusion
globus pallidus externa
dti.mean.md.deep.bn.gp.gpe.right
DTI_mean_md_deep_bn_gp_gpi_left
DTI
left
CIT168
mean diffusion
globus pallidus interna
dti.mean.md.deep.bn.gp.gpi.left
DTI_mean_md_deep_bn_gp_gpi_right
DTI
right
CIT168
mean diffusion
globus pallidus interna
dti.mean.md.deep.bn.gp.gpi.right
DTI_mean_md_deep_bn_str_ca_left
DTI
left
CIT168
mean diffusion
caudate
dti.mean.md.deep.bn.str.ca.left
DTI_mean_md_deep_bn_str_ca_right
DTI
right
CIT168
mean diffusion
caudate
dti.mean.md.deep.bn.str.ca.right
DTI_mean_md_deep_bn_str_pu_left
DTI
left
CIT168
mean diffusion
putamen
dti.mean.md.deep.bn.str.pu.left
DTI_mean_md_deep_bn_str_pu_right
DTI
right
CIT168
mean diffusion
putamen
dti.mean.md.deep.bn.str.pu.right
DTI_mean_md_deep_mtg_rn_left
DTI
left
CIT168
mean diffusion
red nucleus
dti.mean.md.deep.mtg.rn.left
DTI_mean_md_deep_mtg_rn_right
DTI
right
CIT168
mean diffusion
red nucleus
dti.mean.md.deep.mtg.rn.right
DTI_mean_md_deep_mtg_sn_snc_left
DTI
left
CIT168
mean diffusion
Substantia Nigra pars compacta
dti.mean.md.deep.snc.left
DTI_mean_md_deep_mtg_sn_snc_right
DTI
right
CIT168
mean diffusion
Substantia Nigra pars compacta
dti.mean.md.deep.snc.right
DTI_mean_md_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.mean.md.deep.snr.left
DTI_mean_md_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.mean.md.deep.snr.right
DTI_mean_md_deep_referenceregion_left
DTI
left
CIT168
mean diffusion
​
dti.mean.md.deep.referenceregion.left
DTI_mean_md_deep_referenceregion_right
DTI
right
CIT168
mean diffusion
​
dti.mean.md.deep.referenceregion.right
DTI_volume_md_deep_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
dti.volume.md.deep.bn.gp.gpe.left
DTI_volume_md_deep_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
dti.volume.md.deep.bn.gp.gpe.right
DTI_volume_md_deep_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
dti.volume.md.deep.bn.gp.gpi.left
DTI_volume_md_deep_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
dti.volume.md.deep.bn.gp.gpi.right
DTI_volume_md_deep_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
dti.volume.md.deep.bn.str.ca.left
DTI_volume_md_deep_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
dti.volume.md.deep.bn.str.ca.right
DTI_volume_md_deep_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
dti.volume.md.deep.bn.str.pu.left
DTI_volume_md_deep_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
dti.volume.md.deep.bn.str.pu.right
DTI_volume_md_deep_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
dti.volume.md.deep.mtg.rn.left
DTI_volume_md_deep_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
dti.volume.md.deep.mtg.rn.right
DTI_volume_md_deep_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.md.deep.snc.left
DTI_volume_md_deep_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.md.deep.snc.right
DTI_volume_md_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.md.deep.snr.left
DTI_volume_md_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.md.deep.snr.right
DTI_volume_md_deep_referenceregion_left
DTI
left
CIT168
geometry/volume
​
dti.volume.md.deep.referenceregion.left
DTI_volume_md_deep_referenceregion_right
DTI
right
CIT168
geometry/volume
​
dti.volume.md.deep.referenceregion.right
DTI_mean_md_bn_gp_gpe_left
DTI
left
CIT168
mean diffusion
globus pallidus externa
dti.mean.md.bn.gp.gpe.left
DTI_mean_md_bn_gp_gpe_right
DTI
right
CIT168
mean diffusion
globus pallidus externa
dti.mean.md.bn.gp.gpe.right
DTI_mean_md_bn_gp_gpi_left
DTI
left
CIT168
mean diffusion
globus pallidus interna
dti.mean.md.bn.gp.gpi.left
DTI_mean_md_bn_gp_gpi_right
DTI
right
CIT168
mean diffusion
globus pallidus interna
dti.mean.md.bn.gp.gpi.right
DTI_mean_md_bn_gp_vep_left
DTI
left
CIT168
mean diffusion
ventral pallidum
dti.mean.md.bn.gp.vep.left
DTI_mean_md_bn_gp_vep_right
DTI
right
CIT168
mean diffusion
ventral pallidum
dti.mean.md.bn.gp.vep.right
DTI_mean_md_bn_str_ca_left
DTI
left
CIT168
mean diffusion
caudate
dti.mean.md.bn.str.ca.left
DTI_mean_md_bn_str_ca_right
DTI
right
CIT168
mean diffusion
caudate
dti.mean.md.bn.str.ca.right
DTI_mean_md_bn_str_nac_left
DTI
left
CIT168
mean diffusion
Nucleus Accumbens
dti.mean.md.bn.str.nac.left
DTI_mean_md_bn_str_nac_right
DTI
right
CIT168
mean diffusion
Nucleus Accumbens
dti.mean.md.bn.str.nac.right
DTI_mean_md_bn_str_pu_left
DTI
left
CIT168
mean diffusion
putamen
dti.mean.md.bn.str.pu.left
DTI_mean_md_bn_str_pu_right
DTI
right
CIT168
mean diffusion
putamen
dti.mean.md.bn.str.pu.right
DTI_mean_md_die_hth_left
DTI
left
CIT168
mean diffusion
Hypothalamus
dti.mean.md.die.hth.left
DTI_mean_md_die_hth_mn_left
DTI
left
CIT168
mean diffusion
mammillary nucleus
dti.mean.md.die.hth.mn.left
DTI_mean_md_die_hth_mn_right
DTI
right
CIT168
mean diffusion
mammillary nucleus
dti.mean.md.die.hth.mn.right
DTI_mean_md_die_hth_right
DTI
right
CIT168
mean diffusion
Hypothalamus
dti.mean.md.die.hth.right
DTI_mean_md_die_sth_left
DTI
left
CIT168
mean diffusion
Subthalamic Nucleus
dti.mean.md.die.sth.left
DTI_mean_md_die_sth_right
DTI
right
CIT168
mean diffusion
Subthalamic Nucleus
dti.mean.md.die.sth.right
DTI_mean_md_exa_left
DTI
left
CIT168
mean diffusion
extended amygdala
dti.mean.md.exa.left
DTI_mean_md_exa_right
DTI
right
CIT168
mean diffusion
extended amygdala
dti.mean.md.exa.right
DTI_mean_md_mtg_rn_left
DTI
left
CIT168
mean diffusion
red nucleus
dti.mean.md.mtg.rn.left
DTI_mean_md_mtg_rn_right
DTI
right
CIT168
mean diffusion
red nucleus
dti.mean.md.mtg.rn.right
DTI_mean_md_mtg_sn_snc_left
DTI
left
CIT168
mean diffusion
Substantia Nigra pars compacta
dti.mean.md.snc.left
DTI_mean_md_mtg_sn_snc_right
DTI
right
CIT168
mean diffusion
Substantia Nigra pars compacta
dti.mean.md.snc.right
DTI_mean_md_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.mean.md.snr.left
DTI_mean_md_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.mean.md.snr.right
DTI_mean_md_mtg_vtr_pbp_left
DTI
left
CIT168
mean diffusion
Parabrachial Pigmented Nucleus
dti.mean.md.mtg.vtr.pbp.left
DTI_mean_md_mtg_vtr_pbp_right
DTI
right
CIT168
mean diffusion
Parabrachial Pigmented Nucleus
dti.mean.md.mtg.vtr.pbp.right
DTI_mean_md_mtg_vtr_vta_left
DTI
left
CIT168
mean diffusion
Ventral Tegmental Area
dti.mean.md.mtg.vtr.vta.left
DTI_mean_md_mtg_vtr_vta_right
DTI
right
CIT168
mean diffusion
Ventral Tegmental Area
dti.mean.md.mtg.vtr.vta.right
DTI_mean_md_referenceregion_left
DTI
left
CIT168
mean diffusion
​
dti.mean.md.referenceregion.left
DTI_mean_md_referenceregion_right
DTI
right
CIT168
mean diffusion
​
dti.mean.md.referenceregion.right
DTI_mean_md_thm_eth_hn_left
DTI
left
CIT168
mean diffusion
Habenular Nuclei
dti.mean.md.thm.eth.hn.left
DTI_mean_md_thm_eth_hn_right
DTI
right
CIT168
mean diffusion
Habenular Nuclei
dti.mean.md.thm.eth.hn.right
DTI_volume_md_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
dti.volume.md.bn.gp.gpe.left
DTI_volume_md_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
dti.volume.md.bn.gp.gpe.right
DTI_volume_md_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
dti.volume.md.bn.gp.gpi.left
DTI_volume_md_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
dti.volume.md.bn.gp.gpi.right
DTI_volume_md_bn_gp_vep_left
DTI
left
CIT168
geometry/volume
ventral pallidum
dti.volume.md.bn.gp.vep.left
DTI_volume_md_bn_gp_vep_right
DTI
right
CIT168
geometry/volume
ventral pallidum
dti.volume.md.bn.gp.vep.right
DTI_volume_md_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
dti.volume.md.bn.str.ca.left
DTI_volume_md_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
dti.volume.md.bn.str.ca.right
DTI_volume_md_bn_str_nac_left
DTI
left
CIT168
geometry/volume
Nucleus Accumbens
dti.volume.md.bn.str.nac.left
DTI_volume_md_bn_str_nac_right
DTI
right
CIT168
geometry/volume
Nucleus Accumbens
dti.volume.md.bn.str.nac.right
DTI_volume_md_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
dti.volume.md.bn.str.pu.left
DTI_volume_md_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
dti.volume.md.bn.str.pu.right
DTI_volume_md_die_hth_left
DTI
left
CIT168
geometry/volume
Hypothalamus
dti.volume.md.die.hth.left
DTI_volume_md_die_hth_mn_left
DTI
left
CIT168
geometry/volume
mammillary nucleus
dti.volume.md.die.hth.mn.left
DTI_volume_md_die_hth_mn_right
DTI
right
CIT168
geometry/volume
mammillary nucleus
dti.volume.md.die.hth.mn.right
DTI_volume_md_die_hth_right
DTI
right
CIT168
geometry/volume
Hypothalamus
dti.volume.md.die.hth.right
DTI_volume_md_die_sth_left
DTI
left
CIT168
geometry/volume
Subthalamic Nucleus
dti.volume.md.die.sth.left
DTI_volume_md_die_sth_right
DTI
right
CIT168
geometry/volume
Subthalamic Nucleus
dti.volume.md.die.sth.right
DTI_volume_md_exa_left
DTI
left
CIT168
geometry/volume
extended amygdala
dti.volume.md.exa.left
DTI_volume_md_exa_right
DTI
right
CIT168
geometry/volume
extended amygdala
dti.volume.md.exa.right
DTI_volume_md_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
dti.volume.md.mtg.rn.left
DTI_volume_md_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
dti.volume.md.mtg.rn.right
DTI_volume_md_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.md.snc.left
DTI_volume_md_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.md.snc.right
DTI_volume_md_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.md.snr.left
DTI_volume_md_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.md.snr.right
DTI_volume_md_mtg_vtr_pbp_left
DTI
left
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
dti.volume.md.mtg.vtr.pbp.left
DTI_volume_md_mtg_vtr_pbp_right
DTI
right
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
dti.volume.md.mtg.vtr.pbp.right
DTI_volume_md_mtg_vtr_vta_left
DTI
left
CIT168
geometry/volume
Ventral Tegmental Area
dti.volume.md.mtg.vtr.vta.left
DTI_volume_md_mtg_vtr_vta_right
DTI
right
CIT168
geometry/volume
Ventral Tegmental Area
dti.volume.md.mtg.vtr.vta.right
DTI_volume_md_referenceregion_left
DTI
left
CIT168
geometry/volume
​
dti.volume.md.referenceregion.left
DTI_volume_md_referenceregion_right
DTI
right
CIT168
geometry/volume
​
dti.volume.md.referenceregion.right
DTI_volume_md_thm_eth_hn_left
DTI
left
CIT168
geometry/volume
Habenular Nuclei
dti.volume.md.thm.eth.hn.left
DTI_volume_md_thm_eth_hn_right
DTI
right
CIT168
geometry/volume
Habenular Nuclei
dti.volume.md.thm.eth.hn.right
DTI_mean_md_ch13_left
DTI
left
BF
mean diffusion
basal nucleus ch1 to ch3
dti.mean.md.ch13.left
DTI_mean_md_ch13_right
DTI
right
BF
mean diffusion
basal nucleus ch1 to ch3
dti.mean.md.ch13.right
DTI_mean_md_nbm_left_ant
DTI
left
BF
mean diffusion
basal nucleus anterior ch4
dti.mean.md.nbm.left.ant
DTI_mean_md_nbm_left_mid
DTI
left
BF
mean diffusion
basal nucleus middle ch4
dti.mean.md.nbm.left.mid
DTI_mean_md_nbm_left_pos
DTI
left
BF
mean diffusion
basal nucleus posterior ch4
dti.mean.md.nbm.left.pos
DTI_mean_md_nbm_right_ant
DTI
right
BF
mean diffusion
basal nucleus anterior ch4
dti.mean.md.nbm.right.ant
DTI_mean_md_nbm_right_mid
DTI
right
BF
mean diffusion
basal nucleus middle ch4
dti.mean.md.nbm.right.mid
DTI_mean_md_nbm_right_pos
DTI
right
BF
mean diffusion
basal nucleus posterior ch4
dti.mean.md.nbm.right.pos
DTI_volume_md_ch13_left
DTI
left
BF
geometry/volume
basal nucleus ch1 to ch3
dti.volume.md.ch13.left
DTI_volume_md_ch13_right
DTI
right
BF
geometry/volume
basal nucleus ch1 to ch3
dti.volume.md.ch13.right
DTI_volume_md_nbm_left_ant
DTI
left
BF
geometry/volume
basal nucleus anterior ch4
dti.volume.md.nbm.left.ant
DTI_volume_md_nbm_left_mid
DTI
left
BF
geometry/volume
basal nucleus middle ch4
dti.volume.md.nbm.left.mid
DTI_volume_md_nbm_left_pos
DTI
left
BF
geometry/volume
basal nucleus posterior ch4
dti.volume.md.nbm.left.pos
DTI_volume_md_nbm_right_ant
DTI
right
BF
geometry/volume
basal nucleus anterior ch4
dti.volume.md.nbm.right.ant
DTI_volume_md_nbm_right_mid
DTI
right
BF
geometry/volume
basal nucleus middle ch4
dti.volume.md.nbm.right.mid
DTI_volume_md_nbm_right_pos
DTI
right
BF
geometry/volume
basal nucleus posterior ch4
dti.volume.md.nbm.right.pos
DTI_dti_tsnr_b0_mean
DTI
​
ANTs
QC
​
dti.dti.tsnr.b0.mean
DTI_dti_tsnr_dwi_mean
DTI
​
ANTs
QC
​
dti.dti.tsnr.dwi.mean
DTI_dti_dvars_b0_mean
DTI
​
ANTs
QC
​
dti.dti.dvars.b0.mean
DTI_dti_dvars_dwi_mean
DTI
​
ANTs
QC
​
dti.dti.dvars.dwi.mean
DTI_dti_ssnr_b0_mean
DTI
​
ANTs
QC
​
dti.dti.ssnr.b0.mean
DTI_dti_ssnr_dwi_mean
DTI
​
ANTs
QC
​
dti.dti.ssnr.dwi.mean
DTI_dti_fa_evr
DTI
​
ANTs
QC
​
dti.dti.fa.evr
DTI_dti_fa_SNR
DTI
​
ANTs
QC
​
dti.dti.fa.snr
DTI_dti_high_motion_count
DTI
​
ANTs
QC
​
dti.dti.high.motion.count
DTI_dti_FD_mean
DTI
​
ANTs
mean framewise displacement
​
dti.dti.fd.mean
DTI_dti_FD_max
DTI
​
ANTs
max framewise displacement
​
dti.dti.fd.max
DTI_dti_FD_sd
DTI
​
ANTs
motion statistic on framewise displacement
​
dti.dti.fd.sd
NM2DMT_mean_bn_str_ca_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
caudate
nm2dmt.mean.bn.str.ca.right
NM2DMT_mean_bn_str_ca_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
caudate
nm2dmt.mean.bn.str.ca.left
NM2DMT_NM_avg_signaltonoise
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.avg.signaltonoise
NM2DMT_NM_avg_substantianigra
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.avg.substantianigra
NM2DMT_NM_std_substantianigra
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.std.substantianigra
NM2DMT_NM_avg_refregion
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.avg.refregion
NM2DMT_NM_std_refregion
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.std.refregion
NM2DMT_NM_min
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.min
NM2DMT_NM_max
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.max
NM2DMT_NM_mean
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.mean
NM2DMT_NM_sd
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.sd

## Joining with clinical data: PPMI

We provide an example of how to join derived `ANTsPyMM` summary data with clinical variables from PPMI.

    library( subtyper)
    ?merge_ppmi_imaging_clinical_demographic_data